Documentation
¶
Index ¶
- func AlloydbBackup_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func AlloydbBackup_IsConstruct(x interface{}) *bool
- func AlloydbBackup_IsTerraformElement(x interface{}) *bool
- func AlloydbBackup_IsTerraformResource(x interface{}) *bool
- func AlloydbBackup_TfResourceType() *string
- func NewAlloydbBackupEncryptionConfigOutputReference_Override(a AlloydbBackupEncryptionConfigOutputReference, ...)
- func NewAlloydbBackupEncryptionInfoList_Override(a AlloydbBackupEncryptionInfoList, ...)
- func NewAlloydbBackupEncryptionInfoOutputReference_Override(a AlloydbBackupEncryptionInfoOutputReference, ...)
- func NewAlloydbBackupExpiryQuantityList_Override(a AlloydbBackupExpiryQuantityList, ...)
- func NewAlloydbBackupExpiryQuantityOutputReference_Override(a AlloydbBackupExpiryQuantityOutputReference, ...)
- func NewAlloydbBackupTimeoutsOutputReference_Override(a AlloydbBackupTimeoutsOutputReference, ...)
- func NewAlloydbBackup_Override(a AlloydbBackup, scope constructs.Construct, id *string, ...)
- type AlloydbBackup
- type AlloydbBackupConfig
- type AlloydbBackupEncryptionConfig
- type AlloydbBackupEncryptionConfigOutputReference
- type AlloydbBackupEncryptionInfo
- type AlloydbBackupEncryptionInfoList
- type AlloydbBackupEncryptionInfoOutputReference
- type AlloydbBackupExpiryQuantity
- type AlloydbBackupExpiryQuantityList
- type AlloydbBackupExpiryQuantityOutputReference
- type AlloydbBackupTimeouts
- type AlloydbBackupTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AlloydbBackup_GenerateConfigForImport ¶
func AlloydbBackup_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a AlloydbBackup resource upon running "cdktf plan <stack-name>".
func AlloydbBackup_IsConstruct ¶
func AlloydbBackup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AlloydbBackup_IsTerraformElement ¶
func AlloydbBackup_IsTerraformElement(x interface{}) *bool
Experimental.
func AlloydbBackup_IsTerraformResource ¶
func AlloydbBackup_IsTerraformResource(x interface{}) *bool
Experimental.
func AlloydbBackup_TfResourceType ¶
func AlloydbBackup_TfResourceType() *string
func NewAlloydbBackupEncryptionConfigOutputReference_Override ¶
func NewAlloydbBackupEncryptionConfigOutputReference_Override(a AlloydbBackupEncryptionConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAlloydbBackupEncryptionInfoList_Override ¶
func NewAlloydbBackupEncryptionInfoList_Override(a AlloydbBackupEncryptionInfoList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAlloydbBackupEncryptionInfoOutputReference_Override ¶
func NewAlloydbBackupEncryptionInfoOutputReference_Override(a AlloydbBackupEncryptionInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAlloydbBackupExpiryQuantityList_Override ¶
func NewAlloydbBackupExpiryQuantityList_Override(a AlloydbBackupExpiryQuantityList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAlloydbBackupExpiryQuantityOutputReference_Override ¶
func NewAlloydbBackupExpiryQuantityOutputReference_Override(a AlloydbBackupExpiryQuantityOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAlloydbBackupTimeoutsOutputReference_Override ¶
func NewAlloydbBackupTimeoutsOutputReference_Override(a AlloydbBackupTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAlloydbBackup_Override ¶
func NewAlloydbBackup_Override(a AlloydbBackup, scope constructs.Construct, id *string, config *AlloydbBackupConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup google_alloydb_backup} Resource.
Types ¶
type AlloydbBackup ¶
type AlloydbBackup interface {
cdktf.TerraformResource
Annotations() *map[string]*string
SetAnnotations(val *map[string]*string)
AnnotationsInput() *map[string]*string
BackupId() *string
SetBackupId(val *string)
BackupIdInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterName() *string
SetClusterName(val *string)
ClusterNameInput() *string
ClusterUid() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
DeleteTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
EffectiveAnnotations() cdktf.StringMap
EffectiveLabels() cdktf.StringMap
EncryptionConfig() AlloydbBackupEncryptionConfigOutputReference
EncryptionConfigInput() *AlloydbBackupEncryptionConfig
EncryptionInfo() AlloydbBackupEncryptionInfoList
Etag() *string
ExpiryQuantity() AlloydbBackupExpiryQuantityList
ExpiryTime() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Reconciling() cdktf.IResolvable
SizeBytes() *string
State() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() AlloydbBackupTimeoutsOutputReference
TimeoutsInput() interface{}
Type() *string
SetType(val *string)
TypeInput() *string
Uid() *string
UpdateTime() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEncryptionConfig(value *AlloydbBackupEncryptionConfig)
PutTimeouts(value *AlloydbBackupTimeouts)
ResetAnnotations()
ResetDescription()
ResetDisplayName()
ResetEncryptionConfig()
ResetId()
ResetLabels()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
ResetType()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup google_alloydb_backup}.
func NewAlloydbBackup ¶
func NewAlloydbBackup(scope constructs.Construct, id *string, config *AlloydbBackupConfig) AlloydbBackup
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup google_alloydb_backup} Resource.
type AlloydbBackupConfig ¶
type AlloydbBackupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The ID of the alloydb backup.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#backup_id AlloydbBackup#backup_id}
BackupId *string `field:"required" json:"backupId" yaml:"backupId"`
// The full resource name of the backup source cluster (e.g., projects/{project}/locations/{location}/clusters/{clusterId}).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#cluster_name AlloydbBackup#cluster_name}
ClusterName *string `field:"required" json:"clusterName" yaml:"clusterName"`
// The location where the alloydb backup should reside.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#location AlloydbBackup#location}
Location *string `field:"required" json:"location" yaml:"location"`
// Annotations to allow client tools to store small amount of arbitrary data.
//
// This is distinct from labels. https://google.aip.dev/128
// An object containing a list of "key": value pairs. Example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
//
//
// **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
// Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#annotations AlloydbBackup#annotations}
Annotations *map[string]*string `field:"optional" json:"annotations" yaml:"annotations"`
// User-provided description of the backup.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#description AlloydbBackup#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// User-settable and human-readable display name for the Backup.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#display_name AlloydbBackup#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// encryption_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#encryption_config AlloydbBackup#encryption_config}
EncryptionConfig *AlloydbBackupEncryptionConfig `field:"optional" json:"encryptionConfig" yaml:"encryptionConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#id AlloydbBackup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// User-defined labels for the alloydb backup.
//
// An object containing a list of "key": value pairs. Example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
//
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#labels AlloydbBackup#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#project AlloydbBackup#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#timeouts AlloydbBackup#timeouts}
Timeouts *AlloydbBackupTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// The backup type, which suggests the trigger for the backup. Possible values: ["TYPE_UNSPECIFIED", "ON_DEMAND", "AUTOMATED", "CONTINUOUS"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#type AlloydbBackup#type}
Type *string `field:"optional" json:"type" yaml:"type"`
}
type AlloydbBackupEncryptionConfig ¶
type AlloydbBackupEncryptionConfig struct {
// The fully-qualified resource name of the KMS key.
//
// Each Cloud KMS key is regionalized and has the following format: projects/[PROJECT]/locations/[REGION]/keyRings/[RING]/cryptoKeys/[KEY_NAME].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#kms_key_name AlloydbBackup#kms_key_name}
KmsKeyName *string `field:"optional" json:"kmsKeyName" yaml:"kmsKeyName"`
}
type AlloydbBackupEncryptionConfigOutputReference ¶
type AlloydbBackupEncryptionConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AlloydbBackupEncryptionConfig
SetInternalValue(val *AlloydbBackupEncryptionConfig)
KmsKeyName() *string
SetKmsKeyName(val *string)
KmsKeyNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKmsKeyName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlloydbBackupEncryptionConfigOutputReference ¶
func NewAlloydbBackupEncryptionConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AlloydbBackupEncryptionConfigOutputReference
type AlloydbBackupEncryptionInfo ¶
type AlloydbBackupEncryptionInfo struct {
}
type AlloydbBackupEncryptionInfoList ¶
type AlloydbBackupEncryptionInfoList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AlloydbBackupEncryptionInfoOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlloydbBackupEncryptionInfoList ¶
func NewAlloydbBackupEncryptionInfoList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AlloydbBackupEncryptionInfoList
type AlloydbBackupEncryptionInfoOutputReference ¶
type AlloydbBackupEncryptionInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EncryptionType() *string
// Experimental.
Fqn() *string
InternalValue() *AlloydbBackupEncryptionInfo
SetInternalValue(val *AlloydbBackupEncryptionInfo)
KmsKeyVersions() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlloydbBackupEncryptionInfoOutputReference ¶
func NewAlloydbBackupEncryptionInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AlloydbBackupEncryptionInfoOutputReference
type AlloydbBackupExpiryQuantity ¶
type AlloydbBackupExpiryQuantity struct {
}
type AlloydbBackupExpiryQuantityList ¶
type AlloydbBackupExpiryQuantityList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AlloydbBackupExpiryQuantityOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlloydbBackupExpiryQuantityList ¶
func NewAlloydbBackupExpiryQuantityList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AlloydbBackupExpiryQuantityList
type AlloydbBackupExpiryQuantityOutputReference ¶
type AlloydbBackupExpiryQuantityOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AlloydbBackupExpiryQuantity
SetInternalValue(val *AlloydbBackupExpiryQuantity)
RetentionCount() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TotalRetentionCount() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlloydbBackupExpiryQuantityOutputReference ¶
func NewAlloydbBackupExpiryQuantityOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AlloydbBackupExpiryQuantityOutputReference
type AlloydbBackupTimeouts ¶
type AlloydbBackupTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#create AlloydbBackup#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#delete AlloydbBackup#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/alloydb_backup#update AlloydbBackup#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type AlloydbBackupTimeoutsOutputReference ¶
type AlloydbBackupTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlloydbBackupTimeoutsOutputReference ¶
func NewAlloydbBackupTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AlloydbBackupTimeoutsOutputReference
Source Files
¶
- AlloydbBackup.go
- AlloydbBackupConfig.go
- AlloydbBackupEncryptionConfig.go
- AlloydbBackupEncryptionConfigOutputReference.go
- AlloydbBackupEncryptionConfigOutputReference__checks.go
- AlloydbBackupEncryptionInfo.go
- AlloydbBackupEncryptionInfoList.go
- AlloydbBackupEncryptionInfoList__checks.go
- AlloydbBackupEncryptionInfoOutputReference.go
- AlloydbBackupEncryptionInfoOutputReference__checks.go
- AlloydbBackupExpiryQuantity.go
- AlloydbBackupExpiryQuantityList.go
- AlloydbBackupExpiryQuantityList__checks.go
- AlloydbBackupExpiryQuantityOutputReference.go
- AlloydbBackupExpiryQuantityOutputReference__checks.go
- AlloydbBackupTimeouts.go
- AlloydbBackupTimeoutsOutputReference.go
- AlloydbBackupTimeoutsOutputReference__checks.go
- AlloydbBackup__checks.go
- main.go