Documentation
¶
Index ¶
- func BigtableGcPolicy_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func BigtableGcPolicy_IsConstruct(x interface{}) *bool
- func BigtableGcPolicy_IsTerraformElement(x interface{}) *bool
- func BigtableGcPolicy_IsTerraformResource(x interface{}) *bool
- func BigtableGcPolicy_TfResourceType() *string
- func NewBigtableGcPolicyMaxAgeOutputReference_Override(b BigtableGcPolicyMaxAgeOutputReference, ...)
- func NewBigtableGcPolicyMaxVersionList_Override(b BigtableGcPolicyMaxVersionList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewBigtableGcPolicyMaxVersionOutputReference_Override(b BigtableGcPolicyMaxVersionOutputReference, ...)
- func NewBigtableGcPolicyTimeoutsOutputReference_Override(b BigtableGcPolicyTimeoutsOutputReference, ...)
- func NewBigtableGcPolicy_Override(b BigtableGcPolicy, scope constructs.Construct, id *string, ...)
- type BigtableGcPolicy
- type BigtableGcPolicyConfig
- type BigtableGcPolicyMaxAge
- type BigtableGcPolicyMaxAgeOutputReference
- type BigtableGcPolicyMaxVersion
- type BigtableGcPolicyMaxVersionList
- type BigtableGcPolicyMaxVersionOutputReference
- type BigtableGcPolicyTimeouts
- type BigtableGcPolicyTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BigtableGcPolicy_GenerateConfigForImport ¶
func BigtableGcPolicy_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a BigtableGcPolicy resource upon running "cdktf plan <stack-name>".
func BigtableGcPolicy_IsConstruct ¶
func BigtableGcPolicy_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func BigtableGcPolicy_IsTerraformElement ¶
func BigtableGcPolicy_IsTerraformElement(x interface{}) *bool
Experimental.
func BigtableGcPolicy_IsTerraformResource ¶
func BigtableGcPolicy_IsTerraformResource(x interface{}) *bool
Experimental.
func BigtableGcPolicy_TfResourceType ¶
func BigtableGcPolicy_TfResourceType() *string
func NewBigtableGcPolicyMaxAgeOutputReference_Override ¶
func NewBigtableGcPolicyMaxAgeOutputReference_Override(b BigtableGcPolicyMaxAgeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBigtableGcPolicyMaxVersionList_Override ¶
func NewBigtableGcPolicyMaxVersionList_Override(b BigtableGcPolicyMaxVersionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBigtableGcPolicyMaxVersionOutputReference_Override ¶
func NewBigtableGcPolicyMaxVersionOutputReference_Override(b BigtableGcPolicyMaxVersionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBigtableGcPolicyTimeoutsOutputReference_Override ¶
func NewBigtableGcPolicyTimeoutsOutputReference_Override(b BigtableGcPolicyTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBigtableGcPolicy_Override ¶
func NewBigtableGcPolicy_Override(b BigtableGcPolicy, scope constructs.Construct, id *string, config *BigtableGcPolicyConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy google_bigtable_gc_policy} Resource.
Types ¶
type BigtableGcPolicy ¶
type BigtableGcPolicy interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
ColumnFamily() *string
SetColumnFamily(val *string)
ColumnFamilyInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DeletionPolicy() *string
SetDeletionPolicy(val *string)
DeletionPolicyInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GcRules() *string
SetGcRules(val *string)
GcRulesInput() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceName() *string
SetInstanceName(val *string)
InstanceNameInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaxAge() BigtableGcPolicyMaxAgeOutputReference
MaxAgeInput() *BigtableGcPolicyMaxAge
MaxVersion() BigtableGcPolicyMaxVersionList
MaxVersionInput() interface{}
Mode() *string
SetMode(val *string)
ModeInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Table() *string
SetTable(val *string)
TableInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() BigtableGcPolicyTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutMaxAge(value *BigtableGcPolicyMaxAge)
PutMaxVersion(value interface{})
PutTimeouts(value *BigtableGcPolicyTimeouts)
ResetDeletionPolicy()
ResetGcRules()
ResetId()
ResetMaxAge()
ResetMaxVersion()
ResetMode()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy google_bigtable_gc_policy}.
func NewBigtableGcPolicy ¶
func NewBigtableGcPolicy(scope constructs.Construct, id *string, config *BigtableGcPolicyConfig) BigtableGcPolicy
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy google_bigtable_gc_policy} Resource.
type BigtableGcPolicyConfig ¶
type BigtableGcPolicyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The name of the column family.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#column_family BigtableGcPolicy#column_family}
ColumnFamily *string `field:"required" json:"columnFamily" yaml:"columnFamily"`
// The name of the Bigtable instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#instance_name BigtableGcPolicy#instance_name}
InstanceName *string `field:"required" json:"instanceName" yaml:"instanceName"`
// The name of the table.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#table BigtableGcPolicy#table}
Table *string `field:"required" json:"table" yaml:"table"`
// The deletion policy for the GC policy.
//
// Setting ABANDON allows the resource
// to be abandoned rather than deleted. This is useful for GC policy as it cannot be deleted
// in a replicated instance. Possible values are: "ABANDON".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#deletion_policy BigtableGcPolicy#deletion_policy}
DeletionPolicy *string `field:"optional" json:"deletionPolicy" yaml:"deletionPolicy"`
// Serialized JSON string for garbage collection policy. Conflicts with "mode", "max_age" and "max_version".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#gc_rules BigtableGcPolicy#gc_rules}
GcRules *string `field:"optional" json:"gcRules" yaml:"gcRules"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#id BigtableGcPolicy#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// max_age block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#max_age BigtableGcPolicy#max_age}
MaxAge *BigtableGcPolicyMaxAge `field:"optional" json:"maxAge" yaml:"maxAge"`
// max_version block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#max_version BigtableGcPolicy#max_version}
MaxVersion interface{} `field:"optional" json:"maxVersion" yaml:"maxVersion"`
// NOTE: 'gc_rules' is more flexible, and should be preferred over this field for new resources.
//
// This field may be deprecated in the future. If multiple policies are set, you should choose between UNION OR INTERSECTION.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#mode BigtableGcPolicy#mode}
Mode *string `field:"optional" json:"mode" yaml:"mode"`
// The ID of the project in which the resource belongs.
//
// If it is not provided, the provider project is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#project BigtableGcPolicy#project}
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#timeouts BigtableGcPolicy#timeouts}
Timeouts *BigtableGcPolicyTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type BigtableGcPolicyMaxAge ¶
type BigtableGcPolicyMaxAge struct {
// Number of days before applying GC policy.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#days BigtableGcPolicy#days}
Days *float64 `field:"optional" json:"days" yaml:"days"`
// Duration before applying GC policy.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#duration BigtableGcPolicy#duration}
Duration *string `field:"optional" json:"duration" yaml:"duration"`
}
type BigtableGcPolicyMaxAgeOutputReference ¶
type BigtableGcPolicyMaxAgeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Days() *float64
SetDays(val *float64)
DaysInput() *float64
Duration() *string
SetDuration(val *string)
DurationInput() *string
// Experimental.
Fqn() *string
InternalValue() *BigtableGcPolicyMaxAge
SetInternalValue(val *BigtableGcPolicyMaxAge)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDays()
ResetDuration()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBigtableGcPolicyMaxAgeOutputReference ¶
func NewBigtableGcPolicyMaxAgeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BigtableGcPolicyMaxAgeOutputReference
type BigtableGcPolicyMaxVersion ¶
type BigtableGcPolicyMaxVersion struct {
// Number of version before applying the GC policy.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#number BigtableGcPolicy#number}
Number *float64 `field:"required" json:"number" yaml:"number"`
}
type BigtableGcPolicyMaxVersionList ¶
type BigtableGcPolicyMaxVersionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BigtableGcPolicyMaxVersionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBigtableGcPolicyMaxVersionList ¶
func NewBigtableGcPolicyMaxVersionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BigtableGcPolicyMaxVersionList
type BigtableGcPolicyMaxVersionOutputReference ¶
type BigtableGcPolicyMaxVersionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Number() *float64
SetNumber(val *float64)
NumberInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBigtableGcPolicyMaxVersionOutputReference ¶
func NewBigtableGcPolicyMaxVersionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BigtableGcPolicyMaxVersionOutputReference
type BigtableGcPolicyTimeouts ¶
type BigtableGcPolicyTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#create BigtableGcPolicy#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/bigtable_gc_policy#delete BigtableGcPolicy#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type BigtableGcPolicyTimeoutsOutputReference ¶
type BigtableGcPolicyTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBigtableGcPolicyTimeoutsOutputReference ¶
func NewBigtableGcPolicyTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BigtableGcPolicyTimeoutsOutputReference
Source Files
¶
- BigtableGcPolicy.go
- BigtableGcPolicyConfig.go
- BigtableGcPolicyMaxAge.go
- BigtableGcPolicyMaxAgeOutputReference.go
- BigtableGcPolicyMaxAgeOutputReference__checks.go
- BigtableGcPolicyMaxVersion.go
- BigtableGcPolicyMaxVersionList.go
- BigtableGcPolicyMaxVersionList__checks.go
- BigtableGcPolicyMaxVersionOutputReference.go
- BigtableGcPolicyMaxVersionOutputReference__checks.go
- BigtableGcPolicyTimeouts.go
- BigtableGcPolicyTimeoutsOutputReference.go
- BigtableGcPolicyTimeoutsOutputReference__checks.go
- BigtableGcPolicy__checks.go
- main.go