Documentation
¶
Index ¶
- func DataGoogleBillingAccount_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataGoogleBillingAccount_IsConstruct(x interface{}) *bool
- func DataGoogleBillingAccount_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleBillingAccount_IsTerraformElement(x interface{}) *bool
- func DataGoogleBillingAccount_TfResourceType() *string
- func NewDataGoogleBillingAccount_Override(d DataGoogleBillingAccount, scope constructs.Construct, id *string, ...)
- type DataGoogleBillingAccount
- type DataGoogleBillingAccountConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleBillingAccount_GenerateConfigForImport ¶
func DataGoogleBillingAccount_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataGoogleBillingAccount resource upon running "cdktf plan <stack-name>".
func DataGoogleBillingAccount_IsConstruct ¶
func DataGoogleBillingAccount_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleBillingAccount_IsTerraformDataSource ¶
func DataGoogleBillingAccount_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleBillingAccount_IsTerraformElement ¶
func DataGoogleBillingAccount_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleBillingAccount_TfResourceType ¶
func DataGoogleBillingAccount_TfResourceType() *string
func NewDataGoogleBillingAccount_Override ¶
func NewDataGoogleBillingAccount_Override(d DataGoogleBillingAccount, scope constructs.Construct, id *string, config *DataGoogleBillingAccountConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/data-sources/billing_account google_billing_account} Data Source.
Types ¶
type DataGoogleBillingAccount ¶
type DataGoogleBillingAccount interface {
cdktf.TerraformDataSource
BillingAccount() *string
SetBillingAccount(val *string)
BillingAccountInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LookupProjects() interface{}
SetLookupProjects(val interface{})
LookupProjectsInput() interface{}
Name() *string
// The tree node.
Node() constructs.Node
Open() interface{}
SetOpen(val interface{})
OpenInput() interface{}
ProjectIds() *[]*string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetBillingAccount()
ResetDisplayName()
ResetId()
ResetLookupProjects()
ResetOpen()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/data-sources/billing_account google_billing_account}.
func NewDataGoogleBillingAccount ¶
func NewDataGoogleBillingAccount(scope constructs.Construct, id *string, config *DataGoogleBillingAccountConfig) DataGoogleBillingAccount
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/data-sources/billing_account google_billing_account} Data Source.
type DataGoogleBillingAccountConfig ¶
type DataGoogleBillingAccountConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/data-sources/billing_account#billing_account DataGoogleBillingAccount#billing_account}.
BillingAccount *string `field:"optional" json:"billingAccount" yaml:"billingAccount"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/data-sources/billing_account#display_name DataGoogleBillingAccount#display_name}.
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/data-sources/billing_account#id DataGoogleBillingAccount#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/data-sources/billing_account#lookup_projects DataGoogleBillingAccount#lookup_projects}.
LookupProjects interface{} `field:"optional" json:"lookupProjects" yaml:"lookupProjects"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/data-sources/billing_account#open DataGoogleBillingAccount#open}.
Open interface{} `field:"optional" json:"open" yaml:"open"`
}