Documentation
¶
Index ¶
- func DialogflowEntityType_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DialogflowEntityType_IsConstruct(x interface{}) *bool
- func DialogflowEntityType_IsTerraformElement(x interface{}) *bool
- func DialogflowEntityType_IsTerraformResource(x interface{}) *bool
- func DialogflowEntityType_TfResourceType() *string
- func NewDialogflowEntityTypeEntitiesList_Override(d DialogflowEntityTypeEntitiesList, ...)
- func NewDialogflowEntityTypeEntitiesOutputReference_Override(d DialogflowEntityTypeEntitiesOutputReference, ...)
- func NewDialogflowEntityTypeTimeoutsOutputReference_Override(d DialogflowEntityTypeTimeoutsOutputReference, ...)
- func NewDialogflowEntityType_Override(d DialogflowEntityType, scope constructs.Construct, id *string, ...)
- type DialogflowEntityType
- type DialogflowEntityTypeConfig
- type DialogflowEntityTypeEntities
- type DialogflowEntityTypeEntitiesList
- type DialogflowEntityTypeEntitiesOutputReference
- type DialogflowEntityTypeTimeouts
- type DialogflowEntityTypeTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DialogflowEntityType_GenerateConfigForImport ¶
func DialogflowEntityType_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DialogflowEntityType resource upon running "cdktf plan <stack-name>".
func DialogflowEntityType_IsConstruct ¶
func DialogflowEntityType_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DialogflowEntityType_IsTerraformElement ¶
func DialogflowEntityType_IsTerraformElement(x interface{}) *bool
Experimental.
func DialogflowEntityType_IsTerraformResource ¶
func DialogflowEntityType_IsTerraformResource(x interface{}) *bool
Experimental.
func DialogflowEntityType_TfResourceType ¶
func DialogflowEntityType_TfResourceType() *string
func NewDialogflowEntityTypeEntitiesList_Override ¶
func NewDialogflowEntityTypeEntitiesList_Override(d DialogflowEntityTypeEntitiesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDialogflowEntityTypeEntitiesOutputReference_Override ¶
func NewDialogflowEntityTypeEntitiesOutputReference_Override(d DialogflowEntityTypeEntitiesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDialogflowEntityTypeTimeoutsOutputReference_Override ¶
func NewDialogflowEntityTypeTimeoutsOutputReference_Override(d DialogflowEntityTypeTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDialogflowEntityType_Override ¶
func NewDialogflowEntityType_Override(d DialogflowEntityType, scope constructs.Construct, id *string, config *DialogflowEntityTypeConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type google_dialogflow_entity_type} Resource.
Types ¶
type DialogflowEntityType ¶
type DialogflowEntityType interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
EnableFuzzyExtraction() interface{}
SetEnableFuzzyExtraction(val interface{})
EnableFuzzyExtractionInput() interface{}
Entities() DialogflowEntityTypeEntitiesList
EntitiesInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Kind() *string
SetKind(val *string)
KindInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DialogflowEntityTypeTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEntities(value interface{})
PutTimeouts(value *DialogflowEntityTypeTimeouts)
ResetEnableFuzzyExtraction()
ResetEntities()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type google_dialogflow_entity_type}.
func NewDialogflowEntityType ¶
func NewDialogflowEntityType(scope constructs.Construct, id *string, config *DialogflowEntityTypeConfig) DialogflowEntityType
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type google_dialogflow_entity_type} Resource.
type DialogflowEntityTypeConfig ¶
type DialogflowEntityTypeConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The name of this entity type to be displayed on the console.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type#display_name DialogflowEntityType#display_name}
DisplayName *string `field:"required" json:"displayName" yaml:"displayName"`
// Indicates the kind of entity type.
//
// * KIND_MAP: Map entity types allow mapping of a group of synonyms to a reference value.
// * KIND_LIST: List entity types contain a set of entries that do not map to reference values. However, list entity
// types can contain references to other entity types (with or without aliases).
// * KIND_REGEXP: Regexp entity types allow to specify regular expressions in entries values. Possible values: ["KIND_MAP", "KIND_LIST", "KIND_REGEXP"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type#kind DialogflowEntityType#kind}
Kind *string `field:"required" json:"kind" yaml:"kind"`
// Enables fuzzy entity extraction during classification.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type#enable_fuzzy_extraction DialogflowEntityType#enable_fuzzy_extraction}
EnableFuzzyExtraction interface{} `field:"optional" json:"enableFuzzyExtraction" yaml:"enableFuzzyExtraction"`
// entities block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type#entities DialogflowEntityType#entities}
Entities interface{} `field:"optional" json:"entities" yaml:"entities"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type#id DialogflowEntityType#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type#project DialogflowEntityType#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type#timeouts DialogflowEntityType#timeouts}
Timeouts *DialogflowEntityTypeTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DialogflowEntityTypeEntities ¶
type DialogflowEntityTypeEntities struct {
// A collection of value synonyms.
//
// For example, if the entity type is vegetable, and value is scallions, a synonym
// could be green onions.
// For KIND_LIST entity types:
// * This collection must contain exactly one synonym equal to value.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type#synonyms DialogflowEntityType#synonyms}
Synonyms *[]*string `field:"required" json:"synonyms" yaml:"synonyms"`
// The primary value associated with this entity entry.
//
// For example, if the entity type is vegetable, the value
// could be scallions.
// For KIND_MAP entity types:
// * A reference value to be used in place of synonyms.
// For KIND_LIST entity types:
// * A string that can contain references to other entity types (with or without aliases).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type#value DialogflowEntityType#value}
Value *string `field:"required" json:"value" yaml:"value"`
}
type DialogflowEntityTypeEntitiesList ¶
type DialogflowEntityTypeEntitiesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DialogflowEntityTypeEntitiesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDialogflowEntityTypeEntitiesList ¶
func NewDialogflowEntityTypeEntitiesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DialogflowEntityTypeEntitiesList
type DialogflowEntityTypeEntitiesOutputReference ¶
type DialogflowEntityTypeEntitiesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Synonyms() *[]*string
SetSynonyms(val *[]*string)
SynonymsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDialogflowEntityTypeEntitiesOutputReference ¶
func NewDialogflowEntityTypeEntitiesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DialogflowEntityTypeEntitiesOutputReference
type DialogflowEntityTypeTimeouts ¶
type DialogflowEntityTypeTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type#create DialogflowEntityType#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type#delete DialogflowEntityType#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/dialogflow_entity_type#update DialogflowEntityType#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type DialogflowEntityTypeTimeoutsOutputReference ¶
type DialogflowEntityTypeTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDialogflowEntityTypeTimeoutsOutputReference ¶
func NewDialogflowEntityTypeTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DialogflowEntityTypeTimeoutsOutputReference
Source Files
¶
- DialogflowEntityType.go
- DialogflowEntityTypeConfig.go
- DialogflowEntityTypeEntities.go
- DialogflowEntityTypeEntitiesList.go
- DialogflowEntityTypeEntitiesList__checks.go
- DialogflowEntityTypeEntitiesOutputReference.go
- DialogflowEntityTypeEntitiesOutputReference__checks.go
- DialogflowEntityTypeTimeouts.go
- DialogflowEntityTypeTimeoutsOutputReference.go
- DialogflowEntityTypeTimeoutsOutputReference__checks.go
- DialogflowEntityType__checks.go
- main.go