Documentation
¶
Index ¶
- func FirestoreField_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func FirestoreField_IsConstruct(x interface{}) *bool
- func FirestoreField_IsTerraformElement(x interface{}) *bool
- func FirestoreField_IsTerraformResource(x interface{}) *bool
- func FirestoreField_TfResourceType() *string
- func NewFirestoreFieldIndexConfigIndexesList_Override(f FirestoreFieldIndexConfigIndexesList, ...)
- func NewFirestoreFieldIndexConfigIndexesOutputReference_Override(f FirestoreFieldIndexConfigIndexesOutputReference, ...)
- func NewFirestoreFieldIndexConfigOutputReference_Override(f FirestoreFieldIndexConfigOutputReference, ...)
- func NewFirestoreFieldTimeoutsOutputReference_Override(f FirestoreFieldTimeoutsOutputReference, ...)
- func NewFirestoreFieldTtlConfigOutputReference_Override(f FirestoreFieldTtlConfigOutputReference, ...)
- func NewFirestoreField_Override(f FirestoreField, scope constructs.Construct, id *string, ...)
- type FirestoreField
- type FirestoreFieldConfig
- type FirestoreFieldIndexConfig
- type FirestoreFieldIndexConfigIndexes
- type FirestoreFieldIndexConfigIndexesList
- type FirestoreFieldIndexConfigIndexesOutputReference
- type FirestoreFieldIndexConfigOutputReference
- type FirestoreFieldTimeouts
- type FirestoreFieldTimeoutsOutputReference
- type FirestoreFieldTtlConfig
- type FirestoreFieldTtlConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FirestoreField_GenerateConfigForImport ¶
func FirestoreField_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a FirestoreField resource upon running "cdktf plan <stack-name>".
func FirestoreField_IsConstruct ¶
func FirestoreField_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func FirestoreField_IsTerraformElement ¶
func FirestoreField_IsTerraformElement(x interface{}) *bool
Experimental.
func FirestoreField_IsTerraformResource ¶
func FirestoreField_IsTerraformResource(x interface{}) *bool
Experimental.
func FirestoreField_TfResourceType ¶
func FirestoreField_TfResourceType() *string
func NewFirestoreFieldIndexConfigIndexesList_Override ¶
func NewFirestoreFieldIndexConfigIndexesList_Override(f FirestoreFieldIndexConfigIndexesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewFirestoreFieldIndexConfigIndexesOutputReference_Override ¶
func NewFirestoreFieldIndexConfigIndexesOutputReference_Override(f FirestoreFieldIndexConfigIndexesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewFirestoreFieldIndexConfigOutputReference_Override ¶
func NewFirestoreFieldIndexConfigOutputReference_Override(f FirestoreFieldIndexConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFirestoreFieldTimeoutsOutputReference_Override ¶
func NewFirestoreFieldTimeoutsOutputReference_Override(f FirestoreFieldTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFirestoreFieldTtlConfigOutputReference_Override ¶
func NewFirestoreFieldTtlConfigOutputReference_Override(f FirestoreFieldTtlConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFirestoreField_Override ¶
func NewFirestoreField_Override(f FirestoreField, scope constructs.Construct, id *string, config *FirestoreFieldConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field google_firestore_field} Resource.
Types ¶
type FirestoreField ¶
type FirestoreField interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
Collection() *string
SetCollection(val *string)
CollectionInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
Database() *string
SetDatabase(val *string)
DatabaseInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Field() *string
SetField(val *string)
FieldInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IndexConfig() FirestoreFieldIndexConfigOutputReference
IndexConfigInput() *FirestoreFieldIndexConfig
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() FirestoreFieldTimeoutsOutputReference
TimeoutsInput() interface{}
TtlConfig() FirestoreFieldTtlConfigOutputReference
TtlConfigInput() *FirestoreFieldTtlConfig
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutIndexConfig(value *FirestoreFieldIndexConfig)
PutTimeouts(value *FirestoreFieldTimeouts)
PutTtlConfig(value *FirestoreFieldTtlConfig)
ResetDatabase()
ResetId()
ResetIndexConfig()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
ResetTtlConfig()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field google_firestore_field}.
func NewFirestoreField ¶
func NewFirestoreField(scope constructs.Construct, id *string, config *FirestoreFieldConfig) FirestoreField
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field google_firestore_field} Resource.
type FirestoreFieldConfig ¶
type FirestoreFieldConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The id of the collection group to configure.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#collection FirestoreField#collection}
Collection *string `field:"required" json:"collection" yaml:"collection"`
// The id of the field to configure.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#field FirestoreField#field}
Field *string `field:"required" json:"field" yaml:"field"`
// The Firestore database id. Defaults to '"(default)"'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#database FirestoreField#database}
Database *string `field:"optional" json:"database" yaml:"database"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#id FirestoreField#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// index_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#index_config FirestoreField#index_config}
IndexConfig *FirestoreFieldIndexConfig `field:"optional" json:"indexConfig" yaml:"indexConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#project FirestoreField#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#timeouts FirestoreField#timeouts}
Timeouts *FirestoreFieldTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// ttl_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#ttl_config FirestoreField#ttl_config}
TtlConfig *FirestoreFieldTtlConfig `field:"optional" json:"ttlConfig" yaml:"ttlConfig"`
}
type FirestoreFieldIndexConfig ¶
type FirestoreFieldIndexConfig struct {
// indexes block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#indexes FirestoreField#indexes}
Indexes interface{} `field:"optional" json:"indexes" yaml:"indexes"`
}
type FirestoreFieldIndexConfigIndexes ¶
type FirestoreFieldIndexConfigIndexes struct {
// Indicates that this field supports operations on arrayValues. Only one of 'order' and 'arrayConfig' can be specified. Possible values: ["CONTAINS"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#array_config FirestoreField#array_config}
ArrayConfig *string `field:"optional" json:"arrayConfig" yaml:"arrayConfig"`
// Indicates that this field supports ordering by the specified order or comparing using =, <, <=, >, >=, !=. Only one of 'order' and 'arrayConfig' can be specified. Possible values: ["ASCENDING", "DESCENDING"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#order FirestoreField#order}
Order *string `field:"optional" json:"order" yaml:"order"`
// The scope at which a query is run.
//
// Collection scoped queries require you specify
// the collection at query time. Collection group scope allows queries across all
// collections with the same id. Default value: "COLLECTION" Possible values: ["COLLECTION", "COLLECTION_GROUP"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#query_scope FirestoreField#query_scope}
QueryScope *string `field:"optional" json:"queryScope" yaml:"queryScope"`
}
type FirestoreFieldIndexConfigIndexesList ¶
type FirestoreFieldIndexConfigIndexesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) FirestoreFieldIndexConfigIndexesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFirestoreFieldIndexConfigIndexesList ¶
func NewFirestoreFieldIndexConfigIndexesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) FirestoreFieldIndexConfigIndexesList
type FirestoreFieldIndexConfigIndexesOutputReference ¶
type FirestoreFieldIndexConfigIndexesOutputReference interface {
cdktf.ComplexObject
ArrayConfig() *string
SetArrayConfig(val *string)
ArrayConfigInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Order() *string
SetOrder(val *string)
OrderInput() *string
QueryScope() *string
SetQueryScope(val *string)
QueryScopeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetArrayConfig()
ResetOrder()
ResetQueryScope()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFirestoreFieldIndexConfigIndexesOutputReference ¶
func NewFirestoreFieldIndexConfigIndexesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) FirestoreFieldIndexConfigIndexesOutputReference
type FirestoreFieldIndexConfigOutputReference ¶
type FirestoreFieldIndexConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Indexes() FirestoreFieldIndexConfigIndexesList
IndexesInput() interface{}
InternalValue() *FirestoreFieldIndexConfig
SetInternalValue(val *FirestoreFieldIndexConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutIndexes(value interface{})
ResetIndexes()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFirestoreFieldIndexConfigOutputReference ¶
func NewFirestoreFieldIndexConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FirestoreFieldIndexConfigOutputReference
type FirestoreFieldTimeouts ¶
type FirestoreFieldTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#create FirestoreField#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#delete FirestoreField#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/firestore_field#update FirestoreField#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type FirestoreFieldTimeoutsOutputReference ¶
type FirestoreFieldTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFirestoreFieldTimeoutsOutputReference ¶
func NewFirestoreFieldTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FirestoreFieldTimeoutsOutputReference
type FirestoreFieldTtlConfig ¶
type FirestoreFieldTtlConfig struct {
}
type FirestoreFieldTtlConfigOutputReference ¶
type FirestoreFieldTtlConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *FirestoreFieldTtlConfig
SetInternalValue(val *FirestoreFieldTtlConfig)
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFirestoreFieldTtlConfigOutputReference ¶
func NewFirestoreFieldTtlConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FirestoreFieldTtlConfigOutputReference
Source Files
¶
- FirestoreField.go
- FirestoreFieldConfig.go
- FirestoreFieldIndexConfig.go
- FirestoreFieldIndexConfigIndexes.go
- FirestoreFieldIndexConfigIndexesList.go
- FirestoreFieldIndexConfigIndexesList__checks.go
- FirestoreFieldIndexConfigIndexesOutputReference.go
- FirestoreFieldIndexConfigIndexesOutputReference__checks.go
- FirestoreFieldIndexConfigOutputReference.go
- FirestoreFieldIndexConfigOutputReference__checks.go
- FirestoreFieldTimeouts.go
- FirestoreFieldTimeoutsOutputReference.go
- FirestoreFieldTimeoutsOutputReference__checks.go
- FirestoreFieldTtlConfig.go
- FirestoreFieldTtlConfigOutputReference.go
- FirestoreFieldTtlConfigOutputReference__checks.go
- FirestoreField__checks.go
- main.go