Documentation
¶
Index ¶
- func NewNotebooksEnvironmentContainerImageOutputReference_Override(n NotebooksEnvironmentContainerImageOutputReference, ...)
- func NewNotebooksEnvironmentTimeoutsOutputReference_Override(n NotebooksEnvironmentTimeoutsOutputReference, ...)
- func NewNotebooksEnvironmentVmImageOutputReference_Override(n NotebooksEnvironmentVmImageOutputReference, ...)
- func NewNotebooksEnvironment_Override(n NotebooksEnvironment, scope constructs.Construct, id *string, ...)
- func NotebooksEnvironment_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func NotebooksEnvironment_IsConstruct(x interface{}) *bool
- func NotebooksEnvironment_IsTerraformElement(x interface{}) *bool
- func NotebooksEnvironment_IsTerraformResource(x interface{}) *bool
- func NotebooksEnvironment_TfResourceType() *string
- type NotebooksEnvironment
- type NotebooksEnvironmentConfig
- type NotebooksEnvironmentContainerImage
- type NotebooksEnvironmentContainerImageOutputReference
- type NotebooksEnvironmentTimeouts
- type NotebooksEnvironmentTimeoutsOutputReference
- type NotebooksEnvironmentVmImage
- type NotebooksEnvironmentVmImageOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewNotebooksEnvironmentContainerImageOutputReference_Override ¶
func NewNotebooksEnvironmentContainerImageOutputReference_Override(n NotebooksEnvironmentContainerImageOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewNotebooksEnvironmentTimeoutsOutputReference_Override ¶
func NewNotebooksEnvironmentTimeoutsOutputReference_Override(n NotebooksEnvironmentTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewNotebooksEnvironmentVmImageOutputReference_Override ¶
func NewNotebooksEnvironmentVmImageOutputReference_Override(n NotebooksEnvironmentVmImageOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewNotebooksEnvironment_Override ¶
func NewNotebooksEnvironment_Override(n NotebooksEnvironment, scope constructs.Construct, id *string, config *NotebooksEnvironmentConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment google_notebooks_environment} Resource.
func NotebooksEnvironment_GenerateConfigForImport ¶
func NotebooksEnvironment_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a NotebooksEnvironment resource upon running "cdktf plan <stack-name>".
func NotebooksEnvironment_IsConstruct ¶
func NotebooksEnvironment_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func NotebooksEnvironment_IsTerraformElement ¶
func NotebooksEnvironment_IsTerraformElement(x interface{}) *bool
Experimental.
func NotebooksEnvironment_IsTerraformResource ¶
func NotebooksEnvironment_IsTerraformResource(x interface{}) *bool
Experimental.
func NotebooksEnvironment_TfResourceType ¶
func NotebooksEnvironment_TfResourceType() *string
Types ¶
type NotebooksEnvironment ¶
type NotebooksEnvironment interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ContainerImage() NotebooksEnvironmentContainerImageOutputReference
ContainerImageInput() *NotebooksEnvironmentContainerImage
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
PostStartupScript() *string
SetPostStartupScript(val *string)
PostStartupScriptInput() *string
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() NotebooksEnvironmentTimeoutsOutputReference
TimeoutsInput() interface{}
VmImage() NotebooksEnvironmentVmImageOutputReference
VmImageInput() *NotebooksEnvironmentVmImage
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutContainerImage(value *NotebooksEnvironmentContainerImage)
PutTimeouts(value *NotebooksEnvironmentTimeouts)
PutVmImage(value *NotebooksEnvironmentVmImage)
ResetContainerImage()
ResetDescription()
ResetDisplayName()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPostStartupScript()
ResetProject()
ResetTimeouts()
ResetVmImage()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment google_notebooks_environment}.
func NewNotebooksEnvironment ¶
func NewNotebooksEnvironment(scope constructs.Construct, id *string, config *NotebooksEnvironmentConfig) NotebooksEnvironment
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment google_notebooks_environment} Resource.
type NotebooksEnvironmentConfig ¶
type NotebooksEnvironmentConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// A reference to the zone where the machine resides.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#location NotebooksEnvironment#location}
Location *string `field:"required" json:"location" yaml:"location"`
// The name specified for the Environment instance. Format: projects/{project_id}/locations/{location}/environments/{environmentId}.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#name NotebooksEnvironment#name}
Name *string `field:"required" json:"name" yaml:"name"`
// container_image block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#container_image NotebooksEnvironment#container_image}
ContainerImage *NotebooksEnvironmentContainerImage `field:"optional" json:"containerImage" yaml:"containerImage"`
// A brief description of this environment.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#description NotebooksEnvironment#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Display name of this environment for the UI.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#display_name NotebooksEnvironment#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#id NotebooksEnvironment#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Path to a Bash script that automatically runs after a notebook instance fully boots up.
//
// The path must be a URL or Cloud Storage path. Example: "gs://path-to-file/file-name"
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#post_startup_script NotebooksEnvironment#post_startup_script}
PostStartupScript *string `field:"optional" json:"postStartupScript" yaml:"postStartupScript"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#project NotebooksEnvironment#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#timeouts NotebooksEnvironment#timeouts}
Timeouts *NotebooksEnvironmentTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// vm_image block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#vm_image NotebooksEnvironment#vm_image}
VmImage *NotebooksEnvironmentVmImage `field:"optional" json:"vmImage" yaml:"vmImage"`
}
type NotebooksEnvironmentContainerImage ¶
type NotebooksEnvironmentContainerImage struct {
// The path to the container image repository. For example: gcr.io/{project_id}/{imageName}.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#repository NotebooksEnvironment#repository}
Repository *string `field:"required" json:"repository" yaml:"repository"`
// The tag of the container image. If not specified, this defaults to the latest tag.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#tag NotebooksEnvironment#tag}
Tag *string `field:"optional" json:"tag" yaml:"tag"`
}
type NotebooksEnvironmentContainerImageOutputReference ¶
type NotebooksEnvironmentContainerImageOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *NotebooksEnvironmentContainerImage
SetInternalValue(val *NotebooksEnvironmentContainerImage)
Repository() *string
SetRepository(val *string)
RepositoryInput() *string
Tag() *string
SetTag(val *string)
TagInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetTag()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNotebooksEnvironmentContainerImageOutputReference ¶
func NewNotebooksEnvironmentContainerImageOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) NotebooksEnvironmentContainerImageOutputReference
type NotebooksEnvironmentTimeouts ¶
type NotebooksEnvironmentTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#create NotebooksEnvironment#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#delete NotebooksEnvironment#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#update NotebooksEnvironment#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type NotebooksEnvironmentTimeoutsOutputReference ¶
type NotebooksEnvironmentTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNotebooksEnvironmentTimeoutsOutputReference ¶
func NewNotebooksEnvironmentTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) NotebooksEnvironmentTimeoutsOutputReference
type NotebooksEnvironmentVmImage ¶
type NotebooksEnvironmentVmImage struct {
// The name of the Google Cloud project that this VM image belongs to. Format: projects/{project_id}.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#project NotebooksEnvironment#project}
Project *string `field:"required" json:"project" yaml:"project"`
// Use this VM image family to find the image; the newest image in this family will be used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#image_family NotebooksEnvironment#image_family}
ImageFamily *string `field:"optional" json:"imageFamily" yaml:"imageFamily"`
// Use VM image name to find the image.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/notebooks_environment#image_name NotebooksEnvironment#image_name}
ImageName *string `field:"optional" json:"imageName" yaml:"imageName"`
}
type NotebooksEnvironmentVmImageOutputReference ¶
type NotebooksEnvironmentVmImageOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
ImageFamily() *string
SetImageFamily(val *string)
ImageFamilyInput() *string
ImageName() *string
SetImageName(val *string)
ImageNameInput() *string
InternalValue() *NotebooksEnvironmentVmImage
SetInternalValue(val *NotebooksEnvironmentVmImage)
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetImageFamily()
ResetImageName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNotebooksEnvironmentVmImageOutputReference ¶
func NewNotebooksEnvironmentVmImageOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) NotebooksEnvironmentVmImageOutputReference
Source Files
¶
- NotebooksEnvironment.go
- NotebooksEnvironmentConfig.go
- NotebooksEnvironmentContainerImage.go
- NotebooksEnvironmentContainerImageOutputReference.go
- NotebooksEnvironmentContainerImageOutputReference__checks.go
- NotebooksEnvironmentTimeouts.go
- NotebooksEnvironmentTimeoutsOutputReference.go
- NotebooksEnvironmentTimeoutsOutputReference__checks.go
- NotebooksEnvironmentVmImage.go
- NotebooksEnvironmentVmImageOutputReference.go
- NotebooksEnvironmentVmImageOutputReference__checks.go
- NotebooksEnvironment__checks.go
- main.go