Documentation
¶
Index ¶
- func NewSourcerepoRepositoryPubsubConfigsList_Override(s SourcerepoRepositoryPubsubConfigsList, ...)
- func NewSourcerepoRepositoryPubsubConfigsOutputReference_Override(s SourcerepoRepositoryPubsubConfigsOutputReference, ...)
- func NewSourcerepoRepositoryTimeoutsOutputReference_Override(s SourcerepoRepositoryTimeoutsOutputReference, ...)
- func NewSourcerepoRepository_Override(s SourcerepoRepository, scope constructs.Construct, id *string, ...)
- func SourcerepoRepository_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func SourcerepoRepository_IsConstruct(x interface{}) *bool
- func SourcerepoRepository_IsTerraformElement(x interface{}) *bool
- func SourcerepoRepository_IsTerraformResource(x interface{}) *bool
- func SourcerepoRepository_TfResourceType() *string
- type SourcerepoRepository
- type SourcerepoRepositoryConfig
- type SourcerepoRepositoryPubsubConfigs
- type SourcerepoRepositoryPubsubConfigsList
- type SourcerepoRepositoryPubsubConfigsOutputReference
- type SourcerepoRepositoryTimeouts
- type SourcerepoRepositoryTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSourcerepoRepositoryPubsubConfigsList_Override ¶
func NewSourcerepoRepositoryPubsubConfigsList_Override(s SourcerepoRepositoryPubsubConfigsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSourcerepoRepositoryPubsubConfigsOutputReference_Override ¶
func NewSourcerepoRepositoryPubsubConfigsOutputReference_Override(s SourcerepoRepositoryPubsubConfigsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSourcerepoRepositoryTimeoutsOutputReference_Override ¶
func NewSourcerepoRepositoryTimeoutsOutputReference_Override(s SourcerepoRepositoryTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSourcerepoRepository_Override ¶
func NewSourcerepoRepository_Override(s SourcerepoRepository, scope constructs.Construct, id *string, config *SourcerepoRepositoryConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/sourcerepo_repository google_sourcerepo_repository} Resource.
func SourcerepoRepository_GenerateConfigForImport ¶
func SourcerepoRepository_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a SourcerepoRepository resource upon running "cdktf plan <stack-name>".
func SourcerepoRepository_IsConstruct ¶
func SourcerepoRepository_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SourcerepoRepository_IsTerraformElement ¶
func SourcerepoRepository_IsTerraformElement(x interface{}) *bool
Experimental.
func SourcerepoRepository_IsTerraformResource ¶
func SourcerepoRepository_IsTerraformResource(x interface{}) *bool
Experimental.
func SourcerepoRepository_TfResourceType ¶
func SourcerepoRepository_TfResourceType() *string
Types ¶
type SourcerepoRepository ¶
type SourcerepoRepository interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
PubsubConfigs() SourcerepoRepositoryPubsubConfigsList
PubsubConfigsInput() interface{}
// Experimental.
RawOverrides() interface{}
Size() *float64
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() SourcerepoRepositoryTimeoutsOutputReference
TimeoutsInput() interface{}
Url() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutPubsubConfigs(value interface{})
PutTimeouts(value *SourcerepoRepositoryTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetPubsubConfigs()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/sourcerepo_repository google_sourcerepo_repository}.
func NewSourcerepoRepository ¶
func NewSourcerepoRepository(scope constructs.Construct, id *string, config *SourcerepoRepositoryConfig) SourcerepoRepository
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/sourcerepo_repository google_sourcerepo_repository} Resource.
type SourcerepoRepositoryConfig ¶
type SourcerepoRepositoryConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Resource name of the repository, of the form '{{repo}}'. The repo name may contain slashes. eg, 'name/with/slash'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/sourcerepo_repository#name SourcerepoRepository#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/sourcerepo_repository#id SourcerepoRepository#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/sourcerepo_repository#project SourcerepoRepository#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// pubsub_configs block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/sourcerepo_repository#pubsub_configs SourcerepoRepository#pubsub_configs}
PubsubConfigs interface{} `field:"optional" json:"pubsubConfigs" yaml:"pubsubConfigs"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/sourcerepo_repository#timeouts SourcerepoRepository#timeouts}
Timeouts *SourcerepoRepositoryTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type SourcerepoRepositoryPubsubConfigs ¶
type SourcerepoRepositoryPubsubConfigs struct {
// The format of the Cloud Pub/Sub messages.
//
// - PROTOBUF: The message payload is a serialized protocol buffer of SourceRepoEvent.
// - JSON: The message payload is a JSON string of SourceRepoEvent. Possible values: ["PROTOBUF", "JSON"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/sourcerepo_repository#message_format SourcerepoRepository#message_format}
MessageFormat *string `field:"required" json:"messageFormat" yaml:"messageFormat"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/sourcerepo_repository#topic SourcerepoRepository#topic}.
Topic *string `field:"required" json:"topic" yaml:"topic"`
// Email address of the service account used for publishing Cloud Pub/Sub messages.
//
// This service account needs to be in the same project as the PubsubConfig. When added,
// the caller needs to have iam.serviceAccounts.actAs permission on this service account.
// If unspecified, it defaults to the compute engine default service account.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/sourcerepo_repository#service_account_email SourcerepoRepository#service_account_email}
ServiceAccountEmail *string `field:"optional" json:"serviceAccountEmail" yaml:"serviceAccountEmail"`
}
type SourcerepoRepositoryPubsubConfigsList ¶
type SourcerepoRepositoryPubsubConfigsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SourcerepoRepositoryPubsubConfigsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSourcerepoRepositoryPubsubConfigsList ¶
func NewSourcerepoRepositoryPubsubConfigsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SourcerepoRepositoryPubsubConfigsList
type SourcerepoRepositoryPubsubConfigsOutputReference ¶
type SourcerepoRepositoryPubsubConfigsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
MessageFormat() *string
SetMessageFormat(val *string)
MessageFormatInput() *string
ServiceAccountEmail() *string
SetServiceAccountEmail(val *string)
ServiceAccountEmailInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Topic() *string
SetTopic(val *string)
TopicInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetServiceAccountEmail()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSourcerepoRepositoryPubsubConfigsOutputReference ¶
func NewSourcerepoRepositoryPubsubConfigsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SourcerepoRepositoryPubsubConfigsOutputReference
type SourcerepoRepositoryTimeouts ¶
type SourcerepoRepositoryTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/sourcerepo_repository#create SourcerepoRepository#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/sourcerepo_repository#delete SourcerepoRepository#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.7.0/docs/resources/sourcerepo_repository#update SourcerepoRepository#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type SourcerepoRepositoryTimeoutsOutputReference ¶
type SourcerepoRepositoryTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSourcerepoRepositoryTimeoutsOutputReference ¶
func NewSourcerepoRepositoryTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SourcerepoRepositoryTimeoutsOutputReference
Source Files
¶
- SourcerepoRepository.go
- SourcerepoRepositoryConfig.go
- SourcerepoRepositoryPubsubConfigs.go
- SourcerepoRepositoryPubsubConfigsList.go
- SourcerepoRepositoryPubsubConfigsList__checks.go
- SourcerepoRepositoryPubsubConfigsOutputReference.go
- SourcerepoRepositoryPubsubConfigsOutputReference__checks.go
- SourcerepoRepositoryTimeouts.go
- SourcerepoRepositoryTimeoutsOutputReference.go
- SourcerepoRepositoryTimeoutsOutputReference__checks.go
- SourcerepoRepository__checks.go
- main.go