Documentation
¶
Index ¶
- func AccessContextManagerAccessLevelCondition_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func AccessContextManagerAccessLevelCondition_IsConstruct(x interface{}) *bool
- func AccessContextManagerAccessLevelCondition_IsTerraformElement(x interface{}) *bool
- func AccessContextManagerAccessLevelCondition_IsTerraformResource(x interface{}) *bool
- func AccessContextManagerAccessLevelCondition_TfResourceType() *string
- func NewAccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsList_Override(a AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsList, ...)
- func NewAccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsOutputReference_Override(...)
- func NewAccessContextManagerAccessLevelConditionDevicePolicyOutputReference_Override(a AccessContextManagerAccessLevelConditionDevicePolicyOutputReference, ...)
- func NewAccessContextManagerAccessLevelConditionTimeoutsOutputReference_Override(a AccessContextManagerAccessLevelConditionTimeoutsOutputReference, ...)
- func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesList_Override(a AccessContextManagerAccessLevelConditionVpcNetworkSourcesList, ...)
- func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesOutputReference_Override(a AccessContextManagerAccessLevelConditionVpcNetworkSourcesOutputReference, ...)
- func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetworkOutputReference_Override(...)
- func NewAccessContextManagerAccessLevelCondition_Override(a AccessContextManagerAccessLevelCondition, scope constructs.Construct, ...)
- type AccessContextManagerAccessLevelCondition
- type AccessContextManagerAccessLevelConditionConfig
- type AccessContextManagerAccessLevelConditionDevicePolicy
- type AccessContextManagerAccessLevelConditionDevicePolicyOsConstraints
- type AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsList
- type AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsOutputReference
- type AccessContextManagerAccessLevelConditionDevicePolicyOutputReference
- type AccessContextManagerAccessLevelConditionTimeouts
- type AccessContextManagerAccessLevelConditionTimeoutsOutputReference
- type AccessContextManagerAccessLevelConditionVpcNetworkSources
- type AccessContextManagerAccessLevelConditionVpcNetworkSourcesList
- type AccessContextManagerAccessLevelConditionVpcNetworkSourcesOutputReference
- type AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetwork
- type AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetworkOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AccessContextManagerAccessLevelCondition_GenerateConfigForImport ¶
func AccessContextManagerAccessLevelCondition_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a AccessContextManagerAccessLevelCondition resource upon running "cdktf plan <stack-name>".
func AccessContextManagerAccessLevelCondition_IsConstruct ¶
func AccessContextManagerAccessLevelCondition_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AccessContextManagerAccessLevelCondition_IsTerraformElement ¶
func AccessContextManagerAccessLevelCondition_IsTerraformElement(x interface{}) *bool
Experimental.
func AccessContextManagerAccessLevelCondition_IsTerraformResource ¶
func AccessContextManagerAccessLevelCondition_IsTerraformResource(x interface{}) *bool
Experimental.
func AccessContextManagerAccessLevelCondition_TfResourceType ¶
func AccessContextManagerAccessLevelCondition_TfResourceType() *string
func NewAccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsList_Override ¶
func NewAccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsList_Override(a AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsOutputReference_Override ¶
func NewAccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsOutputReference_Override(a AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAccessContextManagerAccessLevelConditionDevicePolicyOutputReference_Override ¶
func NewAccessContextManagerAccessLevelConditionDevicePolicyOutputReference_Override(a AccessContextManagerAccessLevelConditionDevicePolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAccessContextManagerAccessLevelConditionTimeoutsOutputReference_Override ¶
func NewAccessContextManagerAccessLevelConditionTimeoutsOutputReference_Override(a AccessContextManagerAccessLevelConditionTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesList_Override ¶
func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesList_Override(a AccessContextManagerAccessLevelConditionVpcNetworkSourcesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesOutputReference_Override ¶
func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesOutputReference_Override(a AccessContextManagerAccessLevelConditionVpcNetworkSourcesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetworkOutputReference_Override ¶
func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetworkOutputReference_Override(a AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetworkOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAccessContextManagerAccessLevelCondition_Override ¶
func NewAccessContextManagerAccessLevelCondition_Override(a AccessContextManagerAccessLevelCondition, scope constructs.Construct, id *string, config *AccessContextManagerAccessLevelConditionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition google_access_context_manager_access_level_condition} Resource.
Types ¶
type AccessContextManagerAccessLevelCondition ¶
type AccessContextManagerAccessLevelCondition interface {
cdktf.TerraformResource
AccessLevel() *string
SetAccessLevel(val *string)
AccessLevelInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DevicePolicy() AccessContextManagerAccessLevelConditionDevicePolicyOutputReference
DevicePolicyInput() *AccessContextManagerAccessLevelConditionDevicePolicy
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IpSubnetworks() *[]*string
SetIpSubnetworks(val *[]*string)
IpSubnetworksInput() *[]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Members() *[]*string
SetMembers(val *[]*string)
MembersInput() *[]*string
Negate() interface{}
SetNegate(val interface{})
NegateInput() interface{}
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Regions() *[]*string
SetRegions(val *[]*string)
RegionsInput() *[]*string
RequiredAccessLevels() *[]*string
SetRequiredAccessLevels(val *[]*string)
RequiredAccessLevelsInput() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() AccessContextManagerAccessLevelConditionTimeoutsOutputReference
TimeoutsInput() interface{}
VpcNetworkSources() AccessContextManagerAccessLevelConditionVpcNetworkSourcesList
VpcNetworkSourcesInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDevicePolicy(value *AccessContextManagerAccessLevelConditionDevicePolicy)
PutTimeouts(value *AccessContextManagerAccessLevelConditionTimeouts)
PutVpcNetworkSources(value interface{})
ResetDevicePolicy()
ResetId()
ResetIpSubnetworks()
ResetMembers()
ResetNegate()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRegions()
ResetRequiredAccessLevels()
ResetTimeouts()
ResetVpcNetworkSources()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition google_access_context_manager_access_level_condition}.
func NewAccessContextManagerAccessLevelCondition ¶
func NewAccessContextManagerAccessLevelCondition(scope constructs.Construct, id *string, config *AccessContextManagerAccessLevelConditionConfig) AccessContextManagerAccessLevelCondition
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition google_access_context_manager_access_level_condition} Resource.
type AccessContextManagerAccessLevelConditionConfig ¶
type AccessContextManagerAccessLevelConditionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The name of the Access Level to add this condition to.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#access_level AccessContextManagerAccessLevelCondition#access_level}
AccessLevel *string `field:"required" json:"accessLevel" yaml:"accessLevel"`
// device_policy block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#device_policy AccessContextManagerAccessLevelCondition#device_policy}
DevicePolicy *AccessContextManagerAccessLevelConditionDevicePolicy `field:"optional" json:"devicePolicy" yaml:"devicePolicy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#id AccessContextManagerAccessLevelCondition#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// A list of CIDR block IP subnetwork specification.
//
// May be IPv4
// or IPv6.
// Note that for a CIDR IP address block, the specified IP address
// portion must be properly truncated (i.e. all the host bits must
// be zero) or the input is considered malformed. For example,
// "192.0.2.0/24" is accepted but "192.0.2.1/24" is not. Similarly,
// for IPv6, "2001:db8::/32" is accepted whereas "2001:db8::1/32"
// is not. The originating IP of a request must be in one of the
// listed subnets in order for this Condition to be true.
// If empty, all IP addresses are allowed.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#ip_subnetworks AccessContextManagerAccessLevelCondition#ip_subnetworks}
IpSubnetworks *[]*string `field:"optional" json:"ipSubnetworks" yaml:"ipSubnetworks"`
// An allowed list of members (users, service accounts). Using groups is not supported yet.
//
// The signed-in user originating the request must be a part of one
// of the provided members. If not specified, a request may come
// from any user (logged in/not logged in, not present in any
// groups, etc.).
// Formats: 'user:{emailid}', 'serviceAccount:{emailid}'
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#members AccessContextManagerAccessLevelCondition#members}
Members *[]*string `field:"optional" json:"members" yaml:"members"`
// Whether to negate the Condition.
//
// If true, the Condition becomes
// a NAND over its non-empty fields, each field must be false for
// the Condition overall to be satisfied. Defaults to false.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#negate AccessContextManagerAccessLevelCondition#negate}
Negate interface{} `field:"optional" json:"negate" yaml:"negate"`
// The request must originate from one of the provided countries/regions. Format: A valid ISO 3166-1 alpha-2 code.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#regions AccessContextManagerAccessLevelCondition#regions}
Regions *[]*string `field:"optional" json:"regions" yaml:"regions"`
// A list of other access levels defined in the same Policy, referenced by resource name.
//
// Referencing an AccessLevel which
// does not exist is an error. All access levels listed must be
// granted for the Condition to be true.
// Format: accessPolicies/{policy_id}/accessLevels/{short_name}
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#required_access_levels AccessContextManagerAccessLevelCondition#required_access_levels}
RequiredAccessLevels *[]*string `field:"optional" json:"requiredAccessLevels" yaml:"requiredAccessLevels"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#timeouts AccessContextManagerAccessLevelCondition#timeouts}
Timeouts *AccessContextManagerAccessLevelConditionTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// vpc_network_sources block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#vpc_network_sources AccessContextManagerAccessLevelCondition#vpc_network_sources}
VpcNetworkSources interface{} `field:"optional" json:"vpcNetworkSources" yaml:"vpcNetworkSources"`
}
type AccessContextManagerAccessLevelConditionDevicePolicy ¶
type AccessContextManagerAccessLevelConditionDevicePolicy struct {
// A list of allowed device management levels. An empty list allows all management levels. Possible values: ["MANAGEMENT_UNSPECIFIED", "NONE", "BASIC", "COMPLETE"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#allowed_device_management_levels AccessContextManagerAccessLevelCondition#allowed_device_management_levels}
AllowedDeviceManagementLevels *[]*string `field:"optional" json:"allowedDeviceManagementLevels" yaml:"allowedDeviceManagementLevels"`
// A list of allowed encryptions statuses. An empty list allows all statuses. Possible values: ["ENCRYPTION_UNSPECIFIED", "ENCRYPTION_UNSUPPORTED", "UNENCRYPTED", "ENCRYPTED"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#allowed_encryption_statuses AccessContextManagerAccessLevelCondition#allowed_encryption_statuses}
AllowedEncryptionStatuses *[]*string `field:"optional" json:"allowedEncryptionStatuses" yaml:"allowedEncryptionStatuses"`
// os_constraints block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#os_constraints AccessContextManagerAccessLevelCondition#os_constraints}
OsConstraints interface{} `field:"optional" json:"osConstraints" yaml:"osConstraints"`
// Whether the device needs to be approved by the customer admin.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#require_admin_approval AccessContextManagerAccessLevelCondition#require_admin_approval}
RequireAdminApproval interface{} `field:"optional" json:"requireAdminApproval" yaml:"requireAdminApproval"`
// Whether the device needs to be corp owned.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#require_corp_owned AccessContextManagerAccessLevelCondition#require_corp_owned}
RequireCorpOwned interface{} `field:"optional" json:"requireCorpOwned" yaml:"requireCorpOwned"`
// Whether or not screenlock is required for the DevicePolicy to be true. Defaults to false.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#require_screen_lock AccessContextManagerAccessLevelCondition#require_screen_lock}
RequireScreenLock interface{} `field:"optional" json:"requireScreenLock" yaml:"requireScreenLock"`
}
type AccessContextManagerAccessLevelConditionDevicePolicyOsConstraints ¶
type AccessContextManagerAccessLevelConditionDevicePolicyOsConstraints struct {
// The operating system type of the device. Possible values: ["OS_UNSPECIFIED", "DESKTOP_MAC", "DESKTOP_WINDOWS", "DESKTOP_LINUX", "DESKTOP_CHROME_OS", "ANDROID", "IOS"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#os_type AccessContextManagerAccessLevelCondition#os_type}
OsType *string `field:"required" json:"osType" yaml:"osType"`
// The minimum allowed OS version.
//
// If not set, any version
// of this OS satisfies the constraint.
// Format: "major.minor.patch" such as "10.5.301", "9.2.1".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#minimum_version AccessContextManagerAccessLevelCondition#minimum_version}
MinimumVersion *string `field:"optional" json:"minimumVersion" yaml:"minimumVersion"`
}
type AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsList ¶
type AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsList ¶
func NewAccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsList
type AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsOutputReference ¶
type AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
MinimumVersion() *string
SetMinimumVersion(val *string)
MinimumVersionInput() *string
OsType() *string
SetOsType(val *string)
OsTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetMinimumVersion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsOutputReference ¶
func NewAccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsOutputReference
type AccessContextManagerAccessLevelConditionDevicePolicyOutputReference ¶
type AccessContextManagerAccessLevelConditionDevicePolicyOutputReference interface {
cdktf.ComplexObject
AllowedDeviceManagementLevels() *[]*string
SetAllowedDeviceManagementLevels(val *[]*string)
AllowedDeviceManagementLevelsInput() *[]*string
AllowedEncryptionStatuses() *[]*string
SetAllowedEncryptionStatuses(val *[]*string)
AllowedEncryptionStatusesInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AccessContextManagerAccessLevelConditionDevicePolicy
SetInternalValue(val *AccessContextManagerAccessLevelConditionDevicePolicy)
OsConstraints() AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsList
OsConstraintsInput() interface{}
RequireAdminApproval() interface{}
SetRequireAdminApproval(val interface{})
RequireAdminApprovalInput() interface{}
RequireCorpOwned() interface{}
SetRequireCorpOwned(val interface{})
RequireCorpOwnedInput() interface{}
RequireScreenLock() interface{}
SetRequireScreenLock(val interface{})
RequireScreenLockInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutOsConstraints(value interface{})
ResetAllowedDeviceManagementLevels()
ResetAllowedEncryptionStatuses()
ResetOsConstraints()
ResetRequireAdminApproval()
ResetRequireCorpOwned()
ResetRequireScreenLock()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAccessContextManagerAccessLevelConditionDevicePolicyOutputReference ¶
func NewAccessContextManagerAccessLevelConditionDevicePolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AccessContextManagerAccessLevelConditionDevicePolicyOutputReference
type AccessContextManagerAccessLevelConditionTimeouts ¶
type AccessContextManagerAccessLevelConditionTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#create AccessContextManagerAccessLevelCondition#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#delete AccessContextManagerAccessLevelCondition#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type AccessContextManagerAccessLevelConditionTimeoutsOutputReference ¶
type AccessContextManagerAccessLevelConditionTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAccessContextManagerAccessLevelConditionTimeoutsOutputReference ¶
func NewAccessContextManagerAccessLevelConditionTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AccessContextManagerAccessLevelConditionTimeoutsOutputReference
type AccessContextManagerAccessLevelConditionVpcNetworkSources ¶
type AccessContextManagerAccessLevelConditionVpcNetworkSources struct {
// vpc_subnetwork block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#vpc_subnetwork AccessContextManagerAccessLevelCondition#vpc_subnetwork}
VpcSubnetwork *AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetwork `field:"optional" json:"vpcSubnetwork" yaml:"vpcSubnetwork"`
}
type AccessContextManagerAccessLevelConditionVpcNetworkSourcesList ¶
type AccessContextManagerAccessLevelConditionVpcNetworkSourcesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) AccessContextManagerAccessLevelConditionVpcNetworkSourcesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesList ¶
func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AccessContextManagerAccessLevelConditionVpcNetworkSourcesList
type AccessContextManagerAccessLevelConditionVpcNetworkSourcesOutputReference ¶
type AccessContextManagerAccessLevelConditionVpcNetworkSourcesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VpcSubnetwork() AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetworkOutputReference
VpcSubnetworkInput() *AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetwork
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutVpcSubnetwork(value *AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetwork)
ResetVpcSubnetwork()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesOutputReference ¶
func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AccessContextManagerAccessLevelConditionVpcNetworkSourcesOutputReference
type AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetwork ¶
type AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetwork struct {
// Required.
//
// Network name to be allowed by this Access Level. Networks of foreign organizations requires 'compute.network.get' permission to be granted to caller.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#network AccessContextManagerAccessLevelCondition#network}
Network *string `field:"required" json:"network" yaml:"network"`
// CIDR block IP subnetwork specification. Must be IPv4.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/access_context_manager_access_level_condition#vpc_ip_subnetworks AccessContextManagerAccessLevelCondition#vpc_ip_subnetworks}
VpcIpSubnetworks *[]*string `field:"optional" json:"vpcIpSubnetworks" yaml:"vpcIpSubnetworks"`
}
type AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetworkOutputReference ¶
type AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetworkOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetwork
SetInternalValue(val *AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetwork)
Network() *string
SetNetwork(val *string)
NetworkInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VpcIpSubnetworks() *[]*string
SetVpcIpSubnetworks(val *[]*string)
VpcIpSubnetworksInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetVpcIpSubnetworks()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetworkOutputReference ¶
func NewAccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetworkOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetworkOutputReference
Source Files
¶
- AccessContextManagerAccessLevelCondition.go
- AccessContextManagerAccessLevelConditionConfig.go
- AccessContextManagerAccessLevelConditionDevicePolicy.go
- AccessContextManagerAccessLevelConditionDevicePolicyOsConstraints.go
- AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsList.go
- AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsList__checks.go
- AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsOutputReference.go
- AccessContextManagerAccessLevelConditionDevicePolicyOsConstraintsOutputReference__checks.go
- AccessContextManagerAccessLevelConditionDevicePolicyOutputReference.go
- AccessContextManagerAccessLevelConditionDevicePolicyOutputReference__checks.go
- AccessContextManagerAccessLevelConditionTimeouts.go
- AccessContextManagerAccessLevelConditionTimeoutsOutputReference.go
- AccessContextManagerAccessLevelConditionTimeoutsOutputReference__checks.go
- AccessContextManagerAccessLevelConditionVpcNetworkSources.go
- AccessContextManagerAccessLevelConditionVpcNetworkSourcesList.go
- AccessContextManagerAccessLevelConditionVpcNetworkSourcesList__checks.go
- AccessContextManagerAccessLevelConditionVpcNetworkSourcesOutputReference.go
- AccessContextManagerAccessLevelConditionVpcNetworkSourcesOutputReference__checks.go
- AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetwork.go
- AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetworkOutputReference.go
- AccessContextManagerAccessLevelConditionVpcNetworkSourcesVpcSubnetworkOutputReference__checks.go
- AccessContextManagerAccessLevelCondition__checks.go
- main.go