Documentation
¶
Index ¶
- func AccessContextManagerAuthorizedOrgsDesc_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func AccessContextManagerAuthorizedOrgsDesc_IsConstruct(x interface{}) *bool
- func AccessContextManagerAuthorizedOrgsDesc_IsTerraformElement(x interface{}) *bool
- func AccessContextManagerAuthorizedOrgsDesc_IsTerraformResource(x interface{}) *bool
- func AccessContextManagerAuthorizedOrgsDesc_TfResourceType() *string
- func NewAccessContextManagerAuthorizedOrgsDescTimeoutsOutputReference_Override(a AccessContextManagerAuthorizedOrgsDescTimeoutsOutputReference, ...)
- func NewAccessContextManagerAuthorizedOrgsDesc_Override(a AccessContextManagerAuthorizedOrgsDesc, scope constructs.Construct, ...)
- type AccessContextManagerAuthorizedOrgsDesc
- type AccessContextManagerAuthorizedOrgsDescConfig
- type AccessContextManagerAuthorizedOrgsDescTimeouts
- type AccessContextManagerAuthorizedOrgsDescTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AccessContextManagerAuthorizedOrgsDesc_GenerateConfigForImport ¶
func AccessContextManagerAuthorizedOrgsDesc_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a AccessContextManagerAuthorizedOrgsDesc resource upon running "cdktf plan <stack-name>".
func AccessContextManagerAuthorizedOrgsDesc_IsConstruct ¶
func AccessContextManagerAuthorizedOrgsDesc_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AccessContextManagerAuthorizedOrgsDesc_IsTerraformElement ¶
func AccessContextManagerAuthorizedOrgsDesc_IsTerraformElement(x interface{}) *bool
Experimental.
func AccessContextManagerAuthorizedOrgsDesc_IsTerraformResource ¶
func AccessContextManagerAuthorizedOrgsDesc_IsTerraformResource(x interface{}) *bool
Experimental.
func AccessContextManagerAuthorizedOrgsDesc_TfResourceType ¶
func AccessContextManagerAuthorizedOrgsDesc_TfResourceType() *string
func NewAccessContextManagerAuthorizedOrgsDescTimeoutsOutputReference_Override ¶
func NewAccessContextManagerAuthorizedOrgsDescTimeoutsOutputReference_Override(a AccessContextManagerAuthorizedOrgsDescTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAccessContextManagerAuthorizedOrgsDesc_Override ¶
func NewAccessContextManagerAuthorizedOrgsDesc_Override(a AccessContextManagerAuthorizedOrgsDesc, scope constructs.Construct, id *string, config *AccessContextManagerAuthorizedOrgsDescConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/access_context_manager_authorized_orgs_desc google_access_context_manager_authorized_orgs_desc} Resource.
Types ¶
type AccessContextManagerAuthorizedOrgsDesc ¶
type AccessContextManagerAuthorizedOrgsDesc interface {
cdktf.TerraformResource
AssetType() *string
SetAssetType(val *string)
AssetTypeInput() *string
AuthorizationDirection() *string
SetAuthorizationDirection(val *string)
AuthorizationDirectionInput() *string
AuthorizationType() *string
SetAuthorizationType(val *string)
AuthorizationTypeInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Orgs() *[]*string
SetOrgs(val *[]*string)
OrgsInput() *[]*string
Parent() *string
SetParent(val *string)
ParentInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() AccessContextManagerAuthorizedOrgsDescTimeoutsOutputReference
TimeoutsInput() interface{}
UpdateTime() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *AccessContextManagerAuthorizedOrgsDescTimeouts)
ResetAssetType()
ResetAuthorizationDirection()
ResetAuthorizationType()
ResetId()
ResetOrgs()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/access_context_manager_authorized_orgs_desc google_access_context_manager_authorized_orgs_desc}.
func NewAccessContextManagerAuthorizedOrgsDesc ¶
func NewAccessContextManagerAuthorizedOrgsDesc(scope constructs.Construct, id *string, config *AccessContextManagerAuthorizedOrgsDescConfig) AccessContextManagerAuthorizedOrgsDesc
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/access_context_manager_authorized_orgs_desc google_access_context_manager_authorized_orgs_desc} Resource.
type AccessContextManagerAuthorizedOrgsDescConfig ¶
type AccessContextManagerAuthorizedOrgsDescConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Resource name for the 'AuthorizedOrgsDesc'.
//
// Format:
// 'accessPolicies/{access_policy}/authorizedOrgsDescs/{authorized_orgs_desc}'.
// The 'authorized_orgs_desc' component must begin with a letter, followed by
// alphanumeric characters or '_'.
// After you create an 'AuthorizedOrgsDesc', you cannot change its 'name'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/access_context_manager_authorized_orgs_desc#name AccessContextManagerAuthorizedOrgsDesc#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Required. Resource name for the access policy which owns this 'AuthorizedOrgsDesc'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/access_context_manager_authorized_orgs_desc#parent AccessContextManagerAuthorizedOrgsDesc#parent}
Parent *string `field:"required" json:"parent" yaml:"parent"`
// The type of entities that need to use the authorization relationship during evaluation, such as a device.
//
// Valid values are "ASSET_TYPE_DEVICE" and
// "ASSET_TYPE_CREDENTIAL_STRENGTH". Possible values: ["ASSET_TYPE_DEVICE", "ASSET_TYPE_CREDENTIAL_STRENGTH"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/access_context_manager_authorized_orgs_desc#asset_type AccessContextManagerAuthorizedOrgsDesc#asset_type}
AssetType *string `field:"optional" json:"assetType" yaml:"assetType"`
// The direction of the authorization relationship between this organization and the organizations listed in the "orgs" field.
//
// The valid values for this
// field include the following:
//
// AUTHORIZATION_DIRECTION_FROM: Allows this organization to evaluate traffic
// in the organizations listed in the 'orgs' field.
//
// AUTHORIZATION_DIRECTION_TO: Allows the organizations listed in the 'orgs'
// field to evaluate the traffic in this organization.
//
// For the authorization relationship to take effect, all of the organizations
// must authorize and specify the appropriate relationship direction. For
// example, if organization A authorized organization B and C to evaluate its
// traffic, by specifying "AUTHORIZATION_DIRECTION_TO" as the authorization
// direction, organizations B and C must specify
// "AUTHORIZATION_DIRECTION_FROM" as the authorization direction in their
// "AuthorizedOrgsDesc" resource. Possible values: ["AUTHORIZATION_DIRECTION_TO", "AUTHORIZATION_DIRECTION_FROM"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/access_context_manager_authorized_orgs_desc#authorization_direction AccessContextManagerAuthorizedOrgsDesc#authorization_direction}
AuthorizationDirection *string `field:"optional" json:"authorizationDirection" yaml:"authorizationDirection"`
// A granular control type for authorization levels. Valid value is "AUTHORIZATION_TYPE_TRUST". Possible values: ["AUTHORIZATION_TYPE_TRUST"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/access_context_manager_authorized_orgs_desc#authorization_type AccessContextManagerAuthorizedOrgsDesc#authorization_type}
AuthorizationType *string `field:"optional" json:"authorizationType" yaml:"authorizationType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/access_context_manager_authorized_orgs_desc#id AccessContextManagerAuthorizedOrgsDesc#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The list of organization ids in this AuthorizedOrgsDesc. Format: 'organizations/<org_number>' Example: 'organizations/123456'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/access_context_manager_authorized_orgs_desc#orgs AccessContextManagerAuthorizedOrgsDesc#orgs}
Orgs *[]*string `field:"optional" json:"orgs" yaml:"orgs"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/access_context_manager_authorized_orgs_desc#timeouts AccessContextManagerAuthorizedOrgsDesc#timeouts}
Timeouts *AccessContextManagerAuthorizedOrgsDescTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type AccessContextManagerAuthorizedOrgsDescTimeouts ¶
type AccessContextManagerAuthorizedOrgsDescTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/access_context_manager_authorized_orgs_desc#create AccessContextManagerAuthorizedOrgsDesc#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/access_context_manager_authorized_orgs_desc#delete AccessContextManagerAuthorizedOrgsDesc#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/access_context_manager_authorized_orgs_desc#update AccessContextManagerAuthorizedOrgsDesc#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type AccessContextManagerAuthorizedOrgsDescTimeoutsOutputReference ¶
type AccessContextManagerAuthorizedOrgsDescTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAccessContextManagerAuthorizedOrgsDescTimeoutsOutputReference ¶
func NewAccessContextManagerAuthorizedOrgsDescTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AccessContextManagerAuthorizedOrgsDescTimeoutsOutputReference
Source Files
¶
- AccessContextManagerAuthorizedOrgsDesc.go
- AccessContextManagerAuthorizedOrgsDescConfig.go
- AccessContextManagerAuthorizedOrgsDescTimeouts.go
- AccessContextManagerAuthorizedOrgsDescTimeoutsOutputReference.go
- AccessContextManagerAuthorizedOrgsDescTimeoutsOutputReference__checks.go
- AccessContextManagerAuthorizedOrgsDesc__checks.go
- main.go