Documentation
¶
Index ¶
- func ComputeDisk_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func ComputeDisk_IsConstruct(x interface{}) *bool
- func ComputeDisk_IsTerraformElement(x interface{}) *bool
- func ComputeDisk_IsTerraformResource(x interface{}) *bool
- func ComputeDisk_TfResourceType() *string
- func NewComputeDiskAsyncPrimaryDiskOutputReference_Override(c ComputeDiskAsyncPrimaryDiskOutputReference, ...)
- func NewComputeDiskDiskEncryptionKeyOutputReference_Override(c ComputeDiskDiskEncryptionKeyOutputReference, ...)
- func NewComputeDiskGuestOsFeaturesList_Override(c ComputeDiskGuestOsFeaturesList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewComputeDiskGuestOsFeaturesOutputReference_Override(c ComputeDiskGuestOsFeaturesOutputReference, ...)
- func NewComputeDiskSourceImageEncryptionKeyOutputReference_Override(c ComputeDiskSourceImageEncryptionKeyOutputReference, ...)
- func NewComputeDiskSourceSnapshotEncryptionKeyOutputReference_Override(c ComputeDiskSourceSnapshotEncryptionKeyOutputReference, ...)
- func NewComputeDiskTimeoutsOutputReference_Override(c ComputeDiskTimeoutsOutputReference, ...)
- func NewComputeDisk_Override(c ComputeDisk, scope constructs.Construct, id *string, ...)
- type ComputeDisk
- type ComputeDiskAsyncPrimaryDisk
- type ComputeDiskAsyncPrimaryDiskOutputReference
- type ComputeDiskConfig
- type ComputeDiskDiskEncryptionKey
- type ComputeDiskDiskEncryptionKeyOutputReference
- type ComputeDiskGuestOsFeatures
- type ComputeDiskGuestOsFeaturesList
- type ComputeDiskGuestOsFeaturesOutputReference
- type ComputeDiskSourceImageEncryptionKey
- type ComputeDiskSourceImageEncryptionKeyOutputReference
- type ComputeDiskSourceSnapshotEncryptionKey
- type ComputeDiskSourceSnapshotEncryptionKeyOutputReference
- type ComputeDiskTimeouts
- type ComputeDiskTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComputeDisk_GenerateConfigForImport ¶
func ComputeDisk_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a ComputeDisk resource upon running "cdktf plan <stack-name>".
func ComputeDisk_IsConstruct ¶
func ComputeDisk_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ComputeDisk_IsTerraformElement ¶
func ComputeDisk_IsTerraformElement(x interface{}) *bool
Experimental.
func ComputeDisk_IsTerraformResource ¶
func ComputeDisk_IsTerraformResource(x interface{}) *bool
Experimental.
func ComputeDisk_TfResourceType ¶
func ComputeDisk_TfResourceType() *string
func NewComputeDiskAsyncPrimaryDiskOutputReference_Override ¶
func NewComputeDiskAsyncPrimaryDiskOutputReference_Override(c ComputeDiskAsyncPrimaryDiskOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputeDiskDiskEncryptionKeyOutputReference_Override ¶
func NewComputeDiskDiskEncryptionKeyOutputReference_Override(c ComputeDiskDiskEncryptionKeyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputeDiskGuestOsFeaturesList_Override ¶
func NewComputeDiskGuestOsFeaturesList_Override(c ComputeDiskGuestOsFeaturesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewComputeDiskGuestOsFeaturesOutputReference_Override ¶
func NewComputeDiskGuestOsFeaturesOutputReference_Override(c ComputeDiskGuestOsFeaturesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewComputeDiskSourceImageEncryptionKeyOutputReference_Override ¶
func NewComputeDiskSourceImageEncryptionKeyOutputReference_Override(c ComputeDiskSourceImageEncryptionKeyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputeDiskSourceSnapshotEncryptionKeyOutputReference_Override ¶
func NewComputeDiskSourceSnapshotEncryptionKeyOutputReference_Override(c ComputeDiskSourceSnapshotEncryptionKeyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputeDiskTimeoutsOutputReference_Override ¶
func NewComputeDiskTimeoutsOutputReference_Override(c ComputeDiskTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputeDisk_Override ¶
func NewComputeDisk_Override(c ComputeDisk, scope constructs.Construct, id *string, config *ComputeDiskConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk google_compute_disk} Resource.
Types ¶
type ComputeDisk ¶
type ComputeDisk interface {
cdktf.TerraformResource
AccessMode() *string
SetAccessMode(val *string)
AccessModeInput() *string
AsyncPrimaryDisk() ComputeDiskAsyncPrimaryDiskOutputReference
AsyncPrimaryDiskInput() *ComputeDiskAsyncPrimaryDisk
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreationTimestamp() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DiskEncryptionKey() ComputeDiskDiskEncryptionKeyOutputReference
DiskEncryptionKeyInput() *ComputeDiskDiskEncryptionKey
DiskId() *string
EffectiveLabels() cdktf.StringMap
EnableConfidentialCompute() interface{}
SetEnableConfidentialCompute(val interface{})
EnableConfidentialComputeInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GuestOsFeatures() ComputeDiskGuestOsFeaturesList
GuestOsFeaturesInput() interface{}
Id() *string
SetId(val *string)
IdInput() *string
Image() *string
SetImage(val *string)
ImageInput() *string
LabelFingerprint() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
LastAttachTimestamp() *string
LastDetachTimestamp() *string
Licenses() *[]*string
SetLicenses(val *[]*string)
LicensesInput() *[]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
PhysicalBlockSizeBytes() *float64
SetPhysicalBlockSizeBytes(val *float64)
PhysicalBlockSizeBytesInput() *float64
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
ProvisionedIops() *float64
SetProvisionedIops(val *float64)
ProvisionedIopsInput() *float64
ProvisionedThroughput() *float64
SetProvisionedThroughput(val *float64)
ProvisionedThroughputInput() *float64
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SelfLink() *string
Size() *float64
SetSize(val *float64)
SizeInput() *float64
Snapshot() *string
SetSnapshot(val *string)
SnapshotInput() *string
SourceDisk() *string
SetSourceDisk(val *string)
SourceDiskId() *string
SourceDiskInput() *string
SourceImageEncryptionKey() ComputeDiskSourceImageEncryptionKeyOutputReference
SourceImageEncryptionKeyInput() *ComputeDiskSourceImageEncryptionKey
SourceImageId() *string
SourceSnapshotEncryptionKey() ComputeDiskSourceSnapshotEncryptionKeyOutputReference
SourceSnapshotEncryptionKeyInput() *ComputeDiskSourceSnapshotEncryptionKey
SourceSnapshotId() *string
StoragePool() *string
SetStoragePool(val *string)
StoragePoolInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() ComputeDiskTimeoutsOutputReference
TimeoutsInput() interface{}
Type() *string
SetType(val *string)
TypeInput() *string
Users() *[]*string
Zone() *string
SetZone(val *string)
ZoneInput() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAsyncPrimaryDisk(value *ComputeDiskAsyncPrimaryDisk)
PutDiskEncryptionKey(value *ComputeDiskDiskEncryptionKey)
PutGuestOsFeatures(value interface{})
PutSourceImageEncryptionKey(value *ComputeDiskSourceImageEncryptionKey)
PutSourceSnapshotEncryptionKey(value *ComputeDiskSourceSnapshotEncryptionKey)
PutTimeouts(value *ComputeDiskTimeouts)
ResetAccessMode()
ResetAsyncPrimaryDisk()
ResetDescription()
ResetDiskEncryptionKey()
ResetEnableConfidentialCompute()
ResetGuestOsFeatures()
ResetId()
ResetImage()
ResetLabels()
ResetLicenses()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPhysicalBlockSizeBytes()
ResetProject()
ResetProvisionedIops()
ResetProvisionedThroughput()
ResetSize()
ResetSnapshot()
ResetSourceDisk()
ResetSourceImageEncryptionKey()
ResetSourceSnapshotEncryptionKey()
ResetStoragePool()
ResetTimeouts()
ResetType()
ResetZone()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk google_compute_disk}.
func NewComputeDisk ¶
func NewComputeDisk(scope constructs.Construct, id *string, config *ComputeDiskConfig) ComputeDisk
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk google_compute_disk} Resource.
type ComputeDiskAsyncPrimaryDisk ¶
type ComputeDiskAsyncPrimaryDisk struct {
// Primary disk for asynchronous disk replication.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#disk ComputeDisk#disk}
Disk *string `field:"required" json:"disk" yaml:"disk"`
}
type ComputeDiskAsyncPrimaryDiskOutputReference ¶
type ComputeDiskAsyncPrimaryDiskOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Disk() *string
SetDisk(val *string)
DiskInput() *string
// Experimental.
Fqn() *string
InternalValue() *ComputeDiskAsyncPrimaryDisk
SetInternalValue(val *ComputeDiskAsyncPrimaryDisk)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeDiskAsyncPrimaryDiskOutputReference ¶
func NewComputeDiskAsyncPrimaryDiskOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputeDiskAsyncPrimaryDiskOutputReference
type ComputeDiskConfig ¶
type ComputeDiskConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Name of the resource.
//
// Provided by the client when the resource is
// created. The name must be 1-63 characters long, and comply with
// RFC1035. Specifically, the name must be 1-63 characters long and match
// the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
// first character must be a lowercase letter, and all following
// characters must be a dash, lowercase letter, or digit, except the last
// character, which cannot be a dash.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#name ComputeDisk#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The accessMode of the disk. For example: * READ_WRITE_SINGLE * READ_WRITE_MANY * READ_ONLY_SINGLE.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#access_mode ComputeDisk#access_mode}
AccessMode *string `field:"optional" json:"accessMode" yaml:"accessMode"`
// async_primary_disk block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#async_primary_disk ComputeDisk#async_primary_disk}
AsyncPrimaryDisk *ComputeDiskAsyncPrimaryDisk `field:"optional" json:"asyncPrimaryDisk" yaml:"asyncPrimaryDisk"`
// An optional description of this resource. Provide this property when you create the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#description ComputeDisk#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// disk_encryption_key block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#disk_encryption_key ComputeDisk#disk_encryption_key}
DiskEncryptionKey *ComputeDiskDiskEncryptionKey `field:"optional" json:"diskEncryptionKey" yaml:"diskEncryptionKey"`
// Whether this disk is using confidential compute mode.
//
// Note: Only supported on hyperdisk skus, disk_encryption_key is required when setting to true
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#enable_confidential_compute ComputeDisk#enable_confidential_compute}
EnableConfidentialCompute interface{} `field:"optional" json:"enableConfidentialCompute" yaml:"enableConfidentialCompute"`
// guest_os_features block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#guest_os_features ComputeDisk#guest_os_features}
GuestOsFeatures interface{} `field:"optional" json:"guestOsFeatures" yaml:"guestOsFeatures"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#id ComputeDisk#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The image from which to initialize this disk.
//
// This can be
// one of: the image's 'self_link', 'projects/{project}/global/images/{image}',
// 'projects/{project}/global/images/family/{family}', 'global/images/{image}',
// 'global/images/family/{family}', 'family/{family}', '{project}/{family}',
// '{project}/{image}', '{family}', or '{image}'. If referred by family, the
// images names must include the family name. If they don't, use the
// [google_compute_image data source](/docs/providers/google/d/compute_image.html).
// For instance, the image 'centos-6-v20180104' includes its family name 'centos-6'.
// These images can be referred by family name here.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#image ComputeDisk#image}
Image *string `field:"optional" json:"image" yaml:"image"`
// Labels to apply to this disk. A list of key->value pairs.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#labels ComputeDisk#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// Any applicable license URI.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#licenses ComputeDisk#licenses}
Licenses *[]*string `field:"optional" json:"licenses" yaml:"licenses"`
// Physical block size of the persistent disk, in bytes.
//
// If not present
// in a request, a default value is used. Currently supported sizes
// are 4096 and 16384, other sizes may be added in the future.
// If an unsupported value is requested, the error message will list
// the supported values for the caller's project.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#physical_block_size_bytes ComputeDisk#physical_block_size_bytes}
PhysicalBlockSizeBytes *float64 `field:"optional" json:"physicalBlockSizeBytes" yaml:"physicalBlockSizeBytes"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#project ComputeDisk#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// Indicates how many IOPS must be provisioned for the disk.
//
// Note: Updating currently is only supported by hyperdisk skus without the need to delete and recreate the disk, hyperdisk
// allows for an update of IOPS every 4 hours. To update your hyperdisk more frequently, you'll need to manually delete and recreate it
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#provisioned_iops ComputeDisk#provisioned_iops}
ProvisionedIops *float64 `field:"optional" json:"provisionedIops" yaml:"provisionedIops"`
// Indicates how much Throughput must be provisioned for the disk.
//
// Note: Updating currently is only supported by hyperdisk skus without the need to delete and recreate the disk, hyperdisk
// allows for an update of Throughput every 4 hours. To update your hyperdisk more frequently, you'll need to manually delete and recreate it
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#provisioned_throughput ComputeDisk#provisioned_throughput}
ProvisionedThroughput *float64 `field:"optional" json:"provisionedThroughput" yaml:"provisionedThroughput"`
// Size of the persistent disk, specified in GB.
//
// You can specify this
// field when creating a persistent disk using the 'image' or
// 'snapshot' parameter, or specify it alone to create an empty
// persistent disk.
//
// If you specify this field along with 'image' or 'snapshot',
// the value must not be less than the size of the image
// or the size of the snapshot.
//
// ~>**NOTE** If you change the size, Terraform updates the disk size
// if upsizing is detected but recreates the disk if downsizing is requested.
// You can add 'lifecycle.prevent_destroy' in the config to prevent destroying
// and recreating.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#size ComputeDisk#size}
Size *float64 `field:"optional" json:"size" yaml:"size"`
// The source snapshot used to create this disk.
//
// You can provide this as
// a partial or full URL to the resource. If the snapshot is in another
// project than this disk, you must supply a full URL. For example, the
// following are valid values:
//
// * 'https://www.googleapis.com/compute/v1/projects/project/global/snapshots/snapshot'
// * 'projects/project/global/snapshots/snapshot'
// * 'global/snapshots/snapshot'
// * 'snapshot'
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#snapshot ComputeDisk#snapshot}
Snapshot *string `field:"optional" json:"snapshot" yaml:"snapshot"`
// The source disk used to create this disk.
//
// You can provide this as a partial or full URL to the resource.
// For example, the following are valid values:
//
// * https://www.googleapis.com/compute/v1/projects/{project}/zones/{zone}/disks/{disk}
// * https://www.googleapis.com/compute/v1/projects/{project}/regions/{region}/disks/{disk}
// * projects/{project}/zones/{zone}/disks/{disk}
// * projects/{project}/regions/{region}/disks/{disk}
// * zones/{zone}/disks/{disk}
// * regions/{region}/disks/{disk}
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#source_disk ComputeDisk#source_disk}
SourceDisk *string `field:"optional" json:"sourceDisk" yaml:"sourceDisk"`
// source_image_encryption_key block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#source_image_encryption_key ComputeDisk#source_image_encryption_key}
SourceImageEncryptionKey *ComputeDiskSourceImageEncryptionKey `field:"optional" json:"sourceImageEncryptionKey" yaml:"sourceImageEncryptionKey"`
// source_snapshot_encryption_key block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#source_snapshot_encryption_key ComputeDisk#source_snapshot_encryption_key}
SourceSnapshotEncryptionKey *ComputeDiskSourceSnapshotEncryptionKey `field:"optional" json:"sourceSnapshotEncryptionKey" yaml:"sourceSnapshotEncryptionKey"`
// The URL of the storage pool in which the new disk is created. For example: * https://www.googleapis.com/compute/v1/projects/{project}/zones/{zone}/storagePools/{storagePool} * /projects/{project}/zones/{zone}/storagePools/{storagePool}.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#storage_pool ComputeDisk#storage_pool}
StoragePool *string `field:"optional" json:"storagePool" yaml:"storagePool"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#timeouts ComputeDisk#timeouts}
Timeouts *ComputeDiskTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// URL of the disk type resource describing which disk type to use to create the disk.
//
// Provide this when creating the disk.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#type ComputeDisk#type}
Type *string `field:"optional" json:"type" yaml:"type"`
// A reference to the zone where the disk resides.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#zone ComputeDisk#zone}
Zone *string `field:"optional" json:"zone" yaml:"zone"`
}
type ComputeDiskDiskEncryptionKey ¶
type ComputeDiskDiskEncryptionKey struct {
// The self link of the encryption key used to encrypt the disk.
//
// Also called KmsKeyName
// in the cloud console. Your project's Compute Engine System service account
// ('service-{{PROJECT_NUMBER}}@compute-system.iam.gserviceaccount.com') must have
// 'roles/cloudkms.cryptoKeyEncrypterDecrypter' to use this feature.
// See https://cloud.google.com/compute/docs/disks/customer-managed-encryption#encrypt_a_new_persistent_disk_with_your_own_keys
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#kms_key_self_link ComputeDisk#kms_key_self_link}
KmsKeySelfLink *string `field:"optional" json:"kmsKeySelfLink" yaml:"kmsKeySelfLink"`
// The service account used for the encryption request for the given KMS key.
//
// If absent, the Compute Engine Service Agent service account is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#kms_key_service_account ComputeDisk#kms_key_service_account}
KmsKeyServiceAccount *string `field:"optional" json:"kmsKeyServiceAccount" yaml:"kmsKeyServiceAccount"`
// Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#raw_key ComputeDisk#raw_key}
RawKey *string `field:"optional" json:"rawKey" yaml:"rawKey"`
// Specifies an RFC 4648 base64 encoded, RSA-wrapped 2048-bit customer-supplied encryption key to either encrypt or decrypt this resource.
//
// You can provide either the rawKey or the rsaEncryptedKey.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#rsa_encrypted_key ComputeDisk#rsa_encrypted_key}
RsaEncryptedKey *string `field:"optional" json:"rsaEncryptedKey" yaml:"rsaEncryptedKey"`
}
type ComputeDiskDiskEncryptionKeyOutputReference ¶
type ComputeDiskDiskEncryptionKeyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ComputeDiskDiskEncryptionKey
SetInternalValue(val *ComputeDiskDiskEncryptionKey)
KmsKeySelfLink() *string
SetKmsKeySelfLink(val *string)
KmsKeySelfLinkInput() *string
KmsKeyServiceAccount() *string
SetKmsKeyServiceAccount(val *string)
KmsKeyServiceAccountInput() *string
RawKey() *string
SetRawKey(val *string)
RawKeyInput() *string
RsaEncryptedKey() *string
SetRsaEncryptedKey(val *string)
RsaEncryptedKeyInput() *string
Sha256() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKmsKeySelfLink()
ResetKmsKeyServiceAccount()
ResetRawKey()
ResetRsaEncryptedKey()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeDiskDiskEncryptionKeyOutputReference ¶
func NewComputeDiskDiskEncryptionKeyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputeDiskDiskEncryptionKeyOutputReference
type ComputeDiskGuestOsFeatures ¶
type ComputeDiskGuestOsFeatures struct {
// The type of supported feature. Read [Enabling guest operating system features](https://cloud.google.com/compute/docs/images/create-delete-deprecate-private-images#guest-os-features) to see a list of available options.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#type ComputeDisk#type}
Type *string `field:"required" json:"type" yaml:"type"`
}
type ComputeDiskGuestOsFeaturesList ¶
type ComputeDiskGuestOsFeaturesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) ComputeDiskGuestOsFeaturesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeDiskGuestOsFeaturesList ¶
func NewComputeDiskGuestOsFeaturesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ComputeDiskGuestOsFeaturesList
type ComputeDiskGuestOsFeaturesOutputReference ¶
type ComputeDiskGuestOsFeaturesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeDiskGuestOsFeaturesOutputReference ¶
func NewComputeDiskGuestOsFeaturesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ComputeDiskGuestOsFeaturesOutputReference
type ComputeDiskSourceImageEncryptionKey ¶
type ComputeDiskSourceImageEncryptionKey struct {
// The self link of the encryption key used to encrypt the disk.
//
// Also called KmsKeyName
// in the cloud console. Your project's Compute Engine System service account
// ('service-{{PROJECT_NUMBER}}@compute-system.iam.gserviceaccount.com') must have
// 'roles/cloudkms.cryptoKeyEncrypterDecrypter' to use this feature.
// See https://cloud.google.com/compute/docs/disks/customer-managed-encryption#encrypt_a_new_persistent_disk_with_your_own_keys
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#kms_key_self_link ComputeDisk#kms_key_self_link}
KmsKeySelfLink *string `field:"optional" json:"kmsKeySelfLink" yaml:"kmsKeySelfLink"`
// The service account used for the encryption request for the given KMS key.
//
// If absent, the Compute Engine Service Agent service account is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#kms_key_service_account ComputeDisk#kms_key_service_account}
KmsKeyServiceAccount *string `field:"optional" json:"kmsKeyServiceAccount" yaml:"kmsKeyServiceAccount"`
// Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#raw_key ComputeDisk#raw_key}
RawKey *string `field:"optional" json:"rawKey" yaml:"rawKey"`
}
type ComputeDiskSourceImageEncryptionKeyOutputReference ¶
type ComputeDiskSourceImageEncryptionKeyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ComputeDiskSourceImageEncryptionKey
SetInternalValue(val *ComputeDiskSourceImageEncryptionKey)
KmsKeySelfLink() *string
SetKmsKeySelfLink(val *string)
KmsKeySelfLinkInput() *string
KmsKeyServiceAccount() *string
SetKmsKeyServiceAccount(val *string)
KmsKeyServiceAccountInput() *string
RawKey() *string
SetRawKey(val *string)
RawKeyInput() *string
Sha256() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKmsKeySelfLink()
ResetKmsKeyServiceAccount()
ResetRawKey()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeDiskSourceImageEncryptionKeyOutputReference ¶
func NewComputeDiskSourceImageEncryptionKeyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputeDiskSourceImageEncryptionKeyOutputReference
type ComputeDiskSourceSnapshotEncryptionKey ¶
type ComputeDiskSourceSnapshotEncryptionKey struct {
// The self link of the encryption key used to encrypt the disk.
//
// Also called KmsKeyName
// in the cloud console. Your project's Compute Engine System service account
// ('service-{{PROJECT_NUMBER}}@compute-system.iam.gserviceaccount.com') must have
// 'roles/cloudkms.cryptoKeyEncrypterDecrypter' to use this feature.
// See https://cloud.google.com/compute/docs/disks/customer-managed-encryption#encrypt_a_new_persistent_disk_with_your_own_keys
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#kms_key_self_link ComputeDisk#kms_key_self_link}
KmsKeySelfLink *string `field:"optional" json:"kmsKeySelfLink" yaml:"kmsKeySelfLink"`
// The service account used for the encryption request for the given KMS key.
//
// If absent, the Compute Engine Service Agent service account is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#kms_key_service_account ComputeDisk#kms_key_service_account}
KmsKeyServiceAccount *string `field:"optional" json:"kmsKeyServiceAccount" yaml:"kmsKeyServiceAccount"`
// Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#raw_key ComputeDisk#raw_key}
RawKey *string `field:"optional" json:"rawKey" yaml:"rawKey"`
}
type ComputeDiskSourceSnapshotEncryptionKeyOutputReference ¶
type ComputeDiskSourceSnapshotEncryptionKeyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ComputeDiskSourceSnapshotEncryptionKey
SetInternalValue(val *ComputeDiskSourceSnapshotEncryptionKey)
KmsKeySelfLink() *string
SetKmsKeySelfLink(val *string)
KmsKeySelfLinkInput() *string
KmsKeyServiceAccount() *string
SetKmsKeyServiceAccount(val *string)
KmsKeyServiceAccountInput() *string
RawKey() *string
SetRawKey(val *string)
RawKeyInput() *string
Sha256() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKmsKeySelfLink()
ResetKmsKeyServiceAccount()
ResetRawKey()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeDiskSourceSnapshotEncryptionKeyOutputReference ¶
func NewComputeDiskSourceSnapshotEncryptionKeyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputeDiskSourceSnapshotEncryptionKeyOutputReference
type ComputeDiskTimeouts ¶
type ComputeDiskTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#create ComputeDisk#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#delete ComputeDisk#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/compute_disk#update ComputeDisk#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type ComputeDiskTimeoutsOutputReference ¶
type ComputeDiskTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeDiskTimeoutsOutputReference ¶
func NewComputeDiskTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputeDiskTimeoutsOutputReference
Source Files
¶
- ComputeDisk.go
- ComputeDiskAsyncPrimaryDisk.go
- ComputeDiskAsyncPrimaryDiskOutputReference.go
- ComputeDiskAsyncPrimaryDiskOutputReference__checks.go
- ComputeDiskConfig.go
- ComputeDiskDiskEncryptionKey.go
- ComputeDiskDiskEncryptionKeyOutputReference.go
- ComputeDiskDiskEncryptionKeyOutputReference__checks.go
- ComputeDiskGuestOsFeatures.go
- ComputeDiskGuestOsFeaturesList.go
- ComputeDiskGuestOsFeaturesList__checks.go
- ComputeDiskGuestOsFeaturesOutputReference.go
- ComputeDiskGuestOsFeaturesOutputReference__checks.go
- ComputeDiskSourceImageEncryptionKey.go
- ComputeDiskSourceImageEncryptionKeyOutputReference.go
- ComputeDiskSourceImageEncryptionKeyOutputReference__checks.go
- ComputeDiskSourceSnapshotEncryptionKey.go
- ComputeDiskSourceSnapshotEncryptionKeyOutputReference.go
- ComputeDiskSourceSnapshotEncryptionKeyOutputReference__checks.go
- ComputeDiskTimeouts.go
- ComputeDiskTimeoutsOutputReference.go
- ComputeDiskTimeoutsOutputReference__checks.go
- ComputeDisk__checks.go
- main.go