Documentation
¶
Index ¶
- func ComputeSharedVpcServiceProject_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func ComputeSharedVpcServiceProject_IsConstruct(x interface{}) *bool
- func ComputeSharedVpcServiceProject_IsTerraformElement(x interface{}) *bool
- func ComputeSharedVpcServiceProject_IsTerraformResource(x interface{}) *bool
- func ComputeSharedVpcServiceProject_TfResourceType() *string
- func NewComputeSharedVpcServiceProjectTimeoutsOutputReference_Override(c ComputeSharedVpcServiceProjectTimeoutsOutputReference, ...)
- func NewComputeSharedVpcServiceProject_Override(c ComputeSharedVpcServiceProject, scope constructs.Construct, id *string, ...)
- type ComputeSharedVpcServiceProject
- type ComputeSharedVpcServiceProjectConfig
- type ComputeSharedVpcServiceProjectTimeouts
- type ComputeSharedVpcServiceProjectTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComputeSharedVpcServiceProject_GenerateConfigForImport ¶
func ComputeSharedVpcServiceProject_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a ComputeSharedVpcServiceProject resource upon running "cdktf plan <stack-name>".
func ComputeSharedVpcServiceProject_IsConstruct ¶
func ComputeSharedVpcServiceProject_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ComputeSharedVpcServiceProject_IsTerraformElement ¶
func ComputeSharedVpcServiceProject_IsTerraformElement(x interface{}) *bool
Experimental.
func ComputeSharedVpcServiceProject_IsTerraformResource ¶
func ComputeSharedVpcServiceProject_IsTerraformResource(x interface{}) *bool
Experimental.
func ComputeSharedVpcServiceProject_TfResourceType ¶
func ComputeSharedVpcServiceProject_TfResourceType() *string
func NewComputeSharedVpcServiceProjectTimeoutsOutputReference_Override ¶
func NewComputeSharedVpcServiceProjectTimeoutsOutputReference_Override(c ComputeSharedVpcServiceProjectTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputeSharedVpcServiceProject_Override ¶
func NewComputeSharedVpcServiceProject_Override(c ComputeSharedVpcServiceProject, scope constructs.Construct, id *string, config *ComputeSharedVpcServiceProjectConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/compute_shared_vpc_service_project google_compute_shared_vpc_service_project} Resource.
Types ¶
type ComputeSharedVpcServiceProject ¶
type ComputeSharedVpcServiceProject interface {
cdktf.TerraformResource
CdktfStack() cdktf.TerraformStack
Connection() interface{}
SetConnection(val interface{})
ConstructNodeMetadata() *map[string]interface{}
Count() interface{}
// Experimental.
DependsOn() *[]*string
SetDependsOn(val *[]*string)
ForEach() cdktf.ITerraformIterator
SetForEach(val cdktf.ITerraformIterator)
Fqn() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Node() constructs.Node
Provider() cdktf.TerraformProvider
SetProvider(val cdktf.TerraformProvider)
Provisioners() *[]interface{}
SetProvisioners(val *[]interface{})
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformMetaArguments() *map[string]interface{}
// Experimental.
// Experimental.
AddMoveTarget(moveTarget *string)
AddOverride(path *string, value interface{})
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
HasResourceMove() interface{}
ImportFrom(id *string, provider cdktf.TerraformProvider)
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ToHclTerraform() interface{}
ToMetadata() interface{}
ToString() *string
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/compute_shared_vpc_service_project google_compute_shared_vpc_service_project}.
func NewComputeSharedVpcServiceProject ¶
func NewComputeSharedVpcServiceProject(scope constructs.Construct, id *string, config *ComputeSharedVpcServiceProjectConfig) ComputeSharedVpcServiceProject
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/compute_shared_vpc_service_project google_compute_shared_vpc_service_project} Resource.
type ComputeSharedVpcServiceProjectConfig ¶
type ComputeSharedVpcServiceProjectConfig struct {
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
Count interface{} `field:"optional" json:"count" yaml:"count"`
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/compute_shared_vpc_service_project#host_project ComputeSharedVpcServiceProject#host_project}
HostProject *string `field:"required" json:"hostProject" yaml:"hostProject"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/compute_shared_vpc_service_project#service_project ComputeSharedVpcServiceProject#service_project}
ServiceProject *string `field:"required" json:"serviceProject" yaml:"serviceProject"`
//
// Setting ABANDON allows the resource
// to be abandoned rather than deleted. Possible values are: "ABANDON".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/compute_shared_vpc_service_project#deletion_policy ComputeSharedVpcServiceProject#deletion_policy}
DeletionPolicy *string `field:"optional" json:"deletionPolicy" yaml:"deletionPolicy"`
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/compute_shared_vpc_service_project#timeouts ComputeSharedVpcServiceProject#timeouts}
Timeouts *ComputeSharedVpcServiceProjectTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type ComputeSharedVpcServiceProjectTimeoutsOutputReference ¶
type ComputeSharedVpcServiceProjectTimeoutsOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeSharedVpcServiceProjectTimeoutsOutputReference ¶
func NewComputeSharedVpcServiceProjectTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputeSharedVpcServiceProjectTimeoutsOutputReference