Documentation
¶
Index ¶
- func DataGoogleComputeForwardingRule_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataGoogleComputeForwardingRule_IsConstruct(x interface{}) *bool
- func DataGoogleComputeForwardingRule_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleComputeForwardingRule_IsTerraformElement(x interface{}) *bool
- func DataGoogleComputeForwardingRule_TfResourceType() *string
- func NewDataGoogleComputeForwardingRuleServiceDirectoryRegistrationsList_Override(d DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsList, ...)
- func NewDataGoogleComputeForwardingRuleServiceDirectoryRegistrationsOutputReference_Override(d DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsOutputReference, ...)
- func NewDataGoogleComputeForwardingRule_Override(d DataGoogleComputeForwardingRule, scope constructs.Construct, id *string, ...)
- type DataGoogleComputeForwardingRule
- type DataGoogleComputeForwardingRuleConfig
- type DataGoogleComputeForwardingRuleServiceDirectoryRegistrations
- type DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsList
- type DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleComputeForwardingRule_GenerateConfigForImport ¶
func DataGoogleComputeForwardingRule_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataGoogleComputeForwardingRule resource upon running "cdktf plan <stack-name>".
func DataGoogleComputeForwardingRule_IsConstruct ¶
func DataGoogleComputeForwardingRule_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleComputeForwardingRule_IsTerraformDataSource ¶
func DataGoogleComputeForwardingRule_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleComputeForwardingRule_IsTerraformElement ¶
func DataGoogleComputeForwardingRule_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleComputeForwardingRule_TfResourceType ¶
func DataGoogleComputeForwardingRule_TfResourceType() *string
func NewDataGoogleComputeForwardingRuleServiceDirectoryRegistrationsList_Override ¶
func NewDataGoogleComputeForwardingRuleServiceDirectoryRegistrationsList_Override(d DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleComputeForwardingRuleServiceDirectoryRegistrationsOutputReference_Override ¶
func NewDataGoogleComputeForwardingRuleServiceDirectoryRegistrationsOutputReference_Override(d DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleComputeForwardingRule_Override ¶
func NewDataGoogleComputeForwardingRule_Override(d DataGoogleComputeForwardingRule, scope constructs.Construct, id *string, config *DataGoogleComputeForwardingRuleConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/compute_forwarding_rule google_compute_forwarding_rule} Data Source.
Types ¶
type DataGoogleComputeForwardingRule ¶
type DataGoogleComputeForwardingRule interface {
cdktf.TerraformDataSource
AllowGlobalAccess() cdktf.IResolvable
AllowPscGlobalAccess() cdktf.IResolvable
AllPorts() cdktf.IResolvable
BackendService() *string
BaseForwardingRule() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreationTimestamp() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IpAddress() *string
IpProtocol() *string
IpVersion() *string
IsMirroringCollector() cdktf.IResolvable
LabelFingerprint() *string
Labels() cdktf.StringMap
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoadBalancingScheme() *string
Name() *string
SetName(val *string)
NameInput() *string
Network() *string
NetworkTier() *string
NoAutomateDnsZone() cdktf.IResolvable
// The tree node.
Node() constructs.Node
PortRange() *string
Ports() *[]*string
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
PscConnectionId() *string
PscConnectionStatus() *string
// Experimental.
RawOverrides() interface{}
RecreateClosedPsc() cdktf.IResolvable
Region() *string
SetRegion(val *string)
RegionInput() *string
SelfLink() *string
ServiceDirectoryRegistrations() DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsList
ServiceLabel() *string
ServiceName() *string
SourceIpRanges() *[]*string
Subnetwork() *string
Target() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Adds this resource to the terraform JSON output.
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/compute_forwarding_rule google_compute_forwarding_rule}.
func NewDataGoogleComputeForwardingRule ¶
func NewDataGoogleComputeForwardingRule(scope constructs.Construct, id *string, config *DataGoogleComputeForwardingRuleConfig) DataGoogleComputeForwardingRule
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/compute_forwarding_rule google_compute_forwarding_rule} Data Source.
type DataGoogleComputeForwardingRuleConfig ¶
type DataGoogleComputeForwardingRuleConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Name of the resource;
//
// provided by the client when the resource is created.
// The name must be 1-63 characters long, and comply with
// [RFC1035](https://www.ietf.org/rfc/rfc1035.txt).
//
// Specifically, the name must be 1-63 characters long and match the regular
// expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the first
// character must be a lowercase letter, and all following characters must
// be a dash, lowercase letter, or digit, except the last character, which
// cannot be a dash.
//
// For Private Service Connect forwarding rules that forward traffic to Google
// APIs, the forwarding rule name must be a 1-20 characters string with
// lowercase letters and numbers and must start with a letter.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/compute_forwarding_rule#name DataGoogleComputeForwardingRule#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/compute_forwarding_rule#id DataGoogleComputeForwardingRule#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/compute_forwarding_rule#project DataGoogleComputeForwardingRule#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// A reference to the region where the regional forwarding rule resides.
//
// This field is not applicable to global forwarding rules.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/compute_forwarding_rule#region DataGoogleComputeForwardingRule#region}
Region *string `field:"optional" json:"region" yaml:"region"`
}
type DataGoogleComputeForwardingRuleServiceDirectoryRegistrations ¶
type DataGoogleComputeForwardingRuleServiceDirectoryRegistrations struct {
}
type DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsList ¶
type DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleComputeForwardingRuleServiceDirectoryRegistrationsList ¶
func NewDataGoogleComputeForwardingRuleServiceDirectoryRegistrationsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsList
type DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsOutputReference ¶
type DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleComputeForwardingRuleServiceDirectoryRegistrations
SetInternalValue(val *DataGoogleComputeForwardingRuleServiceDirectoryRegistrations)
Namespace() *string
Service() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleComputeForwardingRuleServiceDirectoryRegistrationsOutputReference ¶
func NewDataGoogleComputeForwardingRuleServiceDirectoryRegistrationsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsOutputReference
Source Files
¶
- DataGoogleComputeForwardingRule.go
- DataGoogleComputeForwardingRuleConfig.go
- DataGoogleComputeForwardingRuleServiceDirectoryRegistrations.go
- DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsList.go
- DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsList__checks.go
- DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsOutputReference.go
- DataGoogleComputeForwardingRuleServiceDirectoryRegistrationsOutputReference__checks.go
- DataGoogleComputeForwardingRule__checks.go
- main.go