Documentation
¶
Index ¶
- func DataGoogleRedisInstance_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataGoogleRedisInstance_IsConstruct(x interface{}) *bool
- func DataGoogleRedisInstance_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleRedisInstance_IsTerraformElement(x interface{}) *bool
- func DataGoogleRedisInstance_TfResourceType() *string
- func NewDataGoogleRedisInstanceMaintenancePolicyList_Override(d DataGoogleRedisInstanceMaintenancePolicyList, ...)
- func NewDataGoogleRedisInstanceMaintenancePolicyOutputReference_Override(d DataGoogleRedisInstanceMaintenancePolicyOutputReference, ...)
- func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowList_Override(d DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowList, ...)
- func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference_Override(...)
- func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList_Override(d DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList, ...)
- func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference_Override(...)
- func NewDataGoogleRedisInstanceMaintenanceScheduleList_Override(d DataGoogleRedisInstanceMaintenanceScheduleList, ...)
- func NewDataGoogleRedisInstanceMaintenanceScheduleOutputReference_Override(d DataGoogleRedisInstanceMaintenanceScheduleOutputReference, ...)
- func NewDataGoogleRedisInstanceNodesList_Override(d DataGoogleRedisInstanceNodesList, ...)
- func NewDataGoogleRedisInstanceNodesOutputReference_Override(d DataGoogleRedisInstanceNodesOutputReference, ...)
- func NewDataGoogleRedisInstancePersistenceConfigList_Override(d DataGoogleRedisInstancePersistenceConfigList, ...)
- func NewDataGoogleRedisInstancePersistenceConfigOutputReference_Override(d DataGoogleRedisInstancePersistenceConfigOutputReference, ...)
- func NewDataGoogleRedisInstanceServerCaCertsList_Override(d DataGoogleRedisInstanceServerCaCertsList, ...)
- func NewDataGoogleRedisInstanceServerCaCertsOutputReference_Override(d DataGoogleRedisInstanceServerCaCertsOutputReference, ...)
- func NewDataGoogleRedisInstance_Override(d DataGoogleRedisInstance, scope constructs.Construct, id *string, ...)
- type DataGoogleRedisInstance
- type DataGoogleRedisInstanceConfig
- type DataGoogleRedisInstanceMaintenancePolicy
- type DataGoogleRedisInstanceMaintenancePolicyList
- type DataGoogleRedisInstanceMaintenancePolicyOutputReference
- type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindow
- type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowList
- type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference
- type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime
- type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList
- type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference
- type DataGoogleRedisInstanceMaintenanceSchedule
- type DataGoogleRedisInstanceMaintenanceScheduleList
- type DataGoogleRedisInstanceMaintenanceScheduleOutputReference
- type DataGoogleRedisInstanceNodes
- type DataGoogleRedisInstanceNodesList
- type DataGoogleRedisInstanceNodesOutputReference
- type DataGoogleRedisInstancePersistenceConfig
- type DataGoogleRedisInstancePersistenceConfigList
- type DataGoogleRedisInstancePersistenceConfigOutputReference
- type DataGoogleRedisInstanceServerCaCerts
- type DataGoogleRedisInstanceServerCaCertsList
- type DataGoogleRedisInstanceServerCaCertsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleRedisInstance_GenerateConfigForImport ¶
func DataGoogleRedisInstance_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataGoogleRedisInstance resource upon running "cdktf plan <stack-name>".
func DataGoogleRedisInstance_IsConstruct ¶
func DataGoogleRedisInstance_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleRedisInstance_IsTerraformDataSource ¶
func DataGoogleRedisInstance_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleRedisInstance_IsTerraformElement ¶
func DataGoogleRedisInstance_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleRedisInstance_TfResourceType ¶
func DataGoogleRedisInstance_TfResourceType() *string
func NewDataGoogleRedisInstanceMaintenancePolicyList_Override ¶
func NewDataGoogleRedisInstanceMaintenancePolicyList_Override(d DataGoogleRedisInstanceMaintenancePolicyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleRedisInstanceMaintenancePolicyOutputReference_Override ¶
func NewDataGoogleRedisInstanceMaintenancePolicyOutputReference_Override(d DataGoogleRedisInstanceMaintenancePolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowList_Override ¶
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowList_Override(d DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference_Override ¶
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference_Override(d DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList_Override ¶
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList_Override(d DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference_Override ¶
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference_Override(d DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleRedisInstanceMaintenanceScheduleList_Override ¶
func NewDataGoogleRedisInstanceMaintenanceScheduleList_Override(d DataGoogleRedisInstanceMaintenanceScheduleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleRedisInstanceMaintenanceScheduleOutputReference_Override ¶
func NewDataGoogleRedisInstanceMaintenanceScheduleOutputReference_Override(d DataGoogleRedisInstanceMaintenanceScheduleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleRedisInstanceNodesList_Override ¶
func NewDataGoogleRedisInstanceNodesList_Override(d DataGoogleRedisInstanceNodesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleRedisInstanceNodesOutputReference_Override ¶
func NewDataGoogleRedisInstanceNodesOutputReference_Override(d DataGoogleRedisInstanceNodesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleRedisInstancePersistenceConfigList_Override ¶
func NewDataGoogleRedisInstancePersistenceConfigList_Override(d DataGoogleRedisInstancePersistenceConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleRedisInstancePersistenceConfigOutputReference_Override ¶
func NewDataGoogleRedisInstancePersistenceConfigOutputReference_Override(d DataGoogleRedisInstancePersistenceConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleRedisInstanceServerCaCertsList_Override ¶
func NewDataGoogleRedisInstanceServerCaCertsList_Override(d DataGoogleRedisInstanceServerCaCertsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleRedisInstanceServerCaCertsOutputReference_Override ¶
func NewDataGoogleRedisInstanceServerCaCertsOutputReference_Override(d DataGoogleRedisInstanceServerCaCertsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleRedisInstance_Override ¶
func NewDataGoogleRedisInstance_Override(d DataGoogleRedisInstance, scope constructs.Construct, id *string, config *DataGoogleRedisInstanceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/redis_instance google_redis_instance} Data Source.
Types ¶
type DataGoogleRedisInstance ¶
type DataGoogleRedisInstance interface {
cdktf.TerraformDataSource
AlternativeLocationId() *string
AuthEnabled() cdktf.IResolvable
AuthorizedNetwork() *string
AuthString() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ConnectMode() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
CurrentLocationId() *string
CustomerManagedKey() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Host() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() cdktf.StringMap
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LocationId() *string
MaintenancePolicy() DataGoogleRedisInstanceMaintenancePolicyList
MaintenanceSchedule() DataGoogleRedisInstanceMaintenanceScheduleList
MaintenanceVersion() *string
MemorySizeGb() *float64
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Nodes() DataGoogleRedisInstanceNodesList
PersistenceConfig() DataGoogleRedisInstancePersistenceConfigList
PersistenceIamIdentity() *string
Port() *float64
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
ReadEndpoint() *string
ReadEndpointPort() *float64
ReadReplicasMode() *string
RedisConfigs() cdktf.StringMap
RedisVersion() *string
Region() *string
SetRegion(val *string)
RegionInput() *string
ReplicaCount() *float64
ReservedIpRange() *string
SecondaryIpRange() *string
ServerCaCerts() DataGoogleRedisInstanceServerCaCertsList
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Tier() *string
TransitEncryptionMode() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Adds this resource to the terraform JSON output.
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/redis_instance google_redis_instance}.
func NewDataGoogleRedisInstance ¶
func NewDataGoogleRedisInstance(scope constructs.Construct, id *string, config *DataGoogleRedisInstanceConfig) DataGoogleRedisInstance
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/redis_instance google_redis_instance} Data Source.
type DataGoogleRedisInstanceConfig ¶
type DataGoogleRedisInstanceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The ID of the instance or a fully qualified identifier for the instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/redis_instance#name DataGoogleRedisInstance#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/redis_instance#id DataGoogleRedisInstance#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/redis_instance#project DataGoogleRedisInstance#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// The name of the Redis region of the instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/redis_instance#region DataGoogleRedisInstance#region}
Region *string `field:"optional" json:"region" yaml:"region"`
}
type DataGoogleRedisInstanceMaintenancePolicy ¶
type DataGoogleRedisInstanceMaintenancePolicy struct {
}
type DataGoogleRedisInstanceMaintenancePolicyList ¶
type DataGoogleRedisInstanceMaintenancePolicyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleRedisInstanceMaintenancePolicyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleRedisInstanceMaintenancePolicyList ¶
func NewDataGoogleRedisInstanceMaintenancePolicyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleRedisInstanceMaintenancePolicyList
type DataGoogleRedisInstanceMaintenancePolicyOutputReference ¶
type DataGoogleRedisInstanceMaintenancePolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CreateTime() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleRedisInstanceMaintenancePolicy
SetInternalValue(val *DataGoogleRedisInstanceMaintenancePolicy)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UpdateTime() *string
WeeklyMaintenanceWindow() DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowList
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleRedisInstanceMaintenancePolicyOutputReference ¶
func NewDataGoogleRedisInstanceMaintenancePolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleRedisInstanceMaintenancePolicyOutputReference
type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindow ¶
type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindow struct {
}
type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowList ¶
type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowList ¶
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowList
type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference ¶
type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Day() *string
Duration() *string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindow
SetInternalValue(val *DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindow)
StartTime() DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference ¶
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference
type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime ¶
type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime struct {
}
type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList ¶
type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList ¶
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList
type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference ¶
type DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Hours() *float64
InternalValue() *DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime
SetInternalValue(val *DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime)
Minutes() *float64
Nanos() *float64
Seconds() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference ¶
func NewDataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference
type DataGoogleRedisInstanceMaintenanceSchedule ¶
type DataGoogleRedisInstanceMaintenanceSchedule struct {
}
type DataGoogleRedisInstanceMaintenanceScheduleList ¶
type DataGoogleRedisInstanceMaintenanceScheduleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleRedisInstanceMaintenanceScheduleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleRedisInstanceMaintenanceScheduleList ¶
func NewDataGoogleRedisInstanceMaintenanceScheduleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleRedisInstanceMaintenanceScheduleList
type DataGoogleRedisInstanceMaintenanceScheduleOutputReference ¶
type DataGoogleRedisInstanceMaintenanceScheduleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EndTime() *string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleRedisInstanceMaintenanceSchedule
SetInternalValue(val *DataGoogleRedisInstanceMaintenanceSchedule)
ScheduleDeadlineTime() *string
StartTime() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleRedisInstanceMaintenanceScheduleOutputReference ¶
func NewDataGoogleRedisInstanceMaintenanceScheduleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleRedisInstanceMaintenanceScheduleOutputReference
type DataGoogleRedisInstanceNodes ¶
type DataGoogleRedisInstanceNodes struct {
}
type DataGoogleRedisInstanceNodesList ¶
type DataGoogleRedisInstanceNodesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleRedisInstanceNodesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleRedisInstanceNodesList ¶
func NewDataGoogleRedisInstanceNodesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleRedisInstanceNodesList
type DataGoogleRedisInstanceNodesOutputReference ¶
type DataGoogleRedisInstanceNodesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataGoogleRedisInstanceNodes
SetInternalValue(val *DataGoogleRedisInstanceNodes)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Zone() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleRedisInstanceNodesOutputReference ¶
func NewDataGoogleRedisInstanceNodesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleRedisInstanceNodesOutputReference
type DataGoogleRedisInstancePersistenceConfig ¶
type DataGoogleRedisInstancePersistenceConfig struct {
}
type DataGoogleRedisInstancePersistenceConfigList ¶
type DataGoogleRedisInstancePersistenceConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleRedisInstancePersistenceConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleRedisInstancePersistenceConfigList ¶
func NewDataGoogleRedisInstancePersistenceConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleRedisInstancePersistenceConfigList
type DataGoogleRedisInstancePersistenceConfigOutputReference ¶
type DataGoogleRedisInstancePersistenceConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleRedisInstancePersistenceConfig
SetInternalValue(val *DataGoogleRedisInstancePersistenceConfig)
PersistenceMode() *string
RdbNextSnapshotTime() *string
RdbSnapshotPeriod() *string
RdbSnapshotStartTime() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleRedisInstancePersistenceConfigOutputReference ¶
func NewDataGoogleRedisInstancePersistenceConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleRedisInstancePersistenceConfigOutputReference
type DataGoogleRedisInstanceServerCaCerts ¶
type DataGoogleRedisInstanceServerCaCerts struct {
}
type DataGoogleRedisInstanceServerCaCertsList ¶
type DataGoogleRedisInstanceServerCaCertsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleRedisInstanceServerCaCertsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleRedisInstanceServerCaCertsList ¶
func NewDataGoogleRedisInstanceServerCaCertsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleRedisInstanceServerCaCertsList
type DataGoogleRedisInstanceServerCaCertsOutputReference ¶
type DataGoogleRedisInstanceServerCaCertsOutputReference interface {
cdktf.ComplexObject
Cert() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CreateTime() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ExpireTime() *string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleRedisInstanceServerCaCerts
SetInternalValue(val *DataGoogleRedisInstanceServerCaCerts)
SerialNumber() *string
Sha1Fingerprint() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleRedisInstanceServerCaCertsOutputReference ¶
func NewDataGoogleRedisInstanceServerCaCertsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleRedisInstanceServerCaCertsOutputReference
Source Files
¶
- DataGoogleRedisInstance.go
- DataGoogleRedisInstanceConfig.go
- DataGoogleRedisInstanceMaintenancePolicy.go
- DataGoogleRedisInstanceMaintenancePolicyList.go
- DataGoogleRedisInstanceMaintenancePolicyList__checks.go
- DataGoogleRedisInstanceMaintenancePolicyOutputReference.go
- DataGoogleRedisInstanceMaintenancePolicyOutputReference__checks.go
- DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindow.go
- DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowList.go
- DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowList__checks.go
- DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference.go
- DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference__checks.go
- DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime.go
- DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList.go
- DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList__checks.go
- DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference.go
- DataGoogleRedisInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference__checks.go
- DataGoogleRedisInstanceMaintenanceSchedule.go
- DataGoogleRedisInstanceMaintenanceScheduleList.go
- DataGoogleRedisInstanceMaintenanceScheduleList__checks.go
- DataGoogleRedisInstanceMaintenanceScheduleOutputReference.go
- DataGoogleRedisInstanceMaintenanceScheduleOutputReference__checks.go
- DataGoogleRedisInstanceNodes.go
- DataGoogleRedisInstanceNodesList.go
- DataGoogleRedisInstanceNodesList__checks.go
- DataGoogleRedisInstanceNodesOutputReference.go
- DataGoogleRedisInstanceNodesOutputReference__checks.go
- DataGoogleRedisInstancePersistenceConfig.go
- DataGoogleRedisInstancePersistenceConfigList.go
- DataGoogleRedisInstancePersistenceConfigList__checks.go
- DataGoogleRedisInstancePersistenceConfigOutputReference.go
- DataGoogleRedisInstancePersistenceConfigOutputReference__checks.go
- DataGoogleRedisInstanceServerCaCerts.go
- DataGoogleRedisInstanceServerCaCertsList.go
- DataGoogleRedisInstanceServerCaCertsList__checks.go
- DataGoogleRedisInstanceServerCaCertsOutputReference.go
- DataGoogleRedisInstanceServerCaCertsOutputReference__checks.go
- DataGoogleRedisInstance__checks.go
- main.go