Documentation
¶
Index ¶
- func DataGoogleVmwareenginePrivateCloud_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataGoogleVmwareenginePrivateCloud_IsConstruct(x interface{}) *bool
- func DataGoogleVmwareenginePrivateCloud_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleVmwareenginePrivateCloud_IsTerraformElement(x interface{}) *bool
- func DataGoogleVmwareenginePrivateCloud_TfResourceType() *string
- func NewDataGoogleVmwareenginePrivateCloudHcxList_Override(d DataGoogleVmwareenginePrivateCloudHcxList, ...)
- func NewDataGoogleVmwareenginePrivateCloudHcxOutputReference_Override(d DataGoogleVmwareenginePrivateCloudHcxOutputReference, ...)
- func NewDataGoogleVmwareenginePrivateCloudManagementClusterList_Override(d DataGoogleVmwareenginePrivateCloudManagementClusterList, ...)
- func NewDataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsList_Override(d DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsList, ...)
- func NewDataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsOutputReference_Override(...)
- func NewDataGoogleVmwareenginePrivateCloudManagementClusterOutputReference_Override(d DataGoogleVmwareenginePrivateCloudManagementClusterOutputReference, ...)
- func NewDataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigList_Override(...)
- func NewDataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigOutputReference_Override(...)
- func NewDataGoogleVmwareenginePrivateCloudNetworkConfigList_Override(d DataGoogleVmwareenginePrivateCloudNetworkConfigList, ...)
- func NewDataGoogleVmwareenginePrivateCloudNetworkConfigOutputReference_Override(d DataGoogleVmwareenginePrivateCloudNetworkConfigOutputReference, ...)
- func NewDataGoogleVmwareenginePrivateCloudNsxList_Override(d DataGoogleVmwareenginePrivateCloudNsxList, ...)
- func NewDataGoogleVmwareenginePrivateCloudNsxOutputReference_Override(d DataGoogleVmwareenginePrivateCloudNsxOutputReference, ...)
- func NewDataGoogleVmwareenginePrivateCloudVcenterList_Override(d DataGoogleVmwareenginePrivateCloudVcenterList, ...)
- func NewDataGoogleVmwareenginePrivateCloudVcenterOutputReference_Override(d DataGoogleVmwareenginePrivateCloudVcenterOutputReference, ...)
- func NewDataGoogleVmwareenginePrivateCloud_Override(d DataGoogleVmwareenginePrivateCloud, scope constructs.Construct, id *string, ...)
- type DataGoogleVmwareenginePrivateCloud
- type DataGoogleVmwareenginePrivateCloudConfig
- type DataGoogleVmwareenginePrivateCloudHcx
- type DataGoogleVmwareenginePrivateCloudHcxList
- type DataGoogleVmwareenginePrivateCloudHcxOutputReference
- type DataGoogleVmwareenginePrivateCloudManagementCluster
- type DataGoogleVmwareenginePrivateCloudManagementClusterList
- type DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigs
- type DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsList
- type DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsOutputReference
- type DataGoogleVmwareenginePrivateCloudManagementClusterOutputReference
- type DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfig
- type DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigList
- type DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigOutputReference
- type DataGoogleVmwareenginePrivateCloudNetworkConfig
- type DataGoogleVmwareenginePrivateCloudNetworkConfigList
- type DataGoogleVmwareenginePrivateCloudNetworkConfigOutputReference
- type DataGoogleVmwareenginePrivateCloudNsx
- type DataGoogleVmwareenginePrivateCloudNsxList
- type DataGoogleVmwareenginePrivateCloudNsxOutputReference
- type DataGoogleVmwareenginePrivateCloudVcenter
- type DataGoogleVmwareenginePrivateCloudVcenterList
- type DataGoogleVmwareenginePrivateCloudVcenterOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleVmwareenginePrivateCloud_GenerateConfigForImport ¶
func DataGoogleVmwareenginePrivateCloud_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataGoogleVmwareenginePrivateCloud resource upon running "cdktf plan <stack-name>".
func DataGoogleVmwareenginePrivateCloud_IsConstruct ¶
func DataGoogleVmwareenginePrivateCloud_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleVmwareenginePrivateCloud_IsTerraformDataSource ¶
func DataGoogleVmwareenginePrivateCloud_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleVmwareenginePrivateCloud_IsTerraformElement ¶
func DataGoogleVmwareenginePrivateCloud_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleVmwareenginePrivateCloud_TfResourceType ¶
func DataGoogleVmwareenginePrivateCloud_TfResourceType() *string
func NewDataGoogleVmwareenginePrivateCloudHcxList_Override ¶
func NewDataGoogleVmwareenginePrivateCloudHcxList_Override(d DataGoogleVmwareenginePrivateCloudHcxList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleVmwareenginePrivateCloudHcxOutputReference_Override ¶
func NewDataGoogleVmwareenginePrivateCloudHcxOutputReference_Override(d DataGoogleVmwareenginePrivateCloudHcxOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleVmwareenginePrivateCloudManagementClusterList_Override ¶
func NewDataGoogleVmwareenginePrivateCloudManagementClusterList_Override(d DataGoogleVmwareenginePrivateCloudManagementClusterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsList_Override ¶
func NewDataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsList_Override(d DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsOutputReference_Override ¶
func NewDataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsOutputReference_Override(d DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleVmwareenginePrivateCloudManagementClusterOutputReference_Override ¶
func NewDataGoogleVmwareenginePrivateCloudManagementClusterOutputReference_Override(d DataGoogleVmwareenginePrivateCloudManagementClusterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigList_Override ¶ added in v13.15.0
func NewDataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigList_Override(d DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigOutputReference_Override ¶ added in v13.15.0
func NewDataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigOutputReference_Override(d DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleVmwareenginePrivateCloudNetworkConfigList_Override ¶
func NewDataGoogleVmwareenginePrivateCloudNetworkConfigList_Override(d DataGoogleVmwareenginePrivateCloudNetworkConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleVmwareenginePrivateCloudNetworkConfigOutputReference_Override ¶
func NewDataGoogleVmwareenginePrivateCloudNetworkConfigOutputReference_Override(d DataGoogleVmwareenginePrivateCloudNetworkConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleVmwareenginePrivateCloudNsxList_Override ¶
func NewDataGoogleVmwareenginePrivateCloudNsxList_Override(d DataGoogleVmwareenginePrivateCloudNsxList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleVmwareenginePrivateCloudNsxOutputReference_Override ¶
func NewDataGoogleVmwareenginePrivateCloudNsxOutputReference_Override(d DataGoogleVmwareenginePrivateCloudNsxOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleVmwareenginePrivateCloudVcenterList_Override ¶
func NewDataGoogleVmwareenginePrivateCloudVcenterList_Override(d DataGoogleVmwareenginePrivateCloudVcenterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleVmwareenginePrivateCloudVcenterOutputReference_Override ¶
func NewDataGoogleVmwareenginePrivateCloudVcenterOutputReference_Override(d DataGoogleVmwareenginePrivateCloudVcenterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleVmwareenginePrivateCloud_Override ¶
func NewDataGoogleVmwareenginePrivateCloud_Override(d DataGoogleVmwareenginePrivateCloud, scope constructs.Construct, id *string, config *DataGoogleVmwareenginePrivateCloudConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/vmwareengine_private_cloud google_vmwareengine_private_cloud} Data Source.
Types ¶
type DataGoogleVmwareenginePrivateCloud ¶
type DataGoogleVmwareenginePrivateCloud interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DeletionDelayHours() *float64
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Hcx() DataGoogleVmwareenginePrivateCloudHcxList
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
ManagementCluster() DataGoogleVmwareenginePrivateCloudManagementClusterList
Name() *string
SetName(val *string)
NameInput() *string
NetworkConfig() DataGoogleVmwareenginePrivateCloudNetworkConfigList
// The tree node.
Node() constructs.Node
Nsx() DataGoogleVmwareenginePrivateCloudNsxList
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
SendDeletionDelayHoursIfZero() cdktf.IResolvable
State() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
Uid() *string
Vcenter() DataGoogleVmwareenginePrivateCloudVcenterList
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Adds this resource to the terraform JSON output.
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/vmwareengine_private_cloud google_vmwareengine_private_cloud}.
func NewDataGoogleVmwareenginePrivateCloud ¶
func NewDataGoogleVmwareenginePrivateCloud(scope constructs.Construct, id *string, config *DataGoogleVmwareenginePrivateCloudConfig) DataGoogleVmwareenginePrivateCloud
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/vmwareengine_private_cloud google_vmwareengine_private_cloud} Data Source.
type DataGoogleVmwareenginePrivateCloudConfig ¶
type DataGoogleVmwareenginePrivateCloudConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The location where the PrivateCloud should reside.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/vmwareengine_private_cloud#location DataGoogleVmwareenginePrivateCloud#location}
Location *string `field:"required" json:"location" yaml:"location"`
// The ID of the PrivateCloud.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/vmwareengine_private_cloud#name DataGoogleVmwareenginePrivateCloud#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/vmwareengine_private_cloud#id DataGoogleVmwareenginePrivateCloud#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/data-sources/vmwareengine_private_cloud#project DataGoogleVmwareenginePrivateCloud#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
}
type DataGoogleVmwareenginePrivateCloudHcx ¶
type DataGoogleVmwareenginePrivateCloudHcx struct {
}
type DataGoogleVmwareenginePrivateCloudHcxList ¶
type DataGoogleVmwareenginePrivateCloudHcxList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleVmwareenginePrivateCloudHcxOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareenginePrivateCloudHcxList ¶
func NewDataGoogleVmwareenginePrivateCloudHcxList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleVmwareenginePrivateCloudHcxList
type DataGoogleVmwareenginePrivateCloudHcxOutputReference ¶
type DataGoogleVmwareenginePrivateCloudHcxOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Fqdn() *string
// Experimental.
Fqn() *string
InternalIp() *string
InternalValue() *DataGoogleVmwareenginePrivateCloudHcx
SetInternalValue(val *DataGoogleVmwareenginePrivateCloudHcx)
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Version() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareenginePrivateCloudHcxOutputReference ¶
func NewDataGoogleVmwareenginePrivateCloudHcxOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleVmwareenginePrivateCloudHcxOutputReference
type DataGoogleVmwareenginePrivateCloudManagementCluster ¶
type DataGoogleVmwareenginePrivateCloudManagementCluster struct {
}
type DataGoogleVmwareenginePrivateCloudManagementClusterList ¶
type DataGoogleVmwareenginePrivateCloudManagementClusterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleVmwareenginePrivateCloudManagementClusterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareenginePrivateCloudManagementClusterList ¶
func NewDataGoogleVmwareenginePrivateCloudManagementClusterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleVmwareenginePrivateCloudManagementClusterList
type DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigs ¶
type DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigs struct {
}
type DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsList ¶
type DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsList ¶
func NewDataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsList
type DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsOutputReference ¶
type DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CustomCoreCount() *float64
// Experimental.
Fqn() *string
InternalValue() *DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigs
SetInternalValue(val *DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigs)
NodeCount() *float64
NodeTypeId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsOutputReference ¶
func NewDataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsOutputReference
type DataGoogleVmwareenginePrivateCloudManagementClusterOutputReference ¶
type DataGoogleVmwareenginePrivateCloudManagementClusterOutputReference interface {
cdktf.ComplexObject
ClusterId() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleVmwareenginePrivateCloudManagementCluster
SetInternalValue(val *DataGoogleVmwareenginePrivateCloudManagementCluster)
NodeTypeConfigs() DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsList
StretchedClusterConfig() DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareenginePrivateCloudManagementClusterOutputReference ¶
func NewDataGoogleVmwareenginePrivateCloudManagementClusterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleVmwareenginePrivateCloudManagementClusterOutputReference
type DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfig ¶ added in v13.15.0
type DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfig struct {
}
type DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigList ¶ added in v13.15.0
type DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigList ¶ added in v13.15.0
func NewDataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigList
type DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigOutputReference ¶ added in v13.15.0
type DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfig
SetInternalValue(val *DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfig)
PreferredLocation() *string
SecondaryLocation() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigOutputReference ¶ added in v13.15.0
func NewDataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigOutputReference
type DataGoogleVmwareenginePrivateCloudNetworkConfig ¶
type DataGoogleVmwareenginePrivateCloudNetworkConfig struct {
}
type DataGoogleVmwareenginePrivateCloudNetworkConfigList ¶
type DataGoogleVmwareenginePrivateCloudNetworkConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleVmwareenginePrivateCloudNetworkConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareenginePrivateCloudNetworkConfigList ¶
func NewDataGoogleVmwareenginePrivateCloudNetworkConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleVmwareenginePrivateCloudNetworkConfigList
type DataGoogleVmwareenginePrivateCloudNetworkConfigOutputReference ¶
type DataGoogleVmwareenginePrivateCloudNetworkConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DnsServerIp() *string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleVmwareenginePrivateCloudNetworkConfig
SetInternalValue(val *DataGoogleVmwareenginePrivateCloudNetworkConfig)
ManagementCidr() *string
ManagementIpAddressLayoutVersion() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VmwareEngineNetwork() *string
VmwareEngineNetworkCanonical() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareenginePrivateCloudNetworkConfigOutputReference ¶
func NewDataGoogleVmwareenginePrivateCloudNetworkConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleVmwareenginePrivateCloudNetworkConfigOutputReference
type DataGoogleVmwareenginePrivateCloudNsx ¶
type DataGoogleVmwareenginePrivateCloudNsx struct {
}
type DataGoogleVmwareenginePrivateCloudNsxList ¶
type DataGoogleVmwareenginePrivateCloudNsxList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleVmwareenginePrivateCloudNsxOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareenginePrivateCloudNsxList ¶
func NewDataGoogleVmwareenginePrivateCloudNsxList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleVmwareenginePrivateCloudNsxList
type DataGoogleVmwareenginePrivateCloudNsxOutputReference ¶
type DataGoogleVmwareenginePrivateCloudNsxOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Fqdn() *string
// Experimental.
Fqn() *string
InternalIp() *string
InternalValue() *DataGoogleVmwareenginePrivateCloudNsx
SetInternalValue(val *DataGoogleVmwareenginePrivateCloudNsx)
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Version() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareenginePrivateCloudNsxOutputReference ¶
func NewDataGoogleVmwareenginePrivateCloudNsxOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleVmwareenginePrivateCloudNsxOutputReference
type DataGoogleVmwareenginePrivateCloudVcenter ¶
type DataGoogleVmwareenginePrivateCloudVcenter struct {
}
type DataGoogleVmwareenginePrivateCloudVcenterList ¶
type DataGoogleVmwareenginePrivateCloudVcenterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleVmwareenginePrivateCloudVcenterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareenginePrivateCloudVcenterList ¶
func NewDataGoogleVmwareenginePrivateCloudVcenterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleVmwareenginePrivateCloudVcenterList
type DataGoogleVmwareenginePrivateCloudVcenterOutputReference ¶
type DataGoogleVmwareenginePrivateCloudVcenterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Fqdn() *string
// Experimental.
Fqn() *string
InternalIp() *string
InternalValue() *DataGoogleVmwareenginePrivateCloudVcenter
SetInternalValue(val *DataGoogleVmwareenginePrivateCloudVcenter)
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Version() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareenginePrivateCloudVcenterOutputReference ¶
func NewDataGoogleVmwareenginePrivateCloudVcenterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleVmwareenginePrivateCloudVcenterOutputReference
Source Files
¶
- DataGoogleVmwareenginePrivateCloud.go
- DataGoogleVmwareenginePrivateCloudConfig.go
- DataGoogleVmwareenginePrivateCloudHcx.go
- DataGoogleVmwareenginePrivateCloudHcxList.go
- DataGoogleVmwareenginePrivateCloudHcxList__checks.go
- DataGoogleVmwareenginePrivateCloudHcxOutputReference.go
- DataGoogleVmwareenginePrivateCloudHcxOutputReference__checks.go
- DataGoogleVmwareenginePrivateCloudManagementCluster.go
- DataGoogleVmwareenginePrivateCloudManagementClusterList.go
- DataGoogleVmwareenginePrivateCloudManagementClusterList__checks.go
- DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigs.go
- DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsList.go
- DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsList__checks.go
- DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsOutputReference.go
- DataGoogleVmwareenginePrivateCloudManagementClusterNodeTypeConfigsOutputReference__checks.go
- DataGoogleVmwareenginePrivateCloudManagementClusterOutputReference.go
- DataGoogleVmwareenginePrivateCloudManagementClusterOutputReference__checks.go
- DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfig.go
- DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigList.go
- DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigList__checks.go
- DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigOutputReference.go
- DataGoogleVmwareenginePrivateCloudManagementClusterStretchedClusterConfigOutputReference__checks.go
- DataGoogleVmwareenginePrivateCloudNetworkConfig.go
- DataGoogleVmwareenginePrivateCloudNetworkConfigList.go
- DataGoogleVmwareenginePrivateCloudNetworkConfigList__checks.go
- DataGoogleVmwareenginePrivateCloudNetworkConfigOutputReference.go
- DataGoogleVmwareenginePrivateCloudNetworkConfigOutputReference__checks.go
- DataGoogleVmwareenginePrivateCloudNsx.go
- DataGoogleVmwareenginePrivateCloudNsxList.go
- DataGoogleVmwareenginePrivateCloudNsxList__checks.go
- DataGoogleVmwareenginePrivateCloudNsxOutputReference.go
- DataGoogleVmwareenginePrivateCloudNsxOutputReference__checks.go
- DataGoogleVmwareenginePrivateCloudVcenter.go
- DataGoogleVmwareenginePrivateCloudVcenterList.go
- DataGoogleVmwareenginePrivateCloudVcenterList__checks.go
- DataGoogleVmwareenginePrivateCloudVcenterOutputReference.go
- DataGoogleVmwareenginePrivateCloudVcenterOutputReference__checks.go
- DataGoogleVmwareenginePrivateCloud__checks.go
- main.go