Documentation
¶
Index ¶
- func GkeHubNamespace_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GkeHubNamespace_IsConstruct(x interface{}) *bool
- func GkeHubNamespace_IsTerraformElement(x interface{}) *bool
- func GkeHubNamespace_IsTerraformResource(x interface{}) *bool
- func GkeHubNamespace_TfResourceType() *string
- func NewGkeHubNamespaceStateList_Override(g GkeHubNamespaceStateList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewGkeHubNamespaceStateOutputReference_Override(g GkeHubNamespaceStateOutputReference, ...)
- func NewGkeHubNamespaceTimeoutsOutputReference_Override(g GkeHubNamespaceTimeoutsOutputReference, ...)
- func NewGkeHubNamespace_Override(g GkeHubNamespace, scope constructs.Construct, id *string, ...)
- type GkeHubNamespace
- type GkeHubNamespaceConfig
- type GkeHubNamespaceState
- type GkeHubNamespaceStateList
- type GkeHubNamespaceStateOutputReference
- type GkeHubNamespaceTimeouts
- type GkeHubNamespaceTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GkeHubNamespace_GenerateConfigForImport ¶
func GkeHubNamespace_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GkeHubNamespace resource upon running "cdktf plan <stack-name>".
func GkeHubNamespace_IsConstruct ¶
func GkeHubNamespace_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GkeHubNamespace_IsTerraformElement ¶
func GkeHubNamespace_IsTerraformElement(x interface{}) *bool
Experimental.
func GkeHubNamespace_IsTerraformResource ¶
func GkeHubNamespace_IsTerraformResource(x interface{}) *bool
Experimental.
func GkeHubNamespace_TfResourceType ¶
func GkeHubNamespace_TfResourceType() *string
func NewGkeHubNamespaceStateList_Override ¶
func NewGkeHubNamespaceStateList_Override(g GkeHubNamespaceStateList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGkeHubNamespaceStateOutputReference_Override ¶
func NewGkeHubNamespaceStateOutputReference_Override(g GkeHubNamespaceStateOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGkeHubNamespaceTimeoutsOutputReference_Override ¶
func NewGkeHubNamespaceTimeoutsOutputReference_Override(g GkeHubNamespaceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGkeHubNamespace_Override ¶
func NewGkeHubNamespace_Override(g GkeHubNamespace, scope constructs.Construct, id *string, config *GkeHubNamespaceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/gke_hub_namespace google_gke_hub_namespace} Resource.
Types ¶
type GkeHubNamespace ¶
type GkeHubNamespace interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
DeleteTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
NamespaceLabels() *map[string]*string
SetNamespaceLabels(val *map[string]*string)
NamespaceLabelsInput() *map[string]*string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Scope() *string
SetScope(val *string)
ScopeId() *string
SetScopeId(val *string)
ScopeIdInput() *string
ScopeInput() *string
ScopeNamespaceId() *string
SetScopeNamespaceId(val *string)
ScopeNamespaceIdInput() *string
State() GkeHubNamespaceStateList
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GkeHubNamespaceTimeoutsOutputReference
TimeoutsInput() interface{}
Uid() *string
UpdateTime() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *GkeHubNamespaceTimeouts)
ResetId()
ResetLabels()
ResetNamespaceLabels()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/gke_hub_namespace google_gke_hub_namespace}.
func NewGkeHubNamespace ¶
func NewGkeHubNamespace(scope constructs.Construct, id *string, config *GkeHubNamespaceConfig) GkeHubNamespace
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/gke_hub_namespace google_gke_hub_namespace} Resource.
type GkeHubNamespaceConfig ¶
type GkeHubNamespaceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The name of the Scope instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/gke_hub_namespace#scope GkeHubNamespace#scope}
Scope *string `field:"required" json:"scope" yaml:"scope"`
// Id of the scope.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/gke_hub_namespace#scope_id GkeHubNamespace#scope_id}
ScopeId *string `field:"required" json:"scopeId" yaml:"scopeId"`
// The client-provided identifier of the namespace.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/gke_hub_namespace#scope_namespace_id GkeHubNamespace#scope_namespace_id}
ScopeNamespaceId *string `field:"required" json:"scopeNamespaceId" yaml:"scopeNamespaceId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/gke_hub_namespace#id GkeHubNamespace#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Labels for this Namespace.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/gke_hub_namespace#labels GkeHubNamespace#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// Namespace-level cluster namespace labels.
//
// These labels are applied
// to the related namespace of the member clusters bound to the parent
// Scope. Scope-level labels ('namespace_labels' in the Fleet Scope
// resource) take precedence over Namespace-level labels if they share
// a key. Keys and values must be Kubernetes-conformant.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/gke_hub_namespace#namespace_labels GkeHubNamespace#namespace_labels}
NamespaceLabels *map[string]*string `field:"optional" json:"namespaceLabels" yaml:"namespaceLabels"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/gke_hub_namespace#project GkeHubNamespace#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/gke_hub_namespace#timeouts GkeHubNamespace#timeouts}
Timeouts *GkeHubNamespaceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GkeHubNamespaceState ¶
type GkeHubNamespaceState struct {
}
type GkeHubNamespaceStateList ¶
type GkeHubNamespaceStateList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GkeHubNamespaceStateOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGkeHubNamespaceStateList ¶
func NewGkeHubNamespaceStateList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GkeHubNamespaceStateList
type GkeHubNamespaceStateOutputReference ¶
type GkeHubNamespaceStateOutputReference interface {
cdktf.ComplexObject
Code() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GkeHubNamespaceState
SetInternalValue(val *GkeHubNamespaceState)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGkeHubNamespaceStateOutputReference ¶
func NewGkeHubNamespaceStateOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GkeHubNamespaceStateOutputReference
type GkeHubNamespaceTimeouts ¶
type GkeHubNamespaceTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/gke_hub_namespace#create GkeHubNamespace#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/gke_hub_namespace#delete GkeHubNamespace#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.43.1/docs/resources/gke_hub_namespace#update GkeHubNamespace#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GkeHubNamespaceTimeoutsOutputReference ¶
type GkeHubNamespaceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGkeHubNamespaceTimeoutsOutputReference ¶
func NewGkeHubNamespaceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GkeHubNamespaceTimeoutsOutputReference
Source Files
¶
- GkeHubNamespace.go
- GkeHubNamespaceConfig.go
- GkeHubNamespaceState.go
- GkeHubNamespaceStateList.go
- GkeHubNamespaceStateList__checks.go
- GkeHubNamespaceStateOutputReference.go
- GkeHubNamespaceStateOutputReference__checks.go
- GkeHubNamespaceTimeouts.go
- GkeHubNamespaceTimeoutsOutputReference.go
- GkeHubNamespaceTimeoutsOutputReference__checks.go
- GkeHubNamespace__checks.go
- main.go