Documentation
¶
Index ¶
- func NetappStoragePool_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func NetappStoragePool_IsConstruct(x interface{}) *bool
- func NetappStoragePool_IsTerraformElement(x interface{}) *bool
- func NetappStoragePool_IsTerraformResource(x interface{}) *bool
- func NetappStoragePool_TfResourceType() *string
- func NewNetappStoragePoolTimeoutsOutputReference_Override(n NetappStoragePoolTimeoutsOutputReference, ...)
- func NewNetappStoragePool_Override(n NetappStoragePool, scope constructs.Construct, id *string, ...)
- type NetappStoragePool
- type NetappStoragePoolConfig
- type NetappStoragePoolTimeouts
- type NetappStoragePoolTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NetappStoragePool_GenerateConfigForImport ¶
func NetappStoragePool_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a NetappStoragePool resource upon running "cdktf plan <stack-name>".
func NetappStoragePool_IsConstruct ¶
func NetappStoragePool_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func NetappStoragePool_IsTerraformElement ¶
func NetappStoragePool_IsTerraformElement(x interface{}) *bool
Experimental.
func NetappStoragePool_IsTerraformResource ¶
func NetappStoragePool_IsTerraformResource(x interface{}) *bool
Experimental.
func NetappStoragePool_TfResourceType ¶
func NetappStoragePool_TfResourceType() *string
func NewNetappStoragePoolTimeoutsOutputReference_Override ¶
func NewNetappStoragePoolTimeoutsOutputReference_Override(n NetappStoragePoolTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewNetappStoragePool_Override ¶
func NewNetappStoragePool_Override(n NetappStoragePool, scope constructs.Construct, id *string, config *NetappStoragePoolConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool google_netapp_storage_pool} Resource.
Types ¶
type NetappStoragePool ¶
type NetappStoragePool interface {
cdktf.TerraformResource
ActiveDirectory() *string
SetActiveDirectory(val *string)
ActiveDirectoryInput() *string
CapacityGib() *string
SetCapacityGib(val *string)
CapacityGibInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EffectiveLabels() cdktf.StringMap
EncryptionType() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KmsConfig() *string
SetKmsConfig(val *string)
KmsConfigInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
LdapEnabled() interface{}
SetLdapEnabled(val interface{})
LdapEnabledInput() interface{}
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
SetName(val *string)
NameInput() *string
Network() *string
SetNetwork(val *string)
NetworkInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServiceLevel() *string
SetServiceLevel(val *string)
ServiceLevelInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() NetappStoragePoolTimeoutsOutputReference
TimeoutsInput() interface{}
VolumeCapacityGib() *string
VolumeCount() *float64
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *NetappStoragePoolTimeouts)
ResetActiveDirectory()
ResetDescription()
ResetId()
ResetKmsConfig()
ResetLabels()
ResetLdapEnabled()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool google_netapp_storage_pool}.
func NewNetappStoragePool ¶
func NewNetappStoragePool(scope constructs.Construct, id *string, config *NetappStoragePoolConfig) NetappStoragePool
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool google_netapp_storage_pool} Resource.
type NetappStoragePoolConfig ¶
type NetappStoragePoolConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Capacity of the storage pool (in GiB).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#capacity_gib NetappStoragePool#capacity_gib}
CapacityGib *string `field:"required" json:"capacityGib" yaml:"capacityGib"`
// Name of the location. For zonal Flex pools specify a zone name, in all other cases a region name.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#location NetappStoragePool#location}
Location *string `field:"required" json:"location" yaml:"location"`
// The resource name of the storage pool. Needs to be unique per location/region.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#name NetappStoragePool#name}
Name *string `field:"required" json:"name" yaml:"name"`
// VPC network name with format: 'projects/{{project}}/global/networks/{{network}}'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#network NetappStoragePool#network}
Network *string `field:"required" json:"network" yaml:"network"`
// Service level of the storage pool. Possible values: ["PREMIUM", "EXTREME", "STANDARD", "FLEX"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#service_level NetappStoragePool#service_level}
ServiceLevel *string `field:"required" json:"serviceLevel" yaml:"serviceLevel"`
// Specifies the Active Directory policy to be used.
//
// Format: 'projects/{{project}}/locations/{{location}}/activeDirectories/{{name}}'.
// The policy needs to be in the same location as the storage pool.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#active_directory NetappStoragePool#active_directory}
ActiveDirectory *string `field:"optional" json:"activeDirectory" yaml:"activeDirectory"`
// An optional description of this resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#description NetappStoragePool#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#id NetappStoragePool#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Specifies the CMEK policy to be used for volume encryption.
//
// Format: 'projects/{{project}}/locations/{{location}}/kmsConfigs/{{name}}'.
// The policy needs to be in the same location as the storage pool.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#kms_config NetappStoragePool#kms_config}
KmsConfig *string `field:"optional" json:"kmsConfig" yaml:"kmsConfig"`
// Labels as key value pairs. Example: '{ "owner": "Bob", "department": "finance", "purpose": "testing" }'.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#labels NetappStoragePool#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// When enabled, the volumes uses Active Directory as LDAP name service for UID/GID lookups.
//
// Required to enable extended group support for NFSv3,
// using security identifiers for NFSv4.1 or principal names for kerberized NFSv4.1.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#ldap_enabled NetappStoragePool#ldap_enabled}
LdapEnabled interface{} `field:"optional" json:"ldapEnabled" yaml:"ldapEnabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#project NetappStoragePool#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#timeouts NetappStoragePool#timeouts}
Timeouts *NetappStoragePoolTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type NetappStoragePoolTimeouts ¶
type NetappStoragePoolTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#create NetappStoragePool#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#delete NetappStoragePool#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.41.0/docs/resources/netapp_storage_pool#update NetappStoragePool#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type NetappStoragePoolTimeoutsOutputReference ¶
type NetappStoragePoolTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetappStoragePoolTimeoutsOutputReference ¶
func NewNetappStoragePoolTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) NetappStoragePoolTimeoutsOutputReference