Documentation
¶
Index ¶
- func NewTpuNodeNetworkEndpointsList_Override(t TpuNodeNetworkEndpointsList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewTpuNodeNetworkEndpointsOutputReference_Override(t TpuNodeNetworkEndpointsOutputReference, ...)
- func NewTpuNodeSchedulingConfigOutputReference_Override(t TpuNodeSchedulingConfigOutputReference, ...)
- func NewTpuNodeTimeoutsOutputReference_Override(t TpuNodeTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewTpuNode_Override(t TpuNode, scope constructs.Construct, id *string, config *TpuNodeConfig)
- func TpuNode_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func TpuNode_IsConstruct(x interface{}) *bool
- func TpuNode_IsTerraformElement(x interface{}) *bool
- func TpuNode_IsTerraformResource(x interface{}) *bool
- func TpuNode_TfResourceType() *string
- type TpuNode
- type TpuNodeConfig
- type TpuNodeNetworkEndpoints
- type TpuNodeNetworkEndpointsList
- type TpuNodeNetworkEndpointsOutputReference
- type TpuNodeSchedulingConfig
- type TpuNodeSchedulingConfigOutputReference
- type TpuNodeTimeouts
- type TpuNodeTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewTpuNodeNetworkEndpointsList_Override ¶
func NewTpuNodeNetworkEndpointsList_Override(t TpuNodeNetworkEndpointsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewTpuNodeNetworkEndpointsOutputReference_Override ¶
func NewTpuNodeNetworkEndpointsOutputReference_Override(t TpuNodeNetworkEndpointsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewTpuNodeSchedulingConfigOutputReference_Override ¶
func NewTpuNodeSchedulingConfigOutputReference_Override(t TpuNodeSchedulingConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewTpuNodeTimeoutsOutputReference_Override ¶
func NewTpuNodeTimeoutsOutputReference_Override(t TpuNodeTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewTpuNode_Override ¶
func NewTpuNode_Override(t TpuNode, scope constructs.Construct, id *string, config *TpuNodeConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node google_tpu_node} Resource.
func TpuNode_GenerateConfigForImport ¶
func TpuNode_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a TpuNode resource upon running "cdktf plan <stack-name>".
func TpuNode_IsConstruct ¶
func TpuNode_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func TpuNode_IsTerraformElement ¶
func TpuNode_IsTerraformElement(x interface{}) *bool
Experimental.
func TpuNode_IsTerraformResource ¶
func TpuNode_IsTerraformResource(x interface{}) *bool
Experimental.
func TpuNode_TfResourceType ¶
func TpuNode_TfResourceType() *string
Types ¶
type TpuNode ¶
type TpuNode interface {
cdktf.TerraformResource
AcceleratorType() *string
SetAcceleratorType(val *string)
AcceleratorTypeInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CidrBlock() *string
SetCidrBlock(val *string)
CidrBlockInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
Network() *string
SetNetwork(val *string)
NetworkEndpoints() TpuNodeNetworkEndpointsList
NetworkInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SchedulingConfig() TpuNodeSchedulingConfigOutputReference
SchedulingConfigInput() *TpuNodeSchedulingConfig
ServiceAccount() *string
TensorflowVersion() *string
SetTensorflowVersion(val *string)
TensorflowVersionInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() TpuNodeTimeoutsOutputReference
TimeoutsInput() interface{}
UseServiceNetworking() interface{}
SetUseServiceNetworking(val interface{})
UseServiceNetworkingInput() interface{}
Zone() *string
SetZone(val *string)
ZoneInput() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutSchedulingConfig(value *TpuNodeSchedulingConfig)
PutTimeouts(value *TpuNodeTimeouts)
ResetCidrBlock()
ResetDescription()
ResetId()
ResetLabels()
ResetNetwork()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetSchedulingConfig()
ResetTimeouts()
ResetUseServiceNetworking()
ResetZone()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node google_tpu_node}.
func NewTpuNode ¶
func NewTpuNode(scope constructs.Construct, id *string, config *TpuNodeConfig) TpuNode
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node google_tpu_node} Resource.
type TpuNodeConfig ¶
type TpuNodeConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The type of hardware accelerators associated with this node.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#accelerator_type TpuNode#accelerator_type}
AcceleratorType *string `field:"required" json:"acceleratorType" yaml:"acceleratorType"`
// The immutable name of the TPU.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#name TpuNode#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The version of Tensorflow running in the Node.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#tensorflow_version TpuNode#tensorflow_version}
TensorflowVersion *string `field:"required" json:"tensorflowVersion" yaml:"tensorflowVersion"`
// The CIDR block that the TPU node will use when selecting an IP address.
//
// This CIDR block must be a /29 block; the Compute Engine
// networks API forbids a smaller block, and using a larger block would
// be wasteful (a node can only consume one IP address).
//
// Errors will occur if the CIDR block has already been used for a
// currently existing TPU node, the CIDR block conflicts with any
// subnetworks in the user's provided network, or the provided network
// is peered with another network that is using that CIDR block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#cidr_block TpuNode#cidr_block}
CidrBlock *string `field:"optional" json:"cidrBlock" yaml:"cidrBlock"`
// The user-supplied description of the TPU. Maximum of 512 characters.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#description TpuNode#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#id TpuNode#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Resource labels to represent user provided metadata.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#labels TpuNode#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// The name of a network to peer the TPU node to.
//
// It must be a
// preexisting Compute Engine network inside of the project on which
// this API has been activated. If none is provided, "default" will be
// used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#network TpuNode#network}
Network *string `field:"optional" json:"network" yaml:"network"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#project TpuNode#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// scheduling_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#scheduling_config TpuNode#scheduling_config}
SchedulingConfig *TpuNodeSchedulingConfig `field:"optional" json:"schedulingConfig" yaml:"schedulingConfig"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#timeouts TpuNode#timeouts}
Timeouts *TpuNodeTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Whether the VPC peering for the node is set up through Service Networking API.
//
// The VPC Peering should be set up before provisioning the node. If this field is set,
// cidr_block field should not be specified. If the network that you want to peer the
// TPU Node to is a Shared VPC network, the node must be created with this this field enabled.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#use_service_networking TpuNode#use_service_networking}
UseServiceNetworking interface{} `field:"optional" json:"useServiceNetworking" yaml:"useServiceNetworking"`
// The GCP location for the TPU. If it is not provided, the provider zone is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#zone TpuNode#zone}
Zone *string `field:"optional" json:"zone" yaml:"zone"`
}
type TpuNodeNetworkEndpoints ¶
type TpuNodeNetworkEndpoints struct {
}
type TpuNodeNetworkEndpointsList ¶
type TpuNodeNetworkEndpointsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) TpuNodeNetworkEndpointsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewTpuNodeNetworkEndpointsList ¶
func NewTpuNodeNetworkEndpointsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) TpuNodeNetworkEndpointsList
type TpuNodeNetworkEndpointsOutputReference ¶
type TpuNodeNetworkEndpointsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *TpuNodeNetworkEndpoints
SetInternalValue(val *TpuNodeNetworkEndpoints)
IpAddress() *string
Port() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewTpuNodeNetworkEndpointsOutputReference ¶
func NewTpuNodeNetworkEndpointsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) TpuNodeNetworkEndpointsOutputReference
type TpuNodeSchedulingConfig ¶
type TpuNodeSchedulingConfig struct {
// Defines whether the TPU instance is preemptible.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#preemptible TpuNode#preemptible}
Preemptible interface{} `field:"required" json:"preemptible" yaml:"preemptible"`
}
type TpuNodeSchedulingConfigOutputReference ¶
type TpuNodeSchedulingConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *TpuNodeSchedulingConfig
SetInternalValue(val *TpuNodeSchedulingConfig)
Preemptible() interface{}
SetPreemptible(val interface{})
PreemptibleInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewTpuNodeSchedulingConfigOutputReference ¶
func NewTpuNodeSchedulingConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) TpuNodeSchedulingConfigOutputReference
type TpuNodeTimeouts ¶
type TpuNodeTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#create TpuNode#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#delete TpuNode#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.50.0/docs/resources/tpu_node#update TpuNode#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type TpuNodeTimeoutsOutputReference ¶
type TpuNodeTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewTpuNodeTimeoutsOutputReference ¶
func NewTpuNodeTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) TpuNodeTimeoutsOutputReference
Source Files
¶
- TpuNode.go
- TpuNodeConfig.go
- TpuNodeNetworkEndpoints.go
- TpuNodeNetworkEndpointsList.go
- TpuNodeNetworkEndpointsList__checks.go
- TpuNodeNetworkEndpointsOutputReference.go
- TpuNodeNetworkEndpointsOutputReference__checks.go
- TpuNodeSchedulingConfig.go
- TpuNodeSchedulingConfigOutputReference.go
- TpuNodeSchedulingConfigOutputReference__checks.go
- TpuNodeTimeouts.go
- TpuNodeTimeoutsOutputReference.go
- TpuNodeTimeoutsOutputReference__checks.go
- TpuNode__checks.go
- main.go