Documentation
¶
Index ¶
- func CloudTasksQueue_IsConstruct(x interface{}) *bool
- func CloudTasksQueue_IsTerraformElement(x interface{}) *bool
- func CloudTasksQueue_IsTerraformResource(x interface{}) *bool
- func CloudTasksQueue_TfResourceType() *string
- func NewCloudTasksQueueAppEngineRoutingOverrideOutputReference_Override(c CloudTasksQueueAppEngineRoutingOverrideOutputReference, ...)
- func NewCloudTasksQueueRateLimitsOutputReference_Override(c CloudTasksQueueRateLimitsOutputReference, ...)
- func NewCloudTasksQueueRetryConfigOutputReference_Override(c CloudTasksQueueRetryConfigOutputReference, ...)
- func NewCloudTasksQueueStackdriverLoggingConfigOutputReference_Override(c CloudTasksQueueStackdriverLoggingConfigOutputReference, ...)
- func NewCloudTasksQueueTimeoutsOutputReference_Override(c CloudTasksQueueTimeoutsOutputReference, ...)
- func NewCloudTasksQueue_Override(c CloudTasksQueue, scope constructs.Construct, id *string, ...)
- type CloudTasksQueue
- type CloudTasksQueueAppEngineRoutingOverride
- type CloudTasksQueueAppEngineRoutingOverrideOutputReference
- type CloudTasksQueueConfig
- type CloudTasksQueueRateLimits
- type CloudTasksQueueRateLimitsOutputReference
- type CloudTasksQueueRetryConfig
- type CloudTasksQueueRetryConfigOutputReference
- type CloudTasksQueueStackdriverLoggingConfig
- type CloudTasksQueueStackdriverLoggingConfigOutputReference
- type CloudTasksQueueTimeouts
- type CloudTasksQueueTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CloudTasksQueue_IsConstruct ¶
func CloudTasksQueue_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CloudTasksQueue_IsTerraformElement ¶
func CloudTasksQueue_IsTerraformElement(x interface{}) *bool
Experimental.
func CloudTasksQueue_IsTerraformResource ¶
func CloudTasksQueue_IsTerraformResource(x interface{}) *bool
Experimental.
func CloudTasksQueue_TfResourceType ¶
func CloudTasksQueue_TfResourceType() *string
func NewCloudTasksQueueAppEngineRoutingOverrideOutputReference_Override ¶
func NewCloudTasksQueueAppEngineRoutingOverrideOutputReference_Override(c CloudTasksQueueAppEngineRoutingOverrideOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCloudTasksQueueRateLimitsOutputReference_Override ¶
func NewCloudTasksQueueRateLimitsOutputReference_Override(c CloudTasksQueueRateLimitsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCloudTasksQueueRetryConfigOutputReference_Override ¶
func NewCloudTasksQueueRetryConfigOutputReference_Override(c CloudTasksQueueRetryConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCloudTasksQueueStackdriverLoggingConfigOutputReference_Override ¶
func NewCloudTasksQueueStackdriverLoggingConfigOutputReference_Override(c CloudTasksQueueStackdriverLoggingConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCloudTasksQueueTimeoutsOutputReference_Override ¶
func NewCloudTasksQueueTimeoutsOutputReference_Override(c CloudTasksQueueTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCloudTasksQueue_Override ¶
func NewCloudTasksQueue_Override(c CloudTasksQueue, scope constructs.Construct, id *string, config *CloudTasksQueueConfig)
Create a new {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue google_cloud_tasks_queue} Resource.
Types ¶
type CloudTasksQueue ¶
type CloudTasksQueue interface {
cdktf.TerraformResource
AppEngineRoutingOverride() CloudTasksQueueAppEngineRoutingOverrideOutputReference
AppEngineRoutingOverrideInput() *CloudTasksQueueAppEngineRoutingOverride
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
RateLimits() CloudTasksQueueRateLimitsOutputReference
RateLimitsInput() *CloudTasksQueueRateLimits
// Experimental.
RawOverrides() interface{}
RetryConfig() CloudTasksQueueRetryConfigOutputReference
RetryConfigInput() *CloudTasksQueueRetryConfig
StackdriverLoggingConfig() CloudTasksQueueStackdriverLoggingConfigOutputReference
StackdriverLoggingConfigInput() *CloudTasksQueueStackdriverLoggingConfig
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() CloudTasksQueueTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAppEngineRoutingOverride(value *CloudTasksQueueAppEngineRoutingOverride)
PutRateLimits(value *CloudTasksQueueRateLimits)
PutRetryConfig(value *CloudTasksQueueRetryConfig)
PutStackdriverLoggingConfig(value *CloudTasksQueueStackdriverLoggingConfig)
PutTimeouts(value *CloudTasksQueueTimeouts)
ResetAppEngineRoutingOverride()
ResetId()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRateLimits()
ResetRetryConfig()
ResetStackdriverLoggingConfig()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue google_cloud_tasks_queue}.
func NewCloudTasksQueue ¶
func NewCloudTasksQueue(scope constructs.Construct, id *string, config *CloudTasksQueueConfig) CloudTasksQueue
Create a new {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue google_cloud_tasks_queue} Resource.
type CloudTasksQueueAppEngineRoutingOverride ¶
type CloudTasksQueueAppEngineRoutingOverride struct {
// App instance.
//
// By default, the task is sent to an instance which is available when the task is attempted.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#instance CloudTasksQueue#instance}
Instance *string `field:"optional" json:"instance" yaml:"instance"`
// App service.
//
// By default, the task is sent to the service which is the default service when the task is attempted.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#service CloudTasksQueue#service}
Service *string `field:"optional" json:"service" yaml:"service"`
// App version.
//
// By default, the task is sent to the version which is the default version when the task is attempted.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#version CloudTasksQueue#version}
Version *string `field:"optional" json:"version" yaml:"version"`
}
type CloudTasksQueueAppEngineRoutingOverrideOutputReference ¶
type CloudTasksQueueAppEngineRoutingOverrideOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Host() *string
Instance() *string
SetInstance(val *string)
InstanceInput() *string
InternalValue() *CloudTasksQueueAppEngineRoutingOverride
SetInternalValue(val *CloudTasksQueueAppEngineRoutingOverride)
Service() *string
SetService(val *string)
ServiceInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Version() *string
SetVersion(val *string)
VersionInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetInstance()
ResetService()
ResetVersion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudTasksQueueAppEngineRoutingOverrideOutputReference ¶
func NewCloudTasksQueueAppEngineRoutingOverrideOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CloudTasksQueueAppEngineRoutingOverrideOutputReference
type CloudTasksQueueConfig ¶
type CloudTasksQueueConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The location of the queue.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#location CloudTasksQueue#location}
Location *string `field:"required" json:"location" yaml:"location"`
// app_engine_routing_override block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#app_engine_routing_override CloudTasksQueue#app_engine_routing_override}
AppEngineRoutingOverride *CloudTasksQueueAppEngineRoutingOverride `field:"optional" json:"appEngineRoutingOverride" yaml:"appEngineRoutingOverride"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#id CloudTasksQueue#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The queue name.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#name CloudTasksQueue#name}
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#project CloudTasksQueue#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// rate_limits block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#rate_limits CloudTasksQueue#rate_limits}
RateLimits *CloudTasksQueueRateLimits `field:"optional" json:"rateLimits" yaml:"rateLimits"`
// retry_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#retry_config CloudTasksQueue#retry_config}
RetryConfig *CloudTasksQueueRetryConfig `field:"optional" json:"retryConfig" yaml:"retryConfig"`
// stackdriver_logging_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#stackdriver_logging_config CloudTasksQueue#stackdriver_logging_config}
StackdriverLoggingConfig *CloudTasksQueueStackdriverLoggingConfig `field:"optional" json:"stackdriverLoggingConfig" yaml:"stackdriverLoggingConfig"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#timeouts CloudTasksQueue#timeouts}
Timeouts *CloudTasksQueueTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type CloudTasksQueueRateLimits ¶
type CloudTasksQueueRateLimits struct {
// The maximum number of concurrent tasks that Cloud Tasks allows to be dispatched for this queue.
//
// After this threshold has been
// reached, Cloud Tasks stops dispatching tasks until the number of
// concurrent requests decreases.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#max_concurrent_dispatches CloudTasksQueue#max_concurrent_dispatches}
MaxConcurrentDispatches *float64 `field:"optional" json:"maxConcurrentDispatches" yaml:"maxConcurrentDispatches"`
// The maximum rate at which tasks are dispatched from this queue.
//
// If unspecified when the queue is created, Cloud Tasks will pick the default.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#max_dispatches_per_second CloudTasksQueue#max_dispatches_per_second}
MaxDispatchesPerSecond *float64 `field:"optional" json:"maxDispatchesPerSecond" yaml:"maxDispatchesPerSecond"`
}
type CloudTasksQueueRateLimitsOutputReference ¶
type CloudTasksQueueRateLimitsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *CloudTasksQueueRateLimits
SetInternalValue(val *CloudTasksQueueRateLimits)
MaxBurstSize() *float64
MaxConcurrentDispatches() *float64
SetMaxConcurrentDispatches(val *float64)
MaxConcurrentDispatchesInput() *float64
MaxDispatchesPerSecond() *float64
SetMaxDispatchesPerSecond(val *float64)
MaxDispatchesPerSecondInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetMaxConcurrentDispatches()
ResetMaxDispatchesPerSecond()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudTasksQueueRateLimitsOutputReference ¶
func NewCloudTasksQueueRateLimitsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CloudTasksQueueRateLimitsOutputReference
type CloudTasksQueueRetryConfig ¶
type CloudTasksQueueRetryConfig struct {
// Number of attempts per task.
//
// Cloud Tasks will attempt the task maxAttempts times (that is, if
// the first attempt fails, then there will be maxAttempts - 1
// retries). Must be >= -1.
//
// If unspecified when the queue is created, Cloud Tasks will pick
// the default.
//
// -1 indicates unlimited attempts.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#max_attempts CloudTasksQueue#max_attempts}
MaxAttempts *float64 `field:"optional" json:"maxAttempts" yaml:"maxAttempts"`
// A task will be scheduled for retry between minBackoff and maxBackoff duration after it fails, if the queue's RetryConfig specifies that the task should be retried.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#max_backoff CloudTasksQueue#max_backoff}
MaxBackoff *string `field:"optional" json:"maxBackoff" yaml:"maxBackoff"`
// The time between retries will double maxDoublings times.
//
// A task's retry interval starts at minBackoff, then doubles maxDoublings times,
// then increases linearly, and finally retries retries at intervals of maxBackoff
// up to maxAttempts times.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#max_doublings CloudTasksQueue#max_doublings}
MaxDoublings *float64 `field:"optional" json:"maxDoublings" yaml:"maxDoublings"`
// If positive, maxRetryDuration specifies the time limit for retrying a failed task, measured from when the task was first attempted.
//
// Once maxRetryDuration time has passed and the task has
// been attempted maxAttempts times, no further attempts will be
// made and the task will be deleted.
//
// If zero, then the task age is unlimited.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#max_retry_duration CloudTasksQueue#max_retry_duration}
MaxRetryDuration *string `field:"optional" json:"maxRetryDuration" yaml:"maxRetryDuration"`
// A task will be scheduled for retry between minBackoff and maxBackoff duration after it fails, if the queue's RetryConfig specifies that the task should be retried.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#min_backoff CloudTasksQueue#min_backoff}
MinBackoff *string `field:"optional" json:"minBackoff" yaml:"minBackoff"`
}
type CloudTasksQueueRetryConfigOutputReference ¶
type CloudTasksQueueRetryConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *CloudTasksQueueRetryConfig
SetInternalValue(val *CloudTasksQueueRetryConfig)
MaxAttempts() *float64
SetMaxAttempts(val *float64)
MaxAttemptsInput() *float64
MaxBackoff() *string
SetMaxBackoff(val *string)
MaxBackoffInput() *string
MaxDoublings() *float64
SetMaxDoublings(val *float64)
MaxDoublingsInput() *float64
MaxRetryDuration() *string
SetMaxRetryDuration(val *string)
MaxRetryDurationInput() *string
MinBackoff() *string
SetMinBackoff(val *string)
MinBackoffInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetMaxAttempts()
ResetMaxBackoff()
ResetMaxDoublings()
ResetMaxRetryDuration()
ResetMinBackoff()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudTasksQueueRetryConfigOutputReference ¶
func NewCloudTasksQueueRetryConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CloudTasksQueueRetryConfigOutputReference
type CloudTasksQueueStackdriverLoggingConfig ¶
type CloudTasksQueueStackdriverLoggingConfig struct {
// Specifies the fraction of operations to write to Stackdriver Logging.
//
// This field may contain any value between 0.0 and 1.0, inclusive. 0.0 is the
// default and means that no operations are logged.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#sampling_ratio CloudTasksQueue#sampling_ratio}
SamplingRatio *float64 `field:"required" json:"samplingRatio" yaml:"samplingRatio"`
}
type CloudTasksQueueStackdriverLoggingConfigOutputReference ¶
type CloudTasksQueueStackdriverLoggingConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *CloudTasksQueueStackdriverLoggingConfig
SetInternalValue(val *CloudTasksQueueStackdriverLoggingConfig)
SamplingRatio() *float64
SetSamplingRatio(val *float64)
SamplingRatioInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudTasksQueueStackdriverLoggingConfigOutputReference ¶
func NewCloudTasksQueueStackdriverLoggingConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CloudTasksQueueStackdriverLoggingConfigOutputReference
type CloudTasksQueueTimeouts ¶
type CloudTasksQueueTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#create CloudTasksQueue#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#delete CloudTasksQueue#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_tasks_queue#update CloudTasksQueue#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type CloudTasksQueueTimeoutsOutputReference ¶
type CloudTasksQueueTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudTasksQueueTimeoutsOutputReference ¶
func NewCloudTasksQueueTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CloudTasksQueueTimeoutsOutputReference
Source Files
¶
- cloudtasksqueue.go
- cloudtasksqueue_CloudTasksQueue.go
- cloudtasksqueue_CloudTasksQueueAppEngineRoutingOverride.go
- cloudtasksqueue_CloudTasksQueueAppEngineRoutingOverrideOutputReference.go
- cloudtasksqueue_CloudTasksQueueAppEngineRoutingOverrideOutputReference__runtime_type_checks.go
- cloudtasksqueue_CloudTasksQueueConfig.go
- cloudtasksqueue_CloudTasksQueueRateLimits.go
- cloudtasksqueue_CloudTasksQueueRateLimitsOutputReference.go
- cloudtasksqueue_CloudTasksQueueRateLimitsOutputReference__runtime_type_checks.go
- cloudtasksqueue_CloudTasksQueueRetryConfig.go
- cloudtasksqueue_CloudTasksQueueRetryConfigOutputReference.go
- cloudtasksqueue_CloudTasksQueueRetryConfigOutputReference__runtime_type_checks.go
- cloudtasksqueue_CloudTasksQueueStackdriverLoggingConfig.go
- cloudtasksqueue_CloudTasksQueueStackdriverLoggingConfigOutputReference.go
- cloudtasksqueue_CloudTasksQueueStackdriverLoggingConfigOutputReference__runtime_type_checks.go
- cloudtasksqueue_CloudTasksQueueTimeouts.go
- cloudtasksqueue_CloudTasksQueueTimeoutsOutputReference.go
- cloudtasksqueue_CloudTasksQueueTimeoutsOutputReference__runtime_type_checks.go
- cloudtasksqueue_CloudTasksQueue__runtime_type_checks.go