Documentation
¶
Index ¶
- func ComputePacketMirroring_IsConstruct(x interface{}) *bool
- func ComputePacketMirroring_IsTerraformElement(x interface{}) *bool
- func ComputePacketMirroring_IsTerraformResource(x interface{}) *bool
- func ComputePacketMirroring_TfResourceType() *string
- func NewComputePacketMirroringCollectorIlbOutputReference_Override(c ComputePacketMirroringCollectorIlbOutputReference, ...)
- func NewComputePacketMirroringFilterOutputReference_Override(c ComputePacketMirroringFilterOutputReference, ...)
- func NewComputePacketMirroringMirroredResourcesInstancesList_Override(c ComputePacketMirroringMirroredResourcesInstancesList, ...)
- func NewComputePacketMirroringMirroredResourcesInstancesOutputReference_Override(c ComputePacketMirroringMirroredResourcesInstancesOutputReference, ...)
- func NewComputePacketMirroringMirroredResourcesOutputReference_Override(c ComputePacketMirroringMirroredResourcesOutputReference, ...)
- func NewComputePacketMirroringMirroredResourcesSubnetworksList_Override(c ComputePacketMirroringMirroredResourcesSubnetworksList, ...)
- func NewComputePacketMirroringMirroredResourcesSubnetworksOutputReference_Override(c ComputePacketMirroringMirroredResourcesSubnetworksOutputReference, ...)
- func NewComputePacketMirroringNetworkOutputReference_Override(c ComputePacketMirroringNetworkOutputReference, ...)
- func NewComputePacketMirroringTimeoutsOutputReference_Override(c ComputePacketMirroringTimeoutsOutputReference, ...)
- func NewComputePacketMirroring_Override(c ComputePacketMirroring, scope constructs.Construct, id *string, ...)
- type ComputePacketMirroring
- type ComputePacketMirroringCollectorIlb
- type ComputePacketMirroringCollectorIlbOutputReference
- type ComputePacketMirroringConfig
- type ComputePacketMirroringFilter
- type ComputePacketMirroringFilterOutputReference
- type ComputePacketMirroringMirroredResources
- type ComputePacketMirroringMirroredResourcesInstances
- type ComputePacketMirroringMirroredResourcesInstancesList
- type ComputePacketMirroringMirroredResourcesInstancesOutputReference
- type ComputePacketMirroringMirroredResourcesOutputReference
- type ComputePacketMirroringMirroredResourcesSubnetworks
- type ComputePacketMirroringMirroredResourcesSubnetworksList
- type ComputePacketMirroringMirroredResourcesSubnetworksOutputReference
- type ComputePacketMirroringNetwork
- type ComputePacketMirroringNetworkOutputReference
- type ComputePacketMirroringTimeouts
- type ComputePacketMirroringTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComputePacketMirroring_IsConstruct ¶
func ComputePacketMirroring_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ComputePacketMirroring_IsTerraformElement ¶
func ComputePacketMirroring_IsTerraformElement(x interface{}) *bool
Experimental.
func ComputePacketMirroring_IsTerraformResource ¶
func ComputePacketMirroring_IsTerraformResource(x interface{}) *bool
Experimental.
func ComputePacketMirroring_TfResourceType ¶
func ComputePacketMirroring_TfResourceType() *string
func NewComputePacketMirroringCollectorIlbOutputReference_Override ¶
func NewComputePacketMirroringCollectorIlbOutputReference_Override(c ComputePacketMirroringCollectorIlbOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputePacketMirroringFilterOutputReference_Override ¶
func NewComputePacketMirroringFilterOutputReference_Override(c ComputePacketMirroringFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputePacketMirroringMirroredResourcesInstancesList_Override ¶
func NewComputePacketMirroringMirroredResourcesInstancesList_Override(c ComputePacketMirroringMirroredResourcesInstancesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewComputePacketMirroringMirroredResourcesInstancesOutputReference_Override ¶
func NewComputePacketMirroringMirroredResourcesInstancesOutputReference_Override(c ComputePacketMirroringMirroredResourcesInstancesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewComputePacketMirroringMirroredResourcesOutputReference_Override ¶
func NewComputePacketMirroringMirroredResourcesOutputReference_Override(c ComputePacketMirroringMirroredResourcesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputePacketMirroringMirroredResourcesSubnetworksList_Override ¶
func NewComputePacketMirroringMirroredResourcesSubnetworksList_Override(c ComputePacketMirroringMirroredResourcesSubnetworksList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewComputePacketMirroringMirroredResourcesSubnetworksOutputReference_Override ¶
func NewComputePacketMirroringMirroredResourcesSubnetworksOutputReference_Override(c ComputePacketMirroringMirroredResourcesSubnetworksOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewComputePacketMirroringNetworkOutputReference_Override ¶
func NewComputePacketMirroringNetworkOutputReference_Override(c ComputePacketMirroringNetworkOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputePacketMirroringTimeoutsOutputReference_Override ¶
func NewComputePacketMirroringTimeoutsOutputReference_Override(c ComputePacketMirroringTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputePacketMirroring_Override ¶
func NewComputePacketMirroring_Override(c ComputePacketMirroring, scope constructs.Construct, id *string, config *ComputePacketMirroringConfig)
Create a new {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring google_compute_packet_mirroring} Resource.
Types ¶
type ComputePacketMirroring ¶
type ComputePacketMirroring interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
CollectorIlb() ComputePacketMirroringCollectorIlbOutputReference
CollectorIlbInput() *ComputePacketMirroringCollectorIlb
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Filter() ComputePacketMirroringFilterOutputReference
FilterInput() *ComputePacketMirroringFilter
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MirroredResources() ComputePacketMirroringMirroredResourcesOutputReference
MirroredResourcesInput() *ComputePacketMirroringMirroredResources
Name() *string
SetName(val *string)
NameInput() *string
Network() ComputePacketMirroringNetworkOutputReference
NetworkInput() *ComputePacketMirroringNetwork
// The tree node.
Node() constructs.Node
Priority() *float64
SetPriority(val *float64)
PriorityInput() *float64
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() ComputePacketMirroringTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCollectorIlb(value *ComputePacketMirroringCollectorIlb)
PutFilter(value *ComputePacketMirroringFilter)
PutMirroredResources(value *ComputePacketMirroringMirroredResources)
PutNetwork(value *ComputePacketMirroringNetwork)
PutTimeouts(value *ComputePacketMirroringTimeouts)
ResetDescription()
ResetFilter()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPriority()
ResetProject()
ResetRegion()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring google_compute_packet_mirroring}.
func NewComputePacketMirroring ¶
func NewComputePacketMirroring(scope constructs.Construct, id *string, config *ComputePacketMirroringConfig) ComputePacketMirroring
Create a new {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring google_compute_packet_mirroring} Resource.
type ComputePacketMirroringCollectorIlb ¶
type ComputePacketMirroringCollectorIlb struct {
// The URL of the forwarding rule.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#url ComputePacketMirroring#url}
Url *string `field:"required" json:"url" yaml:"url"`
}
type ComputePacketMirroringCollectorIlbOutputReference ¶
type ComputePacketMirroringCollectorIlbOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ComputePacketMirroringCollectorIlb
SetInternalValue(val *ComputePacketMirroringCollectorIlb)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Url() *string
SetUrl(val *string)
UrlInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputePacketMirroringCollectorIlbOutputReference ¶
func NewComputePacketMirroringCollectorIlbOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputePacketMirroringCollectorIlbOutputReference
type ComputePacketMirroringConfig ¶
type ComputePacketMirroringConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// collector_ilb block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#collector_ilb ComputePacketMirroring#collector_ilb}
CollectorIlb *ComputePacketMirroringCollectorIlb `field:"required" json:"collectorIlb" yaml:"collectorIlb"`
// mirrored_resources block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#mirrored_resources ComputePacketMirroring#mirrored_resources}
MirroredResources *ComputePacketMirroringMirroredResources `field:"required" json:"mirroredResources" yaml:"mirroredResources"`
// The name of the packet mirroring rule.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#name ComputePacketMirroring#name}
Name *string `field:"required" json:"name" yaml:"name"`
// network block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#network ComputePacketMirroring#network}
Network *ComputePacketMirroringNetwork `field:"required" json:"network" yaml:"network"`
// A human-readable description of the rule.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#description ComputePacketMirroring#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// filter block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#filter ComputePacketMirroring#filter}
Filter *ComputePacketMirroringFilter `field:"optional" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#id ComputePacketMirroring#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Since only one rule can be active at a time, priority is used to break ties in the case of two rules that apply to the same instances.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#priority ComputePacketMirroring#priority}
Priority *float64 `field:"optional" json:"priority" yaml:"priority"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#project ComputePacketMirroring#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// The Region in which the created address should reside. If it is not provided, the provider region is used.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#region ComputePacketMirroring#region}
Region *string `field:"optional" json:"region" yaml:"region"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#timeouts ComputePacketMirroring#timeouts}
Timeouts *ComputePacketMirroringTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type ComputePacketMirroringFilter ¶
type ComputePacketMirroringFilter struct {
// IP CIDR ranges that apply as a filter on the source (ingress) or destination (egress) IP in the IP header.
//
// Only IPv4 is supported.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#cidr_ranges ComputePacketMirroring#cidr_ranges}
CidrRanges *[]*string `field:"optional" json:"cidrRanges" yaml:"cidrRanges"`
// Direction of traffic to mirror. Default value: "BOTH" Possible values: ["INGRESS", "EGRESS", "BOTH"].
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#direction ComputePacketMirroring#direction}
Direction *string `field:"optional" json:"direction" yaml:"direction"`
// Possible IP protocols including tcp, udp, icmp and esp.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#ip_protocols ComputePacketMirroring#ip_protocols}
IpProtocols *[]*string `field:"optional" json:"ipProtocols" yaml:"ipProtocols"`
}
type ComputePacketMirroringFilterOutputReference ¶
type ComputePacketMirroringFilterOutputReference interface {
cdktf.ComplexObject
CidrRanges() *[]*string
SetCidrRanges(val *[]*string)
CidrRangesInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Direction() *string
SetDirection(val *string)
DirectionInput() *string
// Experimental.
Fqn() *string
InternalValue() *ComputePacketMirroringFilter
SetInternalValue(val *ComputePacketMirroringFilter)
IpProtocols() *[]*string
SetIpProtocols(val *[]*string)
IpProtocolsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCidrRanges()
ResetDirection()
ResetIpProtocols()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputePacketMirroringFilterOutputReference ¶
func NewComputePacketMirroringFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputePacketMirroringFilterOutputReference
type ComputePacketMirroringMirroredResources ¶
type ComputePacketMirroringMirroredResources struct {
// instances block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#instances ComputePacketMirroring#instances}
Instances interface{} `field:"optional" json:"instances" yaml:"instances"`
// subnetworks block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#subnetworks ComputePacketMirroring#subnetworks}
Subnetworks interface{} `field:"optional" json:"subnetworks" yaml:"subnetworks"`
// All instances with these tags will be mirrored.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#tags ComputePacketMirroring#tags}
Tags *[]*string `field:"optional" json:"tags" yaml:"tags"`
}
type ComputePacketMirroringMirroredResourcesInstances ¶
type ComputePacketMirroringMirroredResourcesInstances struct {
// The URL of the instances where this rule should be active.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#url ComputePacketMirroring#url}
Url *string `field:"required" json:"url" yaml:"url"`
}
type ComputePacketMirroringMirroredResourcesInstancesList ¶
type ComputePacketMirroringMirroredResourcesInstancesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ComputePacketMirroringMirroredResourcesInstancesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputePacketMirroringMirroredResourcesInstancesList ¶
func NewComputePacketMirroringMirroredResourcesInstancesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ComputePacketMirroringMirroredResourcesInstancesList
type ComputePacketMirroringMirroredResourcesInstancesOutputReference ¶
type ComputePacketMirroringMirroredResourcesInstancesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Url() *string
SetUrl(val *string)
UrlInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputePacketMirroringMirroredResourcesInstancesOutputReference ¶
func NewComputePacketMirroringMirroredResourcesInstancesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ComputePacketMirroringMirroredResourcesInstancesOutputReference
type ComputePacketMirroringMirroredResourcesOutputReference ¶
type ComputePacketMirroringMirroredResourcesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Instances() ComputePacketMirroringMirroredResourcesInstancesList
InstancesInput() interface{}
InternalValue() *ComputePacketMirroringMirroredResources
SetInternalValue(val *ComputePacketMirroringMirroredResources)
Subnetworks() ComputePacketMirroringMirroredResourcesSubnetworksList
SubnetworksInput() interface{}
Tags() *[]*string
SetTags(val *[]*string)
TagsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutInstances(value interface{})
PutSubnetworks(value interface{})
ResetInstances()
ResetSubnetworks()
ResetTags()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputePacketMirroringMirroredResourcesOutputReference ¶
func NewComputePacketMirroringMirroredResourcesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputePacketMirroringMirroredResourcesOutputReference
type ComputePacketMirroringMirroredResourcesSubnetworks ¶
type ComputePacketMirroringMirroredResourcesSubnetworks struct {
// The URL of the subnetwork where this rule should be active.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#url ComputePacketMirroring#url}
Url *string `field:"required" json:"url" yaml:"url"`
}
type ComputePacketMirroringMirroredResourcesSubnetworksList ¶
type ComputePacketMirroringMirroredResourcesSubnetworksList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ComputePacketMirroringMirroredResourcesSubnetworksOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputePacketMirroringMirroredResourcesSubnetworksList ¶
func NewComputePacketMirroringMirroredResourcesSubnetworksList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ComputePacketMirroringMirroredResourcesSubnetworksList
type ComputePacketMirroringMirroredResourcesSubnetworksOutputReference ¶
type ComputePacketMirroringMirroredResourcesSubnetworksOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Url() *string
SetUrl(val *string)
UrlInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputePacketMirroringMirroredResourcesSubnetworksOutputReference ¶
func NewComputePacketMirroringMirroredResourcesSubnetworksOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ComputePacketMirroringMirroredResourcesSubnetworksOutputReference
type ComputePacketMirroringNetwork ¶
type ComputePacketMirroringNetwork struct {
// The full self_link URL of the network where this rule is active.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#url ComputePacketMirroring#url}
Url *string `field:"required" json:"url" yaml:"url"`
}
type ComputePacketMirroringNetworkOutputReference ¶
type ComputePacketMirroringNetworkOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ComputePacketMirroringNetwork
SetInternalValue(val *ComputePacketMirroringNetwork)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Url() *string
SetUrl(val *string)
UrlInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputePacketMirroringNetworkOutputReference ¶
func NewComputePacketMirroringNetworkOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputePacketMirroringNetworkOutputReference
type ComputePacketMirroringTimeouts ¶
type ComputePacketMirroringTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#create ComputePacketMirroring#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#delete ComputePacketMirroring#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_packet_mirroring#update ComputePacketMirroring#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type ComputePacketMirroringTimeoutsOutputReference ¶
type ComputePacketMirroringTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputePacketMirroringTimeoutsOutputReference ¶
func NewComputePacketMirroringTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputePacketMirroringTimeoutsOutputReference
Source Files
¶
- computepacketmirroring.go
- computepacketmirroring_ComputePacketMirroring.go
- computepacketmirroring_ComputePacketMirroringCollectorIlb.go
- computepacketmirroring_ComputePacketMirroringCollectorIlbOutputReference.go
- computepacketmirroring_ComputePacketMirroringCollectorIlbOutputReference__runtime_type_checks.go
- computepacketmirroring_ComputePacketMirroringConfig.go
- computepacketmirroring_ComputePacketMirroringFilter.go
- computepacketmirroring_ComputePacketMirroringFilterOutputReference.go
- computepacketmirroring_ComputePacketMirroringFilterOutputReference__runtime_type_checks.go
- computepacketmirroring_ComputePacketMirroringMirroredResources.go
- computepacketmirroring_ComputePacketMirroringMirroredResourcesInstances.go
- computepacketmirroring_ComputePacketMirroringMirroredResourcesInstancesList.go
- computepacketmirroring_ComputePacketMirroringMirroredResourcesInstancesList__runtime_type_checks.go
- computepacketmirroring_ComputePacketMirroringMirroredResourcesInstancesOutputReference.go
- computepacketmirroring_ComputePacketMirroringMirroredResourcesInstancesOutputReference__runtime_type_checks.go
- computepacketmirroring_ComputePacketMirroringMirroredResourcesOutputReference.go
- computepacketmirroring_ComputePacketMirroringMirroredResourcesOutputReference__runtime_type_checks.go
- computepacketmirroring_ComputePacketMirroringMirroredResourcesSubnetworks.go
- computepacketmirroring_ComputePacketMirroringMirroredResourcesSubnetworksList.go
- computepacketmirroring_ComputePacketMirroringMirroredResourcesSubnetworksList__runtime_type_checks.go
- computepacketmirroring_ComputePacketMirroringMirroredResourcesSubnetworksOutputReference.go
- computepacketmirroring_ComputePacketMirroringMirroredResourcesSubnetworksOutputReference__runtime_type_checks.go
- computepacketmirroring_ComputePacketMirroringNetwork.go
- computepacketmirroring_ComputePacketMirroringNetworkOutputReference.go
- computepacketmirroring_ComputePacketMirroringNetworkOutputReference__runtime_type_checks.go
- computepacketmirroring_ComputePacketMirroringTimeouts.go
- computepacketmirroring_ComputePacketMirroringTimeoutsOutputReference.go
- computepacketmirroring_ComputePacketMirroringTimeoutsOutputReference__runtime_type_checks.go
- computepacketmirroring_ComputePacketMirroring__runtime_type_checks.go