Documentation
¶
Index ¶
- func ComputeRoute_IsConstruct(x interface{}) *bool
- func ComputeRoute_IsTerraformElement(x interface{}) *bool
- func ComputeRoute_IsTerraformResource(x interface{}) *bool
- func ComputeRoute_TfResourceType() *string
- func NewComputeRouteTimeoutsOutputReference_Override(c ComputeRouteTimeoutsOutputReference, ...)
- func NewComputeRoute_Override(c ComputeRoute, scope constructs.Construct, id *string, ...)
- type ComputeRoute
- type ComputeRouteConfig
- type ComputeRouteTimeouts
- type ComputeRouteTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComputeRoute_IsConstruct ¶
func ComputeRoute_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ComputeRoute_IsTerraformElement ¶
func ComputeRoute_IsTerraformElement(x interface{}) *bool
Experimental.
func ComputeRoute_IsTerraformResource ¶
func ComputeRoute_IsTerraformResource(x interface{}) *bool
Experimental.
func ComputeRoute_TfResourceType ¶
func ComputeRoute_TfResourceType() *string
func NewComputeRouteTimeoutsOutputReference_Override ¶
func NewComputeRouteTimeoutsOutputReference_Override(c ComputeRouteTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputeRoute_Override ¶
func NewComputeRoute_Override(c ComputeRoute, scope constructs.Construct, id *string, config *ComputeRouteConfig)
Create a new {@link https://www.terraform.io/docs/providers/google/r/compute_route google_compute_route} Resource.
Types ¶
type ComputeRoute ¶
type ComputeRoute interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DestRange() *string
SetDestRange(val *string)
DestRangeInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
Network() *string
SetNetwork(val *string)
NetworkInput() *string
NextHopGateway() *string
SetNextHopGateway(val *string)
NextHopGatewayInput() *string
NextHopIlb() *string
SetNextHopIlb(val *string)
NextHopIlbInput() *string
NextHopInstance() *string
SetNextHopInstance(val *string)
NextHopInstanceInput() *string
NextHopInstanceZone() *string
SetNextHopInstanceZone(val *string)
NextHopInstanceZoneInput() *string
NextHopIp() *string
SetNextHopIp(val *string)
NextHopIpInput() *string
NextHopNetwork() *string
NextHopVpnTunnel() *string
SetNextHopVpnTunnel(val *string)
NextHopVpnTunnelInput() *string
// The tree node.
Node() constructs.Node
Priority() *float64
SetPriority(val *float64)
PriorityInput() *float64
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SelfLink() *string
Tags() *[]*string
SetTags(val *[]*string)
TagsInput() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() ComputeRouteTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *ComputeRouteTimeouts)
ResetDescription()
ResetId()
ResetNextHopGateway()
ResetNextHopIlb()
ResetNextHopInstance()
ResetNextHopInstanceZone()
ResetNextHopIp()
ResetNextHopVpnTunnel()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPriority()
ResetProject()
ResetTags()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/google/r/compute_route google_compute_route}.
func NewComputeRoute ¶
func NewComputeRoute(scope constructs.Construct, id *string, config *ComputeRouteConfig) ComputeRoute
Create a new {@link https://www.terraform.io/docs/providers/google/r/compute_route google_compute_route} Resource.
type ComputeRouteConfig ¶
type ComputeRouteConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The destination range of outgoing packets that this route applies to. Only IPv4 is supported.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#dest_range ComputeRoute#dest_range}
DestRange *string `field:"required" json:"destRange" yaml:"destRange"`
// Name of the resource.
//
// Provided by the client when the resource is
// created. The name must be 1-63 characters long, and comply with
// RFC1035. Specifically, the name must be 1-63 characters long and
// match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means
// the first character must be a lowercase letter, and all following
// characters must be a dash, lowercase letter, or digit, except the
// last character, which cannot be a dash.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#name ComputeRoute#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The network that this route applies to.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#network ComputeRoute#network}
Network *string `field:"required" json:"network" yaml:"network"`
// An optional description of this resource. Provide this property when you create the resource.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#description ComputeRoute#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#id ComputeRoute#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// URL to a gateway that should handle matching packets.
//
// Currently, you can only specify the internet gateway, using a full or
// partial valid URL:
// 'https://www.googleapis.com/compute/v1/projects/project/global/gateways/default-internet-gateway'
// 'projects/project/global/gateways/default-internet-gateway'
// 'global/gateways/default-internet-gateway'
// The string 'default-internet-gateway'.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#next_hop_gateway ComputeRoute#next_hop_gateway}
NextHopGateway *string `field:"optional" json:"nextHopGateway" yaml:"nextHopGateway"`
// The IP address or URL to a forwarding rule of type loadBalancingScheme=INTERNAL that should handle matching packets.
//
// With the GA provider you can only specify the forwarding
// rule as a partial or full URL. For example, the following
// are all valid values:
// 10.128.0.56
// https://www.googleapis.com/compute/v1/projects/project/regions/region/forwardingRules/forwardingRule
// regions/region/forwardingRules/forwardingRule
//
// When the beta provider, you can also specify the IP address
// of a forwarding rule from the same VPC or any peered VPC.
//
// Note that this can only be used when the destinationRange is
// a public (non-RFC 1918) IP CIDR range.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#next_hop_ilb ComputeRoute#next_hop_ilb}
NextHopIlb *string `field:"optional" json:"nextHopIlb" yaml:"nextHopIlb"`
// URL to an instance that should handle matching packets.
//
// You can specify this as a full or partial URL. For example:
// 'https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/instance'
// 'projects/project/zones/zone/instances/instance'
// 'zones/zone/instances/instance'
// Just the instance name, with the zone in 'next_hop_instance_zone'.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#next_hop_instance ComputeRoute#next_hop_instance}
NextHopInstance *string `field:"optional" json:"nextHopInstance" yaml:"nextHopInstance"`
// The zone of the instance specified in next_hop_instance. Omit if next_hop_instance is specified as a URL.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#next_hop_instance_zone ComputeRoute#next_hop_instance_zone}
NextHopInstanceZone *string `field:"optional" json:"nextHopInstanceZone" yaml:"nextHopInstanceZone"`
// Network IP address of an instance that should handle matching packets.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#next_hop_ip ComputeRoute#next_hop_ip}
NextHopIp *string `field:"optional" json:"nextHopIp" yaml:"nextHopIp"`
// URL to a VpnTunnel that should handle matching packets.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#next_hop_vpn_tunnel ComputeRoute#next_hop_vpn_tunnel}
NextHopVpnTunnel *string `field:"optional" json:"nextHopVpnTunnel" yaml:"nextHopVpnTunnel"`
// The priority of this route.
//
// Priority is used to break ties in cases
// where there is more than one matching route of equal prefix length.
//
// In the case of two routes with equal prefix length, the one with the
// lowest-numbered priority value wins.
//
// Default value is 1000. Valid range is 0 through 65535.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#priority ComputeRoute#priority}
Priority *float64 `field:"optional" json:"priority" yaml:"priority"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#project ComputeRoute#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// A list of instance tags to which this route applies.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#tags ComputeRoute#tags}
Tags *[]*string `field:"optional" json:"tags" yaml:"tags"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#timeouts ComputeRoute#timeouts}
Timeouts *ComputeRouteTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type ComputeRouteTimeouts ¶
type ComputeRouteTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#create ComputeRoute#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_route#delete ComputeRoute#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type ComputeRouteTimeoutsOutputReference ¶
type ComputeRouteTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeRouteTimeoutsOutputReference ¶
func NewComputeRouteTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputeRouteTimeoutsOutputReference