Documentation
¶
Index ¶
- func ComputeServiceAttachment_IsConstruct(x interface{}) *bool
- func ComputeServiceAttachment_IsTerraformElement(x interface{}) *bool
- func ComputeServiceAttachment_IsTerraformResource(x interface{}) *bool
- func ComputeServiceAttachment_TfResourceType() *string
- func NewComputeServiceAttachmentConnectedEndpointsList_Override(c ComputeServiceAttachmentConnectedEndpointsList, ...)
- func NewComputeServiceAttachmentConnectedEndpointsOutputReference_Override(c ComputeServiceAttachmentConnectedEndpointsOutputReference, ...)
- func NewComputeServiceAttachmentConsumerAcceptListsList_Override(c ComputeServiceAttachmentConsumerAcceptListsList, ...)
- func NewComputeServiceAttachmentConsumerAcceptListsOutputReference_Override(c ComputeServiceAttachmentConsumerAcceptListsOutputReference, ...)
- func NewComputeServiceAttachmentTimeoutsOutputReference_Override(c ComputeServiceAttachmentTimeoutsOutputReference, ...)
- func NewComputeServiceAttachment_Override(c ComputeServiceAttachment, scope constructs.Construct, id *string, ...)
- type ComputeServiceAttachment
- type ComputeServiceAttachmentConfig
- type ComputeServiceAttachmentConnectedEndpoints
- type ComputeServiceAttachmentConnectedEndpointsList
- type ComputeServiceAttachmentConnectedEndpointsOutputReference
- type ComputeServiceAttachmentConsumerAcceptLists
- type ComputeServiceAttachmentConsumerAcceptListsList
- type ComputeServiceAttachmentConsumerAcceptListsOutputReference
- type ComputeServiceAttachmentTimeouts
- type ComputeServiceAttachmentTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComputeServiceAttachment_IsConstruct ¶
func ComputeServiceAttachment_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ComputeServiceAttachment_IsTerraformElement ¶
func ComputeServiceAttachment_IsTerraformElement(x interface{}) *bool
Experimental.
func ComputeServiceAttachment_IsTerraformResource ¶
func ComputeServiceAttachment_IsTerraformResource(x interface{}) *bool
Experimental.
func ComputeServiceAttachment_TfResourceType ¶
func ComputeServiceAttachment_TfResourceType() *string
func NewComputeServiceAttachmentConnectedEndpointsList_Override ¶
func NewComputeServiceAttachmentConnectedEndpointsList_Override(c ComputeServiceAttachmentConnectedEndpointsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewComputeServiceAttachmentConnectedEndpointsOutputReference_Override ¶
func NewComputeServiceAttachmentConnectedEndpointsOutputReference_Override(c ComputeServiceAttachmentConnectedEndpointsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewComputeServiceAttachmentConsumerAcceptListsList_Override ¶
func NewComputeServiceAttachmentConsumerAcceptListsList_Override(c ComputeServiceAttachmentConsumerAcceptListsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewComputeServiceAttachmentConsumerAcceptListsOutputReference_Override ¶
func NewComputeServiceAttachmentConsumerAcceptListsOutputReference_Override(c ComputeServiceAttachmentConsumerAcceptListsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewComputeServiceAttachmentTimeoutsOutputReference_Override ¶
func NewComputeServiceAttachmentTimeoutsOutputReference_Override(c ComputeServiceAttachmentTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputeServiceAttachment_Override ¶
func NewComputeServiceAttachment_Override(c ComputeServiceAttachment, scope constructs.Construct, id *string, config *ComputeServiceAttachmentConfig)
Create a new {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment google_compute_service_attachment} Resource.
Types ¶
type ComputeServiceAttachment ¶
type ComputeServiceAttachment interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
ConnectedEndpoints() ComputeServiceAttachmentConnectedEndpointsList
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
ConnectionPreference() *string
SetConnectionPreference(val *string)
ConnectionPreferenceInput() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ConsumerAcceptLists() ComputeServiceAttachmentConsumerAcceptListsList
ConsumerAcceptListsInput() interface{}
ConsumerRejectLists() *[]*string
SetConsumerRejectLists(val *[]*string)
ConsumerRejectListsInput() *[]*string
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DomainNames() *[]*string
SetDomainNames(val *[]*string)
DomainNamesInput() *[]*string
EnableProxyProtocol() interface{}
SetEnableProxyProtocol(val interface{})
EnableProxyProtocolInput() interface{}
Fingerprint() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
NatSubnets() *[]*string
SetNatSubnets(val *[]*string)
NatSubnetsInput() *[]*string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
SelfLink() *string
TargetService() *string
SetTargetService(val *string)
TargetServiceInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() ComputeServiceAttachmentTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutConsumerAcceptLists(value interface{})
PutTimeouts(value *ComputeServiceAttachmentTimeouts)
ResetConsumerAcceptLists()
ResetConsumerRejectLists()
ResetDescription()
ResetDomainNames()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment google_compute_service_attachment}.
func NewComputeServiceAttachment ¶
func NewComputeServiceAttachment(scope constructs.Construct, id *string, config *ComputeServiceAttachmentConfig) ComputeServiceAttachment
Create a new {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment google_compute_service_attachment} Resource.
type ComputeServiceAttachmentConfig ¶
type ComputeServiceAttachmentConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The connection preference to use for this service attachment. Valid values include "ACCEPT_AUTOMATIC", "ACCEPT_MANUAL".
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#connection_preference ComputeServiceAttachment#connection_preference}
ConnectionPreference *string `field:"required" json:"connectionPreference" yaml:"connectionPreference"`
// If true, enable the proxy protocol which is for supplying client TCP/IP address data in TCP connections that traverse proxies on their way to destination servers.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#enable_proxy_protocol ComputeServiceAttachment#enable_proxy_protocol}
EnableProxyProtocol interface{} `field:"required" json:"enableProxyProtocol" yaml:"enableProxyProtocol"`
// Name of the resource.
//
// The name must be 1-63 characters long, and
// comply with RFC1035. Specifically, the name must be 1-63 characters
// long and match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?'
// which means the first character must be a lowercase letter, and all
// following characters must be a dash, lowercase letter, or digit,
// except the last character, which cannot be a dash.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#name ComputeServiceAttachment#name}
Name *string `field:"required" json:"name" yaml:"name"`
// An array of subnets that is provided for NAT in this service attachment.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#nat_subnets ComputeServiceAttachment#nat_subnets}
NatSubnets *[]*string `field:"required" json:"natSubnets" yaml:"natSubnets"`
// The URL of a forwarding rule that represents the service identified by this service attachment.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#target_service ComputeServiceAttachment#target_service}
TargetService *string `field:"required" json:"targetService" yaml:"targetService"`
// consumer_accept_lists block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#consumer_accept_lists ComputeServiceAttachment#consumer_accept_lists}
ConsumerAcceptLists interface{} `field:"optional" json:"consumerAcceptLists" yaml:"consumerAcceptLists"`
// An array of projects that are not allowed to connect to this service attachment.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#consumer_reject_lists ComputeServiceAttachment#consumer_reject_lists}
ConsumerRejectLists *[]*string `field:"optional" json:"consumerRejectLists" yaml:"consumerRejectLists"`
// An optional description of this resource.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#description ComputeServiceAttachment#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// If specified, the domain name will be used during the integration between the PSC connected endpoints and the Cloud DNS.
//
// For example, this is a
// valid domain name: "p.mycompany.com.". Current max number of domain names
// supported is 1.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#domain_names ComputeServiceAttachment#domain_names}
DomainNames *[]*string `field:"optional" json:"domainNames" yaml:"domainNames"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#id ComputeServiceAttachment#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#project ComputeServiceAttachment#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// URL of the region where the resource resides.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#region ComputeServiceAttachment#region}
Region *string `field:"optional" json:"region" yaml:"region"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#timeouts ComputeServiceAttachment#timeouts}
Timeouts *ComputeServiceAttachmentTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type ComputeServiceAttachmentConnectedEndpoints ¶
type ComputeServiceAttachmentConnectedEndpoints struct {
}
type ComputeServiceAttachmentConnectedEndpointsList ¶
type ComputeServiceAttachmentConnectedEndpointsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ComputeServiceAttachmentConnectedEndpointsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeServiceAttachmentConnectedEndpointsList ¶
func NewComputeServiceAttachmentConnectedEndpointsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ComputeServiceAttachmentConnectedEndpointsList
type ComputeServiceAttachmentConnectedEndpointsOutputReference ¶
type ComputeServiceAttachmentConnectedEndpointsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Endpoint() *string
// Experimental.
Fqn() *string
InternalValue() *ComputeServiceAttachmentConnectedEndpoints
SetInternalValue(val *ComputeServiceAttachmentConnectedEndpoints)
Status() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeServiceAttachmentConnectedEndpointsOutputReference ¶
func NewComputeServiceAttachmentConnectedEndpointsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ComputeServiceAttachmentConnectedEndpointsOutputReference
type ComputeServiceAttachmentConsumerAcceptLists ¶
type ComputeServiceAttachmentConsumerAcceptLists struct {
// The number of consumer forwarding rules the consumer project can create.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#connection_limit ComputeServiceAttachment#connection_limit}
ConnectionLimit *float64 `field:"required" json:"connectionLimit" yaml:"connectionLimit"`
// A project that is allowed to connect to this service attachment.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#project_id_or_num ComputeServiceAttachment#project_id_or_num}
ProjectIdOrNum *string `field:"required" json:"projectIdOrNum" yaml:"projectIdOrNum"`
}
type ComputeServiceAttachmentConsumerAcceptListsList ¶
type ComputeServiceAttachmentConsumerAcceptListsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ComputeServiceAttachmentConsumerAcceptListsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeServiceAttachmentConsumerAcceptListsList ¶
func NewComputeServiceAttachmentConsumerAcceptListsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ComputeServiceAttachmentConsumerAcceptListsList
type ComputeServiceAttachmentConsumerAcceptListsOutputReference ¶
type ComputeServiceAttachmentConsumerAcceptListsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ConnectionLimit() *float64
SetConnectionLimit(val *float64)
ConnectionLimitInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
ProjectIdOrNum() *string
SetProjectIdOrNum(val *string)
ProjectIdOrNumInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeServiceAttachmentConsumerAcceptListsOutputReference ¶
func NewComputeServiceAttachmentConsumerAcceptListsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ComputeServiceAttachmentConsumerAcceptListsOutputReference
type ComputeServiceAttachmentTimeouts ¶
type ComputeServiceAttachmentTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#create ComputeServiceAttachment#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#delete ComputeServiceAttachment#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_service_attachment#update ComputeServiceAttachment#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type ComputeServiceAttachmentTimeoutsOutputReference ¶
type ComputeServiceAttachmentTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeServiceAttachmentTimeoutsOutputReference ¶
func NewComputeServiceAttachmentTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputeServiceAttachmentTimeoutsOutputReference
Source Files
¶
- computeserviceattachment.go
- computeserviceattachment_ComputeServiceAttachment.go
- computeserviceattachment_ComputeServiceAttachmentConfig.go
- computeserviceattachment_ComputeServiceAttachmentConnectedEndpoints.go
- computeserviceattachment_ComputeServiceAttachmentConnectedEndpointsList.go
- computeserviceattachment_ComputeServiceAttachmentConnectedEndpointsList__runtime_type_checks.go
- computeserviceattachment_ComputeServiceAttachmentConnectedEndpointsOutputReference.go
- computeserviceattachment_ComputeServiceAttachmentConnectedEndpointsOutputReference__runtime_type_checks.go
- computeserviceattachment_ComputeServiceAttachmentConsumerAcceptLists.go
- computeserviceattachment_ComputeServiceAttachmentConsumerAcceptListsList.go
- computeserviceattachment_ComputeServiceAttachmentConsumerAcceptListsList__runtime_type_checks.go
- computeserviceattachment_ComputeServiceAttachmentConsumerAcceptListsOutputReference.go
- computeserviceattachment_ComputeServiceAttachmentConsumerAcceptListsOutputReference__runtime_type_checks.go
- computeserviceattachment_ComputeServiceAttachmentTimeouts.go
- computeserviceattachment_ComputeServiceAttachmentTimeoutsOutputReference.go
- computeserviceattachment_ComputeServiceAttachmentTimeoutsOutputReference__runtime_type_checks.go
- computeserviceattachment_ComputeServiceAttachment__runtime_type_checks.go