Documentation
¶
Index ¶
- func DataGoogleComputeImage_IsConstruct(x interface{}) *bool
- func DataGoogleComputeImage_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleComputeImage_IsTerraformElement(x interface{}) *bool
- func DataGoogleComputeImage_TfResourceType() *string
- func NewDataGoogleComputeImage_Override(d DataGoogleComputeImage, scope constructs.Construct, id *string, ...)
- type DataGoogleComputeImage
- type DataGoogleComputeImageConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleComputeImage_IsConstruct ¶
func DataGoogleComputeImage_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleComputeImage_IsTerraformDataSource ¶
func DataGoogleComputeImage_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleComputeImage_IsTerraformElement ¶
func DataGoogleComputeImage_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleComputeImage_TfResourceType ¶
func DataGoogleComputeImage_TfResourceType() *string
func NewDataGoogleComputeImage_Override ¶
func NewDataGoogleComputeImage_Override(d DataGoogleComputeImage, scope constructs.Construct, id *string, config *DataGoogleComputeImageConfig)
Create a new {@link https://www.terraform.io/docs/providers/google/d/compute_image google_compute_image} Data Source.
Types ¶
type DataGoogleComputeImage ¶
type DataGoogleComputeImage interface {
cdktf.TerraformDataSource
ArchiveSizeBytes() *float64
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreationTimestamp() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
DiskSizeGb() *float64
Family() *string
SetFamily(val *string)
FamilyInput() *string
Filter() *string
SetFilter(val *string)
FilterInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
ImageEncryptionKeySha256() *string
ImageId() *string
LabelFingerprint() *string
Labels() cdktf.StringMap
Licenses() *[]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
SelfLink() *string
SourceDisk() *string
SourceDiskEncryptionKeySha256() *string
SourceDiskId() *string
SourceImageId() *string
Status() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetFamily()
ResetFilter()
ResetId()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/google/d/compute_image google_compute_image}.
func NewDataGoogleComputeImage ¶
func NewDataGoogleComputeImage(scope constructs.Construct, id *string, config *DataGoogleComputeImageConfig) DataGoogleComputeImage
Create a new {@link https://www.terraform.io/docs/providers/google/d/compute_image google_compute_image} Data Source.
type DataGoogleComputeImageConfig ¶
type DataGoogleComputeImageConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_image#family DataGoogleComputeImage#family}.
Family *string `field:"optional" json:"family" yaml:"family"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_image#filter DataGoogleComputeImage#filter}.
Filter *string `field:"optional" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_image#id DataGoogleComputeImage#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_image#name DataGoogleComputeImage#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_image#project DataGoogleComputeImage#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
}