Documentation
¶
Index ¶
- func DeploymentManagerDeployment_IsConstruct(x interface{}) *bool
- func DeploymentManagerDeployment_IsTerraformElement(x interface{}) *bool
- func DeploymentManagerDeployment_IsTerraformResource(x interface{}) *bool
- func DeploymentManagerDeployment_TfResourceType() *string
- func NewDeploymentManagerDeploymentLabelsList_Override(d DeploymentManagerDeploymentLabelsList, ...)
- func NewDeploymentManagerDeploymentLabelsOutputReference_Override(d DeploymentManagerDeploymentLabelsOutputReference, ...)
- func NewDeploymentManagerDeploymentTargetConfigOutputReference_Override(d DeploymentManagerDeploymentTargetConfigOutputReference, ...)
- func NewDeploymentManagerDeploymentTargetImportsList_Override(d DeploymentManagerDeploymentTargetImportsList, ...)
- func NewDeploymentManagerDeploymentTargetImportsOutputReference_Override(d DeploymentManagerDeploymentTargetImportsOutputReference, ...)
- func NewDeploymentManagerDeploymentTargetOutputReference_Override(d DeploymentManagerDeploymentTargetOutputReference, ...)
- func NewDeploymentManagerDeploymentTimeoutsOutputReference_Override(d DeploymentManagerDeploymentTimeoutsOutputReference, ...)
- func NewDeploymentManagerDeployment_Override(d DeploymentManagerDeployment, scope constructs.Construct, id *string, ...)
- type DeploymentManagerDeployment
- type DeploymentManagerDeploymentConfig
- type DeploymentManagerDeploymentLabels
- type DeploymentManagerDeploymentLabelsList
- type DeploymentManagerDeploymentLabelsOutputReference
- type DeploymentManagerDeploymentTarget
- type DeploymentManagerDeploymentTargetConfig
- type DeploymentManagerDeploymentTargetConfigOutputReference
- type DeploymentManagerDeploymentTargetImports
- type DeploymentManagerDeploymentTargetImportsList
- type DeploymentManagerDeploymentTargetImportsOutputReference
- type DeploymentManagerDeploymentTargetOutputReference
- type DeploymentManagerDeploymentTimeouts
- type DeploymentManagerDeploymentTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeploymentManagerDeployment_IsConstruct ¶
func DeploymentManagerDeployment_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DeploymentManagerDeployment_IsTerraformElement ¶
func DeploymentManagerDeployment_IsTerraformElement(x interface{}) *bool
Experimental.
func DeploymentManagerDeployment_IsTerraformResource ¶
func DeploymentManagerDeployment_IsTerraformResource(x interface{}) *bool
Experimental.
func DeploymentManagerDeployment_TfResourceType ¶
func DeploymentManagerDeployment_TfResourceType() *string
func NewDeploymentManagerDeploymentLabelsList_Override ¶
func NewDeploymentManagerDeploymentLabelsList_Override(d DeploymentManagerDeploymentLabelsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDeploymentManagerDeploymentLabelsOutputReference_Override ¶
func NewDeploymentManagerDeploymentLabelsOutputReference_Override(d DeploymentManagerDeploymentLabelsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDeploymentManagerDeploymentTargetConfigOutputReference_Override ¶
func NewDeploymentManagerDeploymentTargetConfigOutputReference_Override(d DeploymentManagerDeploymentTargetConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDeploymentManagerDeploymentTargetImportsList_Override ¶
func NewDeploymentManagerDeploymentTargetImportsList_Override(d DeploymentManagerDeploymentTargetImportsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDeploymentManagerDeploymentTargetImportsOutputReference_Override ¶
func NewDeploymentManagerDeploymentTargetImportsOutputReference_Override(d DeploymentManagerDeploymentTargetImportsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDeploymentManagerDeploymentTargetOutputReference_Override ¶
func NewDeploymentManagerDeploymentTargetOutputReference_Override(d DeploymentManagerDeploymentTargetOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDeploymentManagerDeploymentTimeoutsOutputReference_Override ¶
func NewDeploymentManagerDeploymentTimeoutsOutputReference_Override(d DeploymentManagerDeploymentTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDeploymentManagerDeployment_Override ¶
func NewDeploymentManagerDeployment_Override(d DeploymentManagerDeployment, scope constructs.Construct, id *string, config *DeploymentManagerDeploymentConfig)
Create a new {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment google_deployment_manager_deployment} Resource.
Types ¶
type DeploymentManagerDeployment ¶
type DeploymentManagerDeployment interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreatePolicy() *string
SetCreatePolicy(val *string)
CreatePolicyInput() *string
DeletePolicy() *string
SetDeletePolicy(val *string)
DeletePolicyInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeploymentId() *string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() DeploymentManagerDeploymentLabelsList
LabelsInput() interface{}
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Manifest() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Preview() interface{}
SetPreview(val interface{})
PreviewInput() interface{}
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SelfLink() *string
Target() DeploymentManagerDeploymentTargetOutputReference
TargetInput() *DeploymentManagerDeploymentTarget
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DeploymentManagerDeploymentTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutLabels(value interface{})
PutTarget(value *DeploymentManagerDeploymentTarget)
PutTimeouts(value *DeploymentManagerDeploymentTimeouts)
ResetCreatePolicy()
ResetDeletePolicy()
ResetDescription()
ResetId()
ResetLabels()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPreview()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment google_deployment_manager_deployment}.
func NewDeploymentManagerDeployment ¶
func NewDeploymentManagerDeployment(scope constructs.Construct, id *string, config *DeploymentManagerDeploymentConfig) DeploymentManagerDeployment
Create a new {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment google_deployment_manager_deployment} Resource.
type DeploymentManagerDeploymentConfig ¶
type DeploymentManagerDeploymentConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Unique name for the deployment.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#name DeploymentManagerDeployment#name}
Name *string `field:"required" json:"name" yaml:"name"`
// target block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#target DeploymentManagerDeployment#target}
Target *DeploymentManagerDeploymentTarget `field:"required" json:"target" yaml:"target"`
// Set the policy to use for creating new resources.
//
// Only used on
// create and update. Valid values are 'CREATE_OR_ACQUIRE' (default) or
// 'ACQUIRE'. If set to 'ACQUIRE' and resources do not already exist,
// the deployment will fail. Note that updating this field does not
// actually affect the deployment, just how it is updated. Default value: "CREATE_OR_ACQUIRE" Possible values: ["ACQUIRE", "CREATE_OR_ACQUIRE"]
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#create_policy DeploymentManagerDeployment#create_policy}
CreatePolicy *string `field:"optional" json:"createPolicy" yaml:"createPolicy"`
// Set the policy to use for deleting new resources on update/delete.
//
// Valid values are 'DELETE' (default) or 'ABANDON'. If 'DELETE',
// resource is deleted after removal from Deployment Manager. If
// 'ABANDON', the resource is only removed from Deployment Manager
// and is not actually deleted. Note that updating this field does not
// actually change the deployment, just how it is updated. Default value: "DELETE" Possible values: ["ABANDON", "DELETE"]
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#delete_policy DeploymentManagerDeployment#delete_policy}
DeletePolicy *string `field:"optional" json:"deletePolicy" yaml:"deletePolicy"`
// Optional user-provided description of deployment.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#description DeploymentManagerDeployment#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#id DeploymentManagerDeployment#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// labels block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#labels DeploymentManagerDeployment#labels}
Labels interface{} `field:"optional" json:"labels" yaml:"labels"`
// If set to true, a deployment is created with "shell" resources that are not actually instantiated.
//
// This allows you to preview a
// deployment. It can be updated to false to actually deploy
// with real resources.
// ~>**NOTE:** Deployment Manager does not allow update
// of a deployment in preview (unless updating to preview=false). Thus,
// Terraform will force-recreate deployments if either preview is updated
// to true or if other fields are updated while preview is true.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#preview DeploymentManagerDeployment#preview}
Preview interface{} `field:"optional" json:"preview" yaml:"preview"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#project DeploymentManagerDeployment#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#timeouts DeploymentManagerDeployment#timeouts}
Timeouts *DeploymentManagerDeploymentTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DeploymentManagerDeploymentLabels ¶
type DeploymentManagerDeploymentLabels struct {
// Key for label.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#key DeploymentManagerDeployment#key}
Key *string `field:"optional" json:"key" yaml:"key"`
// Value of label.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#value DeploymentManagerDeployment#value}
Value *string `field:"optional" json:"value" yaml:"value"`
}
type DeploymentManagerDeploymentLabelsList ¶
type DeploymentManagerDeploymentLabelsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DeploymentManagerDeploymentLabelsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDeploymentManagerDeploymentLabelsList ¶
func NewDeploymentManagerDeploymentLabelsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DeploymentManagerDeploymentLabelsList
type DeploymentManagerDeploymentLabelsOutputReference ¶
type DeploymentManagerDeploymentLabelsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKey()
ResetValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDeploymentManagerDeploymentLabelsOutputReference ¶
func NewDeploymentManagerDeploymentLabelsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DeploymentManagerDeploymentLabelsOutputReference
type DeploymentManagerDeploymentTarget ¶
type DeploymentManagerDeploymentTarget struct {
// config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#config DeploymentManagerDeployment#config}
Config *DeploymentManagerDeploymentTargetConfig `field:"required" json:"config" yaml:"config"`
// imports block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#imports DeploymentManagerDeployment#imports}
Imports interface{} `field:"optional" json:"imports" yaml:"imports"`
}
type DeploymentManagerDeploymentTargetConfig ¶
type DeploymentManagerDeploymentTargetConfig struct {
// The full YAML contents of your configuration file.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#content DeploymentManagerDeployment#content}
Content *string `field:"required" json:"content" yaml:"content"`
}
type DeploymentManagerDeploymentTargetConfigOutputReference ¶
type DeploymentManagerDeploymentTargetConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Content() *string
SetContent(val *string)
ContentInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DeploymentManagerDeploymentTargetConfig
SetInternalValue(val *DeploymentManagerDeploymentTargetConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDeploymentManagerDeploymentTargetConfigOutputReference ¶
func NewDeploymentManagerDeploymentTargetConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DeploymentManagerDeploymentTargetConfigOutputReference
type DeploymentManagerDeploymentTargetImports ¶
type DeploymentManagerDeploymentTargetImports struct {
// The full contents of the template that you want to import.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#content DeploymentManagerDeployment#content}
Content *string `field:"optional" json:"content" yaml:"content"`
// The name of the template to import, as declared in the YAML configuration.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#name DeploymentManagerDeployment#name}
Name *string `field:"optional" json:"name" yaml:"name"`
}
type DeploymentManagerDeploymentTargetImportsList ¶
type DeploymentManagerDeploymentTargetImportsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DeploymentManagerDeploymentTargetImportsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDeploymentManagerDeploymentTargetImportsList ¶
func NewDeploymentManagerDeploymentTargetImportsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DeploymentManagerDeploymentTargetImportsList
type DeploymentManagerDeploymentTargetImportsOutputReference ¶
type DeploymentManagerDeploymentTargetImportsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Content() *string
SetContent(val *string)
ContentInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetContent()
ResetName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDeploymentManagerDeploymentTargetImportsOutputReference ¶
func NewDeploymentManagerDeploymentTargetImportsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DeploymentManagerDeploymentTargetImportsOutputReference
type DeploymentManagerDeploymentTargetOutputReference ¶
type DeploymentManagerDeploymentTargetOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Config() DeploymentManagerDeploymentTargetConfigOutputReference
ConfigInput() *DeploymentManagerDeploymentTargetConfig
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Imports() DeploymentManagerDeploymentTargetImportsList
ImportsInput() interface{}
InternalValue() *DeploymentManagerDeploymentTarget
SetInternalValue(val *DeploymentManagerDeploymentTarget)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutConfig(value *DeploymentManagerDeploymentTargetConfig)
PutImports(value interface{})
ResetImports()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDeploymentManagerDeploymentTargetOutputReference ¶
func NewDeploymentManagerDeploymentTargetOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DeploymentManagerDeploymentTargetOutputReference
type DeploymentManagerDeploymentTimeouts ¶
type DeploymentManagerDeploymentTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#create DeploymentManagerDeployment#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#delete DeploymentManagerDeployment#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/deployment_manager_deployment#update DeploymentManagerDeployment#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type DeploymentManagerDeploymentTimeoutsOutputReference ¶
type DeploymentManagerDeploymentTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDeploymentManagerDeploymentTimeoutsOutputReference ¶
func NewDeploymentManagerDeploymentTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DeploymentManagerDeploymentTimeoutsOutputReference
Source Files
¶
- deploymentmanagerdeployment.go
- deploymentmanagerdeployment_DeploymentManagerDeployment.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentConfig.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentLabels.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentLabelsList.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentLabelsList__runtime_type_checks.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentLabelsOutputReference.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentLabelsOutputReference__runtime_type_checks.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentTarget.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentTargetConfig.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentTargetConfigOutputReference.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentTargetConfigOutputReference__runtime_type_checks.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentTargetImports.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentTargetImportsList.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentTargetImportsList__runtime_type_checks.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentTargetImportsOutputReference.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentTargetImportsOutputReference__runtime_type_checks.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentTargetOutputReference.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentTargetOutputReference__runtime_type_checks.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentTimeouts.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentTimeoutsOutputReference.go
- deploymentmanagerdeployment_DeploymentManagerDeploymentTimeoutsOutputReference__runtime_type_checks.go
- deploymentmanagerdeployment_DeploymentManagerDeployment__runtime_type_checks.go