Documentation
¶
Index ¶
- func DialogflowFulfillment_IsConstruct(x interface{}) *bool
- func DialogflowFulfillment_IsTerraformElement(x interface{}) *bool
- func DialogflowFulfillment_IsTerraformResource(x interface{}) *bool
- func DialogflowFulfillment_TfResourceType() *string
- func NewDialogflowFulfillmentFeaturesList_Override(d DialogflowFulfillmentFeaturesList, ...)
- func NewDialogflowFulfillmentFeaturesOutputReference_Override(d DialogflowFulfillmentFeaturesOutputReference, ...)
- func NewDialogflowFulfillmentGenericWebServiceOutputReference_Override(d DialogflowFulfillmentGenericWebServiceOutputReference, ...)
- func NewDialogflowFulfillmentTimeoutsOutputReference_Override(d DialogflowFulfillmentTimeoutsOutputReference, ...)
- func NewDialogflowFulfillment_Override(d DialogflowFulfillment, scope constructs.Construct, id *string, ...)
- type DialogflowFulfillment
- type DialogflowFulfillmentConfig
- type DialogflowFulfillmentFeatures
- type DialogflowFulfillmentFeaturesList
- type DialogflowFulfillmentFeaturesOutputReference
- type DialogflowFulfillmentGenericWebService
- type DialogflowFulfillmentGenericWebServiceOutputReference
- type DialogflowFulfillmentTimeouts
- type DialogflowFulfillmentTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DialogflowFulfillment_IsConstruct ¶
func DialogflowFulfillment_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DialogflowFulfillment_IsTerraformElement ¶
func DialogflowFulfillment_IsTerraformElement(x interface{}) *bool
Experimental.
func DialogflowFulfillment_IsTerraformResource ¶
func DialogflowFulfillment_IsTerraformResource(x interface{}) *bool
Experimental.
func DialogflowFulfillment_TfResourceType ¶
func DialogflowFulfillment_TfResourceType() *string
func NewDialogflowFulfillmentFeaturesList_Override ¶
func NewDialogflowFulfillmentFeaturesList_Override(d DialogflowFulfillmentFeaturesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDialogflowFulfillmentFeaturesOutputReference_Override ¶
func NewDialogflowFulfillmentFeaturesOutputReference_Override(d DialogflowFulfillmentFeaturesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDialogflowFulfillmentGenericWebServiceOutputReference_Override ¶
func NewDialogflowFulfillmentGenericWebServiceOutputReference_Override(d DialogflowFulfillmentGenericWebServiceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDialogflowFulfillmentTimeoutsOutputReference_Override ¶
func NewDialogflowFulfillmentTimeoutsOutputReference_Override(d DialogflowFulfillmentTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDialogflowFulfillment_Override ¶
func NewDialogflowFulfillment_Override(d DialogflowFulfillment, scope constructs.Construct, id *string, config *DialogflowFulfillmentConfig)
Create a new {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment google_dialogflow_fulfillment} Resource.
Types ¶
type DialogflowFulfillment ¶
type DialogflowFulfillment interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
Features() DialogflowFulfillmentFeaturesList
FeaturesInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GenericWebService() DialogflowFulfillmentGenericWebServiceOutputReference
GenericWebServiceInput() *DialogflowFulfillmentGenericWebService
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DialogflowFulfillmentTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutFeatures(value interface{})
PutGenericWebService(value *DialogflowFulfillmentGenericWebService)
PutTimeouts(value *DialogflowFulfillmentTimeouts)
ResetEnabled()
ResetFeatures()
ResetGenericWebService()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment google_dialogflow_fulfillment}.
func NewDialogflowFulfillment ¶
func NewDialogflowFulfillment(scope constructs.Construct, id *string, config *DialogflowFulfillmentConfig) DialogflowFulfillment
Create a new {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment google_dialogflow_fulfillment} Resource.
type DialogflowFulfillmentConfig ¶
type DialogflowFulfillmentConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The human-readable name of the fulfillment, unique within the agent.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#display_name DialogflowFulfillment#display_name}
DisplayName *string `field:"required" json:"displayName" yaml:"displayName"`
// Whether fulfillment is enabled.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#enabled DialogflowFulfillment#enabled}
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// features block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#features DialogflowFulfillment#features}
Features interface{} `field:"optional" json:"features" yaml:"features"`
// generic_web_service block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#generic_web_service DialogflowFulfillment#generic_web_service}
GenericWebService *DialogflowFulfillmentGenericWebService `field:"optional" json:"genericWebService" yaml:"genericWebService"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#id DialogflowFulfillment#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#project DialogflowFulfillment#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#timeouts DialogflowFulfillment#timeouts}
Timeouts *DialogflowFulfillmentTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DialogflowFulfillmentFeatures ¶
type DialogflowFulfillmentFeatures struct {
// The type of the feature that enabled for fulfillment. SMALLTALK: Fulfillment is enabled for SmallTalk. Possible values: ["SMALLTALK"].
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#type DialogflowFulfillment#type}
Type *string `field:"required" json:"type" yaml:"type"`
}
type DialogflowFulfillmentFeaturesList ¶
type DialogflowFulfillmentFeaturesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DialogflowFulfillmentFeaturesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDialogflowFulfillmentFeaturesList ¶
func NewDialogflowFulfillmentFeaturesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DialogflowFulfillmentFeaturesList
type DialogflowFulfillmentFeaturesOutputReference ¶
type DialogflowFulfillmentFeaturesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDialogflowFulfillmentFeaturesOutputReference ¶
func NewDialogflowFulfillmentFeaturesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DialogflowFulfillmentFeaturesOutputReference
type DialogflowFulfillmentGenericWebService ¶
type DialogflowFulfillmentGenericWebService struct {
// The fulfillment URI for receiving POST requests. It must use https protocol.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#uri DialogflowFulfillment#uri}
Uri *string `field:"required" json:"uri" yaml:"uri"`
// The password for HTTP Basic authentication.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#password DialogflowFulfillment#password}
Password *string `field:"optional" json:"password" yaml:"password"`
// The HTTP request headers to send together with fulfillment requests.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#request_headers DialogflowFulfillment#request_headers}
RequestHeaders *map[string]*string `field:"optional" json:"requestHeaders" yaml:"requestHeaders"`
// The user name for HTTP Basic authentication.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#username DialogflowFulfillment#username}
Username *string `field:"optional" json:"username" yaml:"username"`
}
type DialogflowFulfillmentGenericWebServiceOutputReference ¶
type DialogflowFulfillmentGenericWebServiceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DialogflowFulfillmentGenericWebService
SetInternalValue(val *DialogflowFulfillmentGenericWebService)
Password() *string
SetPassword(val *string)
PasswordInput() *string
RequestHeaders() *map[string]*string
SetRequestHeaders(val *map[string]*string)
RequestHeadersInput() *map[string]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Uri() *string
SetUri(val *string)
UriInput() *string
Username() *string
SetUsername(val *string)
UsernameInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPassword()
ResetRequestHeaders()
ResetUsername()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDialogflowFulfillmentGenericWebServiceOutputReference ¶
func NewDialogflowFulfillmentGenericWebServiceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DialogflowFulfillmentGenericWebServiceOutputReference
type DialogflowFulfillmentTimeouts ¶
type DialogflowFulfillmentTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#create DialogflowFulfillment#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#delete DialogflowFulfillment#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_fulfillment#update DialogflowFulfillment#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type DialogflowFulfillmentTimeoutsOutputReference ¶
type DialogflowFulfillmentTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDialogflowFulfillmentTimeoutsOutputReference ¶
func NewDialogflowFulfillmentTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DialogflowFulfillmentTimeoutsOutputReference
Source Files
¶
- dialogflowfulfillment.go
- dialogflowfulfillment_DialogflowFulfillment.go
- dialogflowfulfillment_DialogflowFulfillmentConfig.go
- dialogflowfulfillment_DialogflowFulfillmentFeatures.go
- dialogflowfulfillment_DialogflowFulfillmentFeaturesList.go
- dialogflowfulfillment_DialogflowFulfillmentFeaturesList__runtime_type_checks.go
- dialogflowfulfillment_DialogflowFulfillmentFeaturesOutputReference.go
- dialogflowfulfillment_DialogflowFulfillmentFeaturesOutputReference__runtime_type_checks.go
- dialogflowfulfillment_DialogflowFulfillmentGenericWebService.go
- dialogflowfulfillment_DialogflowFulfillmentGenericWebServiceOutputReference.go
- dialogflowfulfillment_DialogflowFulfillmentGenericWebServiceOutputReference__runtime_type_checks.go
- dialogflowfulfillment_DialogflowFulfillmentTimeouts.go
- dialogflowfulfillment_DialogflowFulfillmentTimeoutsOutputReference.go
- dialogflowfulfillment_DialogflowFulfillmentTimeoutsOutputReference__runtime_type_checks.go
- dialogflowfulfillment_DialogflowFulfillment__runtime_type_checks.go