Documentation
¶
Index ¶
- func DataGoogleIapClient_IsConstruct(x interface{}) *bool
- func DataGoogleIapClient_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleIapClient_IsTerraformElement(x interface{}) *bool
- func DataGoogleIapClient_TfResourceType() *string
- func NewDataGoogleIapClient_Override(d DataGoogleIapClient, scope constructs.Construct, id *string, ...)
- type DataGoogleIapClient
- type DataGoogleIapClientConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleIapClient_IsConstruct ¶
func DataGoogleIapClient_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleIapClient_IsTerraformDataSource ¶
func DataGoogleIapClient_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleIapClient_IsTerraformElement ¶
func DataGoogleIapClient_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleIapClient_TfResourceType ¶
func DataGoogleIapClient_TfResourceType() *string
func NewDataGoogleIapClient_Override ¶
func NewDataGoogleIapClient_Override(d DataGoogleIapClient, scope constructs.Construct, id *string, config *DataGoogleIapClientConfig)
Create a new {@link https://www.terraform.io/docs/providers/google/d/iap_client google_iap_client} Data Source.
Types ¶
type DataGoogleIapClient ¶
type DataGoogleIapClient interface {
cdktf.TerraformDataSource
Brand() *string
SetBrand(val *string)
BrandInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClientId() *string
SetClientId(val *string)
ClientIdInput() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Secret() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/google/d/iap_client google_iap_client}.
func NewDataGoogleIapClient ¶
func NewDataGoogleIapClient(scope constructs.Construct, id *string, config *DataGoogleIapClientConfig) DataGoogleIapClient
Create a new {@link https://www.terraform.io/docs/providers/google/d/iap_client google_iap_client} Data Source.
type DataGoogleIapClientConfig ¶
type DataGoogleIapClientConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Identifier of the brand to which this client is attached to. The format is 'projects/{project_number}/brands/{brand_id}/identityAwareProxyClients/{client_id}'.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/iap_client#brand DataGoogleIapClient#brand}
Brand *string `field:"required" json:"brand" yaml:"brand"`
// Output only. Unique identifier of the OAuth client.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/iap_client#client_id DataGoogleIapClient#client_id}
ClientId *string `field:"required" json:"clientId" yaml:"clientId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/iap_client#id DataGoogleIapClient#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}