Documentation
¶
Index ¶
- func AlloydbInstance_IsConstruct(x interface{}) *bool
- func AlloydbInstance_IsTerraformElement(x interface{}) *bool
- func AlloydbInstance_IsTerraformResource(x interface{}) *bool
- func AlloydbInstance_TfResourceType() *string
- func NewAlloydbInstanceMachineConfigOutputReference_Override(a AlloydbInstanceMachineConfigOutputReference, ...)
- func NewAlloydbInstanceReadPoolConfigOutputReference_Override(a AlloydbInstanceReadPoolConfigOutputReference, ...)
- func NewAlloydbInstanceTimeoutsOutputReference_Override(a AlloydbInstanceTimeoutsOutputReference, ...)
- func NewAlloydbInstance_Override(a AlloydbInstance, scope constructs.Construct, id *string, ...)
- type AlloydbInstance
- type AlloydbInstanceConfig
- type AlloydbInstanceMachineConfig
- type AlloydbInstanceMachineConfigOutputReference
- type AlloydbInstanceReadPoolConfig
- type AlloydbInstanceReadPoolConfigOutputReference
- type AlloydbInstanceTimeouts
- type AlloydbInstanceTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AlloydbInstance_IsConstruct ¶
func AlloydbInstance_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AlloydbInstance_IsTerraformElement ¶
func AlloydbInstance_IsTerraformElement(x interface{}) *bool
Experimental.
func AlloydbInstance_IsTerraformResource ¶
func AlloydbInstance_IsTerraformResource(x interface{}) *bool
Experimental.
func AlloydbInstance_TfResourceType ¶
func AlloydbInstance_TfResourceType() *string
func NewAlloydbInstanceMachineConfigOutputReference_Override ¶
func NewAlloydbInstanceMachineConfigOutputReference_Override(a AlloydbInstanceMachineConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAlloydbInstanceReadPoolConfigOutputReference_Override ¶
func NewAlloydbInstanceReadPoolConfigOutputReference_Override(a AlloydbInstanceReadPoolConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAlloydbInstanceTimeoutsOutputReference_Override ¶
func NewAlloydbInstanceTimeoutsOutputReference_Override(a AlloydbInstanceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAlloydbInstance_Override ¶
func NewAlloydbInstance_Override(a AlloydbInstance, scope constructs.Construct, id *string, config *AlloydbInstanceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance google_alloydb_instance} Resource.
Types ¶
type AlloydbInstance ¶
type AlloydbInstance interface {
cdktf.TerraformResource
Annotations() *map[string]*string
SetAnnotations(val *map[string]*string)
AnnotationsInput() *map[string]*string
AvailabilityType() *string
SetAvailabilityType(val *string)
AvailabilityTypeInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Cluster() *string
SetCluster(val *string)
ClusterInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
DatabaseFlags() *map[string]*string
SetDatabaseFlags(val *map[string]*string)
DatabaseFlagsInput() *map[string]*string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GceZone() *string
SetGceZone(val *string)
GceZoneInput() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceId() *string
SetInstanceId(val *string)
InstanceIdInput() *string
InstanceType() *string
SetInstanceType(val *string)
InstanceTypeInput() *string
IpAddress() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MachineConfig() AlloydbInstanceMachineConfigOutputReference
MachineConfigInput() *AlloydbInstanceMachineConfig
Name() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReadPoolConfig() AlloydbInstanceReadPoolConfigOutputReference
ReadPoolConfigInput() *AlloydbInstanceReadPoolConfig
Reconciling() cdktf.IResolvable
State() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() AlloydbInstanceTimeoutsOutputReference
TimeoutsInput() interface{}
Uid() *string
UpdateTime() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutMachineConfig(value *AlloydbInstanceMachineConfig)
PutReadPoolConfig(value *AlloydbInstanceReadPoolConfig)
PutTimeouts(value *AlloydbInstanceTimeouts)
ResetAnnotations()
ResetAvailabilityType()
ResetDatabaseFlags()
ResetDisplayName()
ResetGceZone()
ResetId()
ResetLabels()
ResetMachineConfig()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetReadPoolConfig()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance google_alloydb_instance}.
func NewAlloydbInstance ¶
func NewAlloydbInstance(scope constructs.Construct, id *string, config *AlloydbInstanceConfig) AlloydbInstance
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance google_alloydb_instance} Resource.
type AlloydbInstanceConfig ¶
type AlloydbInstanceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Identifies the alloydb cluster. Must be in the format 'projects/{project}/locations/{location}/clusters/{cluster_id}'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#cluster AlloydbInstance#cluster}
Cluster *string `field:"required" json:"cluster" yaml:"cluster"`
// The ID of the alloydb instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#instance_id AlloydbInstance#instance_id}
InstanceId *string `field:"required" json:"instanceId" yaml:"instanceId"`
// The type of the instance.
//
// If the instance type is READ_POOL, provide the associated PRIMARY instance in the 'depends_on' meta-data attribute. Possible values: ["PRIMARY", "READ_POOL"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#instance_type AlloydbInstance#instance_type}
InstanceType *string `field:"required" json:"instanceType" yaml:"instanceType"`
// Annotations to allow client tools to store small amount of arbitrary data. This is distinct from labels.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#annotations AlloydbInstance#annotations}
Annotations *map[string]*string `field:"optional" json:"annotations" yaml:"annotations"`
// Availability type of an Instance.
//
// Defaults to REGIONAL for both primary and read instances. Note that primary and read instances can have different availability types. Possible values: ["AVAILABILITY_TYPE_UNSPECIFIED", "ZONAL", "REGIONAL"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#availability_type AlloydbInstance#availability_type}
AvailabilityType *string `field:"optional" json:"availabilityType" yaml:"availabilityType"`
// Database flags.
//
// Set at instance level. * They are copied from primary instance on read instance creation. * Read instances can set new or override existing flags that are relevant for reads, e.g. for enabling columnar cache on a read instance. Flags set on read instance may or may not be present on primary.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#database_flags AlloydbInstance#database_flags}
DatabaseFlags *map[string]*string `field:"optional" json:"databaseFlags" yaml:"databaseFlags"`
// User-settable and human-readable display name for the Instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#display_name AlloydbInstance#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// The Compute Engine zone that the instance should serve from, per https://cloud.google.com/compute/docs/regions-zones This can ONLY be specified for ZONAL instances. If present for a REGIONAL instance, an error will be thrown. If this is absent for a ZONAL instance, instance is created in a random zone with available capacity.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#gce_zone AlloydbInstance#gce_zone}
GceZone *string `field:"optional" json:"gceZone" yaml:"gceZone"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#id AlloydbInstance#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// User-defined labels for the alloydb instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#labels AlloydbInstance#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// machine_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#machine_config AlloydbInstance#machine_config}
MachineConfig *AlloydbInstanceMachineConfig `field:"optional" json:"machineConfig" yaml:"machineConfig"`
// read_pool_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#read_pool_config AlloydbInstance#read_pool_config}
ReadPoolConfig *AlloydbInstanceReadPoolConfig `field:"optional" json:"readPoolConfig" yaml:"readPoolConfig"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#timeouts AlloydbInstance#timeouts}
Timeouts *AlloydbInstanceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type AlloydbInstanceMachineConfig ¶
type AlloydbInstanceMachineConfig struct {
// The number of CPU's in the VM instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#cpu_count AlloydbInstance#cpu_count}
CpuCount *float64 `field:"optional" json:"cpuCount" yaml:"cpuCount"`
}
type AlloydbInstanceMachineConfigOutputReference ¶
type AlloydbInstanceMachineConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CpuCount() *float64
SetCpuCount(val *float64)
CpuCountInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AlloydbInstanceMachineConfig
SetInternalValue(val *AlloydbInstanceMachineConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCpuCount()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlloydbInstanceMachineConfigOutputReference ¶
func NewAlloydbInstanceMachineConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AlloydbInstanceMachineConfigOutputReference
type AlloydbInstanceReadPoolConfig ¶
type AlloydbInstanceReadPoolConfig struct {
// Read capacity, i.e. number of nodes in a read pool instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#node_count AlloydbInstance#node_count}
NodeCount *float64 `field:"optional" json:"nodeCount" yaml:"nodeCount"`
}
type AlloydbInstanceReadPoolConfigOutputReference ¶
type AlloydbInstanceReadPoolConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AlloydbInstanceReadPoolConfig
SetInternalValue(val *AlloydbInstanceReadPoolConfig)
NodeCount() *float64
SetNodeCount(val *float64)
NodeCountInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetNodeCount()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlloydbInstanceReadPoolConfigOutputReference ¶
func NewAlloydbInstanceReadPoolConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AlloydbInstanceReadPoolConfigOutputReference
type AlloydbInstanceTimeouts ¶
type AlloydbInstanceTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#create AlloydbInstance#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#delete AlloydbInstance#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.67.0/docs/resources/alloydb_instance#update AlloydbInstance#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type AlloydbInstanceTimeoutsOutputReference ¶
type AlloydbInstanceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlloydbInstanceTimeoutsOutputReference ¶
func NewAlloydbInstanceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AlloydbInstanceTimeoutsOutputReference
Source Files
¶
- AlloydbInstance.go
- AlloydbInstanceConfig.go
- AlloydbInstanceMachineConfig.go
- AlloydbInstanceMachineConfigOutputReference.go
- AlloydbInstanceMachineConfigOutputReference__checks.go
- AlloydbInstanceReadPoolConfig.go
- AlloydbInstanceReadPoolConfigOutputReference.go
- AlloydbInstanceReadPoolConfigOutputReference__checks.go
- AlloydbInstanceTimeouts.go
- AlloydbInstanceTimeoutsOutputReference.go
- AlloydbInstanceTimeoutsOutputReference__checks.go
- AlloydbInstance__checks.go
- main.go