Documentation
¶
Index ¶
- func BigqueryConnection_IsConstruct(x interface{}) *bool
- func BigqueryConnection_IsTerraformElement(x interface{}) *bool
- func BigqueryConnection_IsTerraformResource(x interface{}) *bool
- func BigqueryConnection_TfResourceType() *string
- func NewBigqueryConnectionAwsAccessRoleOutputReference_Override(b BigqueryConnectionAwsAccessRoleOutputReference, ...)
- func NewBigqueryConnectionAwsOutputReference_Override(b BigqueryConnectionAwsOutputReference, ...)
- func NewBigqueryConnectionAzureOutputReference_Override(b BigqueryConnectionAzureOutputReference, ...)
- func NewBigqueryConnectionCloudResourceOutputReference_Override(b BigqueryConnectionCloudResourceOutputReference, ...)
- func NewBigqueryConnectionCloudSpannerOutputReference_Override(b BigqueryConnectionCloudSpannerOutputReference, ...)
- func NewBigqueryConnectionCloudSqlCredentialOutputReference_Override(b BigqueryConnectionCloudSqlCredentialOutputReference, ...)
- func NewBigqueryConnectionCloudSqlOutputReference_Override(b BigqueryConnectionCloudSqlOutputReference, ...)
- func NewBigqueryConnectionTimeoutsOutputReference_Override(b BigqueryConnectionTimeoutsOutputReference, ...)
- func NewBigqueryConnection_Override(b BigqueryConnection, scope constructs.Construct, id *string, ...)
- type BigqueryConnection
- type BigqueryConnectionAws
- type BigqueryConnectionAwsAccessRole
- type BigqueryConnectionAwsAccessRoleOutputReference
- type BigqueryConnectionAwsOutputReference
- type BigqueryConnectionAzure
- type BigqueryConnectionAzureOutputReference
- type BigqueryConnectionCloudResource
- type BigqueryConnectionCloudResourceOutputReference
- type BigqueryConnectionCloudSpanner
- type BigqueryConnectionCloudSpannerOutputReference
- type BigqueryConnectionCloudSql
- type BigqueryConnectionCloudSqlCredential
- type BigqueryConnectionCloudSqlCredentialOutputReference
- type BigqueryConnectionCloudSqlOutputReference
- type BigqueryConnectionConfig
- type BigqueryConnectionTimeouts
- type BigqueryConnectionTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BigqueryConnection_IsConstruct ¶
func BigqueryConnection_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func BigqueryConnection_IsTerraformElement ¶
func BigqueryConnection_IsTerraformElement(x interface{}) *bool
Experimental.
func BigqueryConnection_IsTerraformResource ¶
func BigqueryConnection_IsTerraformResource(x interface{}) *bool
Experimental.
func BigqueryConnection_TfResourceType ¶
func BigqueryConnection_TfResourceType() *string
func NewBigqueryConnectionAwsAccessRoleOutputReference_Override ¶
func NewBigqueryConnectionAwsAccessRoleOutputReference_Override(b BigqueryConnectionAwsAccessRoleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBigqueryConnectionAwsOutputReference_Override ¶
func NewBigqueryConnectionAwsOutputReference_Override(b BigqueryConnectionAwsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBigqueryConnectionAzureOutputReference_Override ¶
func NewBigqueryConnectionAzureOutputReference_Override(b BigqueryConnectionAzureOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBigqueryConnectionCloudResourceOutputReference_Override ¶
func NewBigqueryConnectionCloudResourceOutputReference_Override(b BigqueryConnectionCloudResourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBigqueryConnectionCloudSpannerOutputReference_Override ¶
func NewBigqueryConnectionCloudSpannerOutputReference_Override(b BigqueryConnectionCloudSpannerOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBigqueryConnectionCloudSqlCredentialOutputReference_Override ¶
func NewBigqueryConnectionCloudSqlCredentialOutputReference_Override(b BigqueryConnectionCloudSqlCredentialOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBigqueryConnectionCloudSqlOutputReference_Override ¶
func NewBigqueryConnectionCloudSqlOutputReference_Override(b BigqueryConnectionCloudSqlOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBigqueryConnectionTimeoutsOutputReference_Override ¶
func NewBigqueryConnectionTimeoutsOutputReference_Override(b BigqueryConnectionTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBigqueryConnection_Override ¶
func NewBigqueryConnection_Override(b BigqueryConnection, scope constructs.Construct, id *string, config *BigqueryConnectionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection google_bigquery_connection} Resource.
Types ¶
type BigqueryConnection ¶
type BigqueryConnection interface {
cdktf.TerraformResource
Aws() BigqueryConnectionAwsOutputReference
AwsInput() *BigqueryConnectionAws
Azure() BigqueryConnectionAzureOutputReference
AzureInput() *BigqueryConnectionAzure
// Experimental.
CdktfStack() cdktf.TerraformStack
CloudResource() BigqueryConnectionCloudResourceOutputReference
CloudResourceInput() *BigqueryConnectionCloudResource
CloudSpanner() BigqueryConnectionCloudSpannerOutputReference
CloudSpannerInput() *BigqueryConnectionCloudSpanner
CloudSql() BigqueryConnectionCloudSqlOutputReference
CloudSqlInput() *BigqueryConnectionCloudSql
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
ConnectionId() *string
SetConnectionId(val *string)
ConnectionIdInput() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
FriendlyName() *string
SetFriendlyName(val *string)
FriendlyNameInput() *string
// Experimental.
FriendlyUniqueId() *string
HasCredential() cdktf.IResolvable
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() BigqueryConnectionTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAws(value *BigqueryConnectionAws)
PutAzure(value *BigqueryConnectionAzure)
PutCloudResource(value *BigqueryConnectionCloudResource)
PutCloudSpanner(value *BigqueryConnectionCloudSpanner)
PutCloudSql(value *BigqueryConnectionCloudSql)
PutTimeouts(value *BigqueryConnectionTimeouts)
ResetAws()
ResetAzure()
ResetCloudResource()
ResetCloudSpanner()
ResetCloudSql()
ResetConnectionId()
ResetDescription()
ResetFriendlyName()
ResetId()
ResetLocation()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection google_bigquery_connection}.
func NewBigqueryConnection ¶
func NewBigqueryConnection(scope constructs.Construct, id *string, config *BigqueryConnectionConfig) BigqueryConnection
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection google_bigquery_connection} Resource.
type BigqueryConnectionAws ¶
type BigqueryConnectionAws struct {
// access_role block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#access_role BigqueryConnection#access_role}
AccessRole *BigqueryConnectionAwsAccessRole `field:"required" json:"accessRole" yaml:"accessRole"`
}
type BigqueryConnectionAwsAccessRole ¶
type BigqueryConnectionAwsAccessRole struct {
// The user’s AWS IAM Role that trusts the Google-owned AWS IAM user Connection.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#iam_role_id BigqueryConnection#iam_role_id}
IamRoleId *string `field:"required" json:"iamRoleId" yaml:"iamRoleId"`
}
type BigqueryConnectionAwsAccessRoleOutputReference ¶
type BigqueryConnectionAwsAccessRoleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IamRoleId() *string
SetIamRoleId(val *string)
IamRoleIdInput() *string
Identity() *string
InternalValue() *BigqueryConnectionAwsAccessRole
SetInternalValue(val *BigqueryConnectionAwsAccessRole)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBigqueryConnectionAwsAccessRoleOutputReference ¶
func NewBigqueryConnectionAwsAccessRoleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BigqueryConnectionAwsAccessRoleOutputReference
type BigqueryConnectionAwsOutputReference ¶
type BigqueryConnectionAwsOutputReference interface {
cdktf.ComplexObject
AccessRole() BigqueryConnectionAwsAccessRoleOutputReference
AccessRoleInput() *BigqueryConnectionAwsAccessRole
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *BigqueryConnectionAws
SetInternalValue(val *BigqueryConnectionAws)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAccessRole(value *BigqueryConnectionAwsAccessRole)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBigqueryConnectionAwsOutputReference ¶
func NewBigqueryConnectionAwsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BigqueryConnectionAwsOutputReference
type BigqueryConnectionAzure ¶
type BigqueryConnectionAzure struct {
// The id of customer's directory that host the data.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#customer_tenant_id BigqueryConnection#customer_tenant_id}
CustomerTenantId *string `field:"required" json:"customerTenantId" yaml:"customerTenantId"`
// The Azure Application (client) ID where the federated credentials will be hosted.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#federated_application_client_id BigqueryConnection#federated_application_client_id}
FederatedApplicationClientId *string `field:"optional" json:"federatedApplicationClientId" yaml:"federatedApplicationClientId"`
}
type BigqueryConnectionAzureOutputReference ¶
type BigqueryConnectionAzureOutputReference interface {
cdktf.ComplexObject
Application() *string
ClientId() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CustomerTenantId() *string
SetCustomerTenantId(val *string)
CustomerTenantIdInput() *string
FederatedApplicationClientId() *string
SetFederatedApplicationClientId(val *string)
FederatedApplicationClientIdInput() *string
// Experimental.
Fqn() *string
Identity() *string
InternalValue() *BigqueryConnectionAzure
SetInternalValue(val *BigqueryConnectionAzure)
ObjectId() *string
RedirectUri() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetFederatedApplicationClientId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBigqueryConnectionAzureOutputReference ¶
func NewBigqueryConnectionAzureOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BigqueryConnectionAzureOutputReference
type BigqueryConnectionCloudResource ¶
type BigqueryConnectionCloudResource struct {
}
type BigqueryConnectionCloudResourceOutputReference ¶
type BigqueryConnectionCloudResourceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *BigqueryConnectionCloudResource
SetInternalValue(val *BigqueryConnectionCloudResource)
ServiceAccountId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBigqueryConnectionCloudResourceOutputReference ¶
func NewBigqueryConnectionCloudResourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BigqueryConnectionCloudResourceOutputReference
type BigqueryConnectionCloudSpanner ¶
type BigqueryConnectionCloudSpanner struct {
// Cloud Spanner database in the form 'project/instance/database'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#database BigqueryConnection#database}
Database *string `field:"required" json:"database" yaml:"database"`
// If parallelism should be used when reading from Cloud Spanner.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#use_parallelism BigqueryConnection#use_parallelism}
UseParallelism interface{} `field:"optional" json:"useParallelism" yaml:"useParallelism"`
// If the serverless analytics service should be used to read data from Cloud Spanner.
//
// useParallelism must be set when using serverless analytics
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#use_serverless_analytics BigqueryConnection#use_serverless_analytics}
UseServerlessAnalytics interface{} `field:"optional" json:"useServerlessAnalytics" yaml:"useServerlessAnalytics"`
}
type BigqueryConnectionCloudSpannerOutputReference ¶
type BigqueryConnectionCloudSpannerOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Database() *string
SetDatabase(val *string)
DatabaseInput() *string
// Experimental.
Fqn() *string
InternalValue() *BigqueryConnectionCloudSpanner
SetInternalValue(val *BigqueryConnectionCloudSpanner)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UseParallelism() interface{}
SetUseParallelism(val interface{})
UseParallelismInput() interface{}
UseServerlessAnalytics() interface{}
SetUseServerlessAnalytics(val interface{})
UseServerlessAnalyticsInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetUseParallelism()
ResetUseServerlessAnalytics()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBigqueryConnectionCloudSpannerOutputReference ¶
func NewBigqueryConnectionCloudSpannerOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BigqueryConnectionCloudSpannerOutputReference
type BigqueryConnectionCloudSql ¶
type BigqueryConnectionCloudSql struct {
// credential block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#credential BigqueryConnection#credential}
Credential *BigqueryConnectionCloudSqlCredential `field:"required" json:"credential" yaml:"credential"`
// Database name.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#database BigqueryConnection#database}
Database *string `field:"required" json:"database" yaml:"database"`
// Cloud SQL instance ID in the form project:location:instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#instance_id BigqueryConnection#instance_id}
InstanceId *string `field:"required" json:"instanceId" yaml:"instanceId"`
// Type of the Cloud SQL database. Possible values: ["DATABASE_TYPE_UNSPECIFIED", "POSTGRES", "MYSQL"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#type BigqueryConnection#type}
Type *string `field:"required" json:"type" yaml:"type"`
}
type BigqueryConnectionCloudSqlCredential ¶
type BigqueryConnectionCloudSqlCredential struct {
// Password for database.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#password BigqueryConnection#password}
Password *string `field:"required" json:"password" yaml:"password"`
// Username for database.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#username BigqueryConnection#username}
Username *string `field:"required" json:"username" yaml:"username"`
}
type BigqueryConnectionCloudSqlCredentialOutputReference ¶
type BigqueryConnectionCloudSqlCredentialOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *BigqueryConnectionCloudSqlCredential
SetInternalValue(val *BigqueryConnectionCloudSqlCredential)
Password() *string
SetPassword(val *string)
PasswordInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Username() *string
SetUsername(val *string)
UsernameInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBigqueryConnectionCloudSqlCredentialOutputReference ¶
func NewBigqueryConnectionCloudSqlCredentialOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BigqueryConnectionCloudSqlCredentialOutputReference
type BigqueryConnectionCloudSqlOutputReference ¶
type BigqueryConnectionCloudSqlOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Credential() BigqueryConnectionCloudSqlCredentialOutputReference
CredentialInput() *BigqueryConnectionCloudSqlCredential
Database() *string
SetDatabase(val *string)
DatabaseInput() *string
// Experimental.
Fqn() *string
InstanceId() *string
SetInstanceId(val *string)
InstanceIdInput() *string
InternalValue() *BigqueryConnectionCloudSql
SetInternalValue(val *BigqueryConnectionCloudSql)
ServiceAccountId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCredential(value *BigqueryConnectionCloudSqlCredential)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBigqueryConnectionCloudSqlOutputReference ¶
func NewBigqueryConnectionCloudSqlOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BigqueryConnectionCloudSqlOutputReference
type BigqueryConnectionConfig ¶
type BigqueryConnectionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// aws block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#aws BigqueryConnection#aws}
Aws *BigqueryConnectionAws `field:"optional" json:"aws" yaml:"aws"`
// azure block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#azure BigqueryConnection#azure}
Azure *BigqueryConnectionAzure `field:"optional" json:"azure" yaml:"azure"`
// cloud_resource block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#cloud_resource BigqueryConnection#cloud_resource}
CloudResource *BigqueryConnectionCloudResource `field:"optional" json:"cloudResource" yaml:"cloudResource"`
// cloud_spanner block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#cloud_spanner BigqueryConnection#cloud_spanner}
CloudSpanner *BigqueryConnectionCloudSpanner `field:"optional" json:"cloudSpanner" yaml:"cloudSpanner"`
// cloud_sql block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#cloud_sql BigqueryConnection#cloud_sql}
CloudSql *BigqueryConnectionCloudSql `field:"optional" json:"cloudSql" yaml:"cloudSql"`
// Optional connection id that should be assigned to the created connection.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#connection_id BigqueryConnection#connection_id}
ConnectionId *string `field:"optional" json:"connectionId" yaml:"connectionId"`
// A descriptive description for the connection.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#description BigqueryConnection#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// A descriptive name for the connection.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#friendly_name BigqueryConnection#friendly_name}
FriendlyName *string `field:"optional" json:"friendlyName" yaml:"friendlyName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#id BigqueryConnection#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The geographic location where the connection should reside.
//
// Cloud SQL instance must be in the same location as the connection
// with following exceptions: Cloud SQL us-central1 maps to BigQuery US, Cloud SQL europe-west1 maps to BigQuery EU.
// Examples: US, EU, asia-northeast1, us-central1, europe-west1.
// Spanner Connections same as spanner region
// AWS allowed regions are aws-us-east-1
// Azure allowed regions are azure-eastus2
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#location BigqueryConnection#location}
Location *string `field:"optional" json:"location" yaml:"location"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#project BigqueryConnection#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#timeouts BigqueryConnection#timeouts}
Timeouts *BigqueryConnectionTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type BigqueryConnectionTimeouts ¶
type BigqueryConnectionTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#create BigqueryConnection#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#delete BigqueryConnection#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.79.0/docs/resources/bigquery_connection#update BigqueryConnection#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type BigqueryConnectionTimeoutsOutputReference ¶
type BigqueryConnectionTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBigqueryConnectionTimeoutsOutputReference ¶
func NewBigqueryConnectionTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BigqueryConnectionTimeoutsOutputReference
Source Files
¶
- BigqueryConnection.go
- BigqueryConnectionAws.go
- BigqueryConnectionAwsAccessRole.go
- BigqueryConnectionAwsAccessRoleOutputReference.go
- BigqueryConnectionAwsAccessRoleOutputReference__checks.go
- BigqueryConnectionAwsOutputReference.go
- BigqueryConnectionAwsOutputReference__checks.go
- BigqueryConnectionAzure.go
- BigqueryConnectionAzureOutputReference.go
- BigqueryConnectionAzureOutputReference__checks.go
- BigqueryConnectionCloudResource.go
- BigqueryConnectionCloudResourceOutputReference.go
- BigqueryConnectionCloudResourceOutputReference__checks.go
- BigqueryConnectionCloudSpanner.go
- BigqueryConnectionCloudSpannerOutputReference.go
- BigqueryConnectionCloudSpannerOutputReference__checks.go
- BigqueryConnectionCloudSql.go
- BigqueryConnectionCloudSqlCredential.go
- BigqueryConnectionCloudSqlCredentialOutputReference.go
- BigqueryConnectionCloudSqlCredentialOutputReference__checks.go
- BigqueryConnectionCloudSqlOutputReference.go
- BigqueryConnectionCloudSqlOutputReference__checks.go
- BigqueryConnectionConfig.go
- BigqueryConnectionTimeouts.go
- BigqueryConnectionTimeoutsOutputReference.go
- BigqueryConnectionTimeoutsOutputReference__checks.go
- BigqueryConnection__checks.go
- main.go