Documentation
¶
Index ¶
- func ComputeTargetPool_IsConstruct(x interface{}) *bool
- func ComputeTargetPool_IsTerraformElement(x interface{}) *bool
- func ComputeTargetPool_IsTerraformResource(x interface{}) *bool
- func ComputeTargetPool_TfResourceType() *string
- func NewComputeTargetPoolTimeoutsOutputReference_Override(c ComputeTargetPoolTimeoutsOutputReference, ...)
- func NewComputeTargetPool_Override(c ComputeTargetPool, scope constructs.Construct, id *string, ...)
- type ComputeTargetPool
- type ComputeTargetPoolConfig
- type ComputeTargetPoolTimeouts
- type ComputeTargetPoolTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComputeTargetPool_IsConstruct ¶
func ComputeTargetPool_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ComputeTargetPool_IsTerraformElement ¶
func ComputeTargetPool_IsTerraformElement(x interface{}) *bool
Experimental.
func ComputeTargetPool_IsTerraformResource ¶
func ComputeTargetPool_IsTerraformResource(x interface{}) *bool
Experimental.
func ComputeTargetPool_TfResourceType ¶
func ComputeTargetPool_TfResourceType() *string
func NewComputeTargetPoolTimeoutsOutputReference_Override ¶
func NewComputeTargetPoolTimeoutsOutputReference_Override(c ComputeTargetPoolTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputeTargetPool_Override ¶
func NewComputeTargetPool_Override(c ComputeTargetPool, scope constructs.Construct, id *string, config *ComputeTargetPoolConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool google_compute_target_pool} Resource.
Types ¶
type ComputeTargetPool ¶
type ComputeTargetPool interface {
cdktf.TerraformResource
BackupPool() *string
SetBackupPool(val *string)
BackupPoolInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
FailoverRatio() *float64
SetFailoverRatio(val *float64)
FailoverRatioInput() *float64
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HealthChecks() *[]*string
SetHealthChecks(val *[]*string)
HealthChecksInput() *[]*string
Id() *string
SetId(val *string)
IdInput() *string
Instances() *[]*string
SetInstances(val *[]*string)
InstancesInput() *[]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
SelfLink() *string
SessionAffinity() *string
SetSessionAffinity(val *string)
SessionAffinityInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() ComputeTargetPoolTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *ComputeTargetPoolTimeouts)
ResetBackupPool()
ResetDescription()
ResetFailoverRatio()
ResetHealthChecks()
ResetId()
ResetInstances()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
ResetSessionAffinity()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool google_compute_target_pool}.
func NewComputeTargetPool ¶
func NewComputeTargetPool(scope constructs.Construct, id *string, config *ComputeTargetPoolConfig) ComputeTargetPool
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool google_compute_target_pool} Resource.
type ComputeTargetPoolConfig ¶
type ComputeTargetPoolConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// A unique name for the resource, required by GCE. Changing this forces a new resource to be created.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool#name ComputeTargetPool#name}
Name *string `field:"required" json:"name" yaml:"name"`
// URL to the backup target pool. Must also set failover_ratio.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool#backup_pool ComputeTargetPool#backup_pool}
BackupPool *string `field:"optional" json:"backupPool" yaml:"backupPool"`
// Textual description field.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool#description ComputeTargetPool#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Ratio (0 to 1) of failed nodes before using the backup pool (which must also be set).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool#failover_ratio ComputeTargetPool#failover_ratio}
FailoverRatio *float64 `field:"optional" json:"failoverRatio" yaml:"failoverRatio"`
// List of zero or one health check name or self_link. Only legacy google_compute_http_health_check is supported.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool#health_checks ComputeTargetPool#health_checks}
HealthChecks *[]*string `field:"optional" json:"healthChecks" yaml:"healthChecks"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool#id ComputeTargetPool#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// List of instances in the pool.
//
// They can be given as URLs, or in the form of "zone/name". Note that the instances need not exist at the time of target pool creation, so there is no need to use the Terraform interpolators to create a dependency on the instances from the target pool.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool#instances ComputeTargetPool#instances}
Instances *[]*string `field:"optional" json:"instances" yaml:"instances"`
// The ID of the project in which the resource belongs.
//
// If it is not provided, the provider project is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool#project ComputeTargetPool#project}
Project *string `field:"optional" json:"project" yaml:"project"`
// Where the target pool resides. Defaults to project region.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool#region ComputeTargetPool#region}
Region *string `field:"optional" json:"region" yaml:"region"`
// How to distribute load.
//
// Options are "NONE" (no affinity). "CLIENT_IP" (hash of the source/dest addresses / ports), and "CLIENT_IP_PROTO" also includes the protocol (default "NONE").
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool#session_affinity ComputeTargetPool#session_affinity}
SessionAffinity *string `field:"optional" json:"sessionAffinity" yaml:"sessionAffinity"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool#timeouts ComputeTargetPool#timeouts}
Timeouts *ComputeTargetPoolTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type ComputeTargetPoolTimeouts ¶
type ComputeTargetPoolTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool#create ComputeTargetPool#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool#delete ComputeTargetPool#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.77.0/docs/resources/compute_target_pool#update ComputeTargetPool#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type ComputeTargetPoolTimeoutsOutputReference ¶
type ComputeTargetPoolTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeTargetPoolTimeoutsOutputReference ¶
func NewComputeTargetPoolTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputeTargetPoolTimeoutsOutputReference