Documentation
¶
Index ¶
- func FolderAccessApprovalSettings_IsConstruct(x interface{}) *bool
- func FolderAccessApprovalSettings_IsTerraformElement(x interface{}) *bool
- func FolderAccessApprovalSettings_IsTerraformResource(x interface{}) *bool
- func FolderAccessApprovalSettings_TfResourceType() *string
- func NewFolderAccessApprovalSettingsEnrolledServicesList_Override(f FolderAccessApprovalSettingsEnrolledServicesList, ...)
- func NewFolderAccessApprovalSettingsEnrolledServicesOutputReference_Override(f FolderAccessApprovalSettingsEnrolledServicesOutputReference, ...)
- func NewFolderAccessApprovalSettingsTimeoutsOutputReference_Override(f FolderAccessApprovalSettingsTimeoutsOutputReference, ...)
- func NewFolderAccessApprovalSettings_Override(f FolderAccessApprovalSettings, scope constructs.Construct, id *string, ...)
- type FolderAccessApprovalSettings
- type FolderAccessApprovalSettingsConfig
- type FolderAccessApprovalSettingsEnrolledServices
- type FolderAccessApprovalSettingsEnrolledServicesList
- type FolderAccessApprovalSettingsEnrolledServicesOutputReference
- type FolderAccessApprovalSettingsTimeouts
- type FolderAccessApprovalSettingsTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FolderAccessApprovalSettings_IsConstruct ¶
func FolderAccessApprovalSettings_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func FolderAccessApprovalSettings_IsTerraformElement ¶
func FolderAccessApprovalSettings_IsTerraformElement(x interface{}) *bool
Experimental.
func FolderAccessApprovalSettings_IsTerraformResource ¶
func FolderAccessApprovalSettings_IsTerraformResource(x interface{}) *bool
Experimental.
func FolderAccessApprovalSettings_TfResourceType ¶
func FolderAccessApprovalSettings_TfResourceType() *string
func NewFolderAccessApprovalSettingsEnrolledServicesList_Override ¶
func NewFolderAccessApprovalSettingsEnrolledServicesList_Override(f FolderAccessApprovalSettingsEnrolledServicesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewFolderAccessApprovalSettingsEnrolledServicesOutputReference_Override ¶
func NewFolderAccessApprovalSettingsEnrolledServicesOutputReference_Override(f FolderAccessApprovalSettingsEnrolledServicesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewFolderAccessApprovalSettingsTimeoutsOutputReference_Override ¶
func NewFolderAccessApprovalSettingsTimeoutsOutputReference_Override(f FolderAccessApprovalSettingsTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFolderAccessApprovalSettings_Override ¶
func NewFolderAccessApprovalSettings_Override(f FolderAccessApprovalSettings, scope constructs.Construct, id *string, config *FolderAccessApprovalSettingsConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.76.0/docs/resources/folder_access_approval_settings google_folder_access_approval_settings} Resource.
Types ¶
type FolderAccessApprovalSettings ¶
type FolderAccessApprovalSettings interface {
cdktf.TerraformResource
ActiveKeyVersion() *string
SetActiveKeyVersion(val *string)
ActiveKeyVersionInput() *string
AncestorHasActiveKeyVersion() cdktf.IResolvable
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EnrolledAncestor() cdktf.IResolvable
EnrolledServices() FolderAccessApprovalSettingsEnrolledServicesList
EnrolledServicesInput() interface{}
FolderId() *string
SetFolderId(val *string)
FolderIdInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InvalidKeyVersion() cdktf.IResolvable
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
NotificationEmails() *[]*string
SetNotificationEmails(val *[]*string)
NotificationEmailsInput() *[]*string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() FolderAccessApprovalSettingsTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEnrolledServices(value interface{})
PutTimeouts(value *FolderAccessApprovalSettingsTimeouts)
ResetActiveKeyVersion()
ResetId()
ResetNotificationEmails()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/4.76.0/docs/resources/folder_access_approval_settings google_folder_access_approval_settings}.
func NewFolderAccessApprovalSettings ¶
func NewFolderAccessApprovalSettings(scope constructs.Construct, id *string, config *FolderAccessApprovalSettingsConfig) FolderAccessApprovalSettings
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.76.0/docs/resources/folder_access_approval_settings google_folder_access_approval_settings} Resource.
type FolderAccessApprovalSettingsConfig ¶
type FolderAccessApprovalSettingsConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// enrolled_services block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.76.0/docs/resources/folder_access_approval_settings#enrolled_services FolderAccessApprovalSettings#enrolled_services}
EnrolledServices interface{} `field:"required" json:"enrolledServices" yaml:"enrolledServices"`
// ID of the folder of the access approval settings.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.76.0/docs/resources/folder_access_approval_settings#folder_id FolderAccessApprovalSettings#folder_id}
FolderId *string `field:"required" json:"folderId" yaml:"folderId"`
// The asymmetric crypto key version to use for signing approval requests.
//
// Empty active_key_version indicates that a Google-managed key should be used for signing.
// This property will be ignored if set by an ancestor of the resource, and new non-empty values may not be set.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.76.0/docs/resources/folder_access_approval_settings#active_key_version FolderAccessApprovalSettings#active_key_version}
ActiveKeyVersion *string `field:"optional" json:"activeKeyVersion" yaml:"activeKeyVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.76.0/docs/resources/folder_access_approval_settings#id FolderAccessApprovalSettings#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// A list of email addresses to which notifications relating to approval requests should be sent.
//
// Notifications relating to a resource will be sent to all emails in the settings of ancestor
// resources of that resource. A maximum of 50 email addresses are allowed.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.76.0/docs/resources/folder_access_approval_settings#notification_emails FolderAccessApprovalSettings#notification_emails}
NotificationEmails *[]*string `field:"optional" json:"notificationEmails" yaml:"notificationEmails"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.76.0/docs/resources/folder_access_approval_settings#timeouts FolderAccessApprovalSettings#timeouts}
Timeouts *FolderAccessApprovalSettingsTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type FolderAccessApprovalSettingsEnrolledServices ¶
type FolderAccessApprovalSettingsEnrolledServices struct {
// The product for which Access Approval will be enrolled.
//
// Allowed values are listed (case-sensitive):
// all
// App Engine
// BigQuery
// Cloud Bigtable
// Cloud Key Management Service
// Compute Engine
// Cloud Dataflow
// Cloud Identity and Access Management
// Cloud Pub/Sub
// Cloud Storage
// Persistent Disk
//
// Note: These values are supported as input, but considered a legacy format:
// all
// appengine.googleapis.com
// bigquery.googleapis.com
// bigtable.googleapis.com
// cloudkms.googleapis.com
// compute.googleapis.com
// dataflow.googleapis.com
// iam.googleapis.com
// pubsub.googleapis.com
// storage.googleapis.com
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.76.0/docs/resources/folder_access_approval_settings#cloud_product FolderAccessApprovalSettings#cloud_product}
CloudProduct *string `field:"required" json:"cloudProduct" yaml:"cloudProduct"`
// The enrollment level of the service. Default value: "BLOCK_ALL" Possible values: ["BLOCK_ALL"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.76.0/docs/resources/folder_access_approval_settings#enrollment_level FolderAccessApprovalSettings#enrollment_level}
EnrollmentLevel *string `field:"optional" json:"enrollmentLevel" yaml:"enrollmentLevel"`
}
type FolderAccessApprovalSettingsEnrolledServicesList ¶
type FolderAccessApprovalSettingsEnrolledServicesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) FolderAccessApprovalSettingsEnrolledServicesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFolderAccessApprovalSettingsEnrolledServicesList ¶
func NewFolderAccessApprovalSettingsEnrolledServicesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) FolderAccessApprovalSettingsEnrolledServicesList
type FolderAccessApprovalSettingsEnrolledServicesOutputReference ¶
type FolderAccessApprovalSettingsEnrolledServicesOutputReference interface {
cdktf.ComplexObject
CloudProduct() *string
SetCloudProduct(val *string)
CloudProductInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnrollmentLevel() *string
SetEnrollmentLevel(val *string)
EnrollmentLevelInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnrollmentLevel()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFolderAccessApprovalSettingsEnrolledServicesOutputReference ¶
func NewFolderAccessApprovalSettingsEnrolledServicesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) FolderAccessApprovalSettingsEnrolledServicesOutputReference
type FolderAccessApprovalSettingsTimeouts ¶
type FolderAccessApprovalSettingsTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.76.0/docs/resources/folder_access_approval_settings#create FolderAccessApprovalSettings#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.76.0/docs/resources/folder_access_approval_settings#delete FolderAccessApprovalSettings#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.76.0/docs/resources/folder_access_approval_settings#update FolderAccessApprovalSettings#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type FolderAccessApprovalSettingsTimeoutsOutputReference ¶
type FolderAccessApprovalSettingsTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFolderAccessApprovalSettingsTimeoutsOutputReference ¶
func NewFolderAccessApprovalSettingsTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FolderAccessApprovalSettingsTimeoutsOutputReference
Source Files
¶
- FolderAccessApprovalSettings.go
- FolderAccessApprovalSettingsConfig.go
- FolderAccessApprovalSettingsEnrolledServices.go
- FolderAccessApprovalSettingsEnrolledServicesList.go
- FolderAccessApprovalSettingsEnrolledServicesList__checks.go
- FolderAccessApprovalSettingsEnrolledServicesOutputReference.go
- FolderAccessApprovalSettingsEnrolledServicesOutputReference__checks.go
- FolderAccessApprovalSettingsTimeouts.go
- FolderAccessApprovalSettingsTimeoutsOutputReference.go
- FolderAccessApprovalSettingsTimeoutsOutputReference__checks.go
- FolderAccessApprovalSettings__checks.go
- main.go