Documentation
¶
Index ¶
- func LoggingProjectExclusion_IsConstruct(x interface{}) *bool
- func LoggingProjectExclusion_IsTerraformElement(x interface{}) *bool
- func LoggingProjectExclusion_IsTerraformResource(x interface{}) *bool
- func LoggingProjectExclusion_TfResourceType() *string
- func NewLoggingProjectExclusion_Override(l LoggingProjectExclusion, scope constructs.Construct, id *string, ...)
- type LoggingProjectExclusion
- type LoggingProjectExclusionConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LoggingProjectExclusion_IsConstruct ¶
func LoggingProjectExclusion_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LoggingProjectExclusion_IsTerraformElement ¶
func LoggingProjectExclusion_IsTerraformElement(x interface{}) *bool
Experimental.
func LoggingProjectExclusion_IsTerraformResource ¶
func LoggingProjectExclusion_IsTerraformResource(x interface{}) *bool
Experimental.
func LoggingProjectExclusion_TfResourceType ¶
func LoggingProjectExclusion_TfResourceType() *string
func NewLoggingProjectExclusion_Override ¶
func NewLoggingProjectExclusion_Override(l LoggingProjectExclusion, scope constructs.Construct, id *string, config *LoggingProjectExclusionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/logging_project_exclusion google_logging_project_exclusion} Resource.
Types ¶
type LoggingProjectExclusion ¶
type LoggingProjectExclusion interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Disabled() interface{}
SetDisabled(val interface{})
DisabledInput() interface{}
Filter() *string
SetFilter(val *string)
FilterInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetDescription()
ResetDisabled()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/logging_project_exclusion google_logging_project_exclusion}.
func NewLoggingProjectExclusion ¶
func NewLoggingProjectExclusion(scope constructs.Construct, id *string, config *LoggingProjectExclusionConfig) LoggingProjectExclusion
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/logging_project_exclusion google_logging_project_exclusion} Resource.
type LoggingProjectExclusionConfig ¶
type LoggingProjectExclusionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The filter to apply when excluding logs. Only log entries that match the filter are excluded.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/logging_project_exclusion#filter LoggingProjectExclusion#filter}
Filter *string `field:"required" json:"filter" yaml:"filter"`
// The name of the logging exclusion.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/logging_project_exclusion#name LoggingProjectExclusion#name}
Name *string `field:"required" json:"name" yaml:"name"`
// A human-readable description.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/logging_project_exclusion#description LoggingProjectExclusion#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Whether this exclusion rule should be disabled or not. This defaults to false.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/logging_project_exclusion#disabled LoggingProjectExclusion#disabled}
Disabled interface{} `field:"optional" json:"disabled" yaml:"disabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/logging_project_exclusion#id LoggingProjectExclusion#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/logging_project_exclusion#project LoggingProjectExclusion#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
}