Documentation
¶
Index ¶
- func NewVertexAiIndexDeployedIndexesList_Override(v VertexAiIndexDeployedIndexesList, ...)
- func NewVertexAiIndexDeployedIndexesOutputReference_Override(v VertexAiIndexDeployedIndexesOutputReference, ...)
- func NewVertexAiIndexIndexStatsList_Override(v VertexAiIndexIndexStatsList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewVertexAiIndexIndexStatsOutputReference_Override(v VertexAiIndexIndexStatsOutputReference, ...)
- func NewVertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfigOutputReference_Override(v VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfigOutputReference, ...)
- func NewVertexAiIndexMetadataConfigAlgorithmConfigOutputReference_Override(v VertexAiIndexMetadataConfigAlgorithmConfigOutputReference, ...)
- func NewVertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfigOutputReference_Override(v VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfigOutputReference, ...)
- func NewVertexAiIndexMetadataConfigOutputReference_Override(v VertexAiIndexMetadataConfigOutputReference, ...)
- func NewVertexAiIndexMetadataOutputReference_Override(v VertexAiIndexMetadataOutputReference, ...)
- func NewVertexAiIndexTimeoutsOutputReference_Override(v VertexAiIndexTimeoutsOutputReference, ...)
- func NewVertexAiIndex_Override(v VertexAiIndex, scope constructs.Construct, id *string, ...)
- func VertexAiIndex_IsConstruct(x interface{}) *bool
- func VertexAiIndex_IsTerraformElement(x interface{}) *bool
- func VertexAiIndex_IsTerraformResource(x interface{}) *bool
- func VertexAiIndex_TfResourceType() *string
- type VertexAiIndex
- type VertexAiIndexConfig
- type VertexAiIndexDeployedIndexes
- type VertexAiIndexDeployedIndexesList
- type VertexAiIndexDeployedIndexesOutputReference
- type VertexAiIndexIndexStats
- type VertexAiIndexIndexStatsList
- type VertexAiIndexIndexStatsOutputReference
- type VertexAiIndexMetadata
- type VertexAiIndexMetadataConfig
- type VertexAiIndexMetadataConfigAlgorithmConfig
- type VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfig
- type VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfigOutputReference
- type VertexAiIndexMetadataConfigAlgorithmConfigOutputReference
- type VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfig
- type VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfigOutputReference
- type VertexAiIndexMetadataConfigOutputReference
- type VertexAiIndexMetadataOutputReference
- type VertexAiIndexTimeouts
- type VertexAiIndexTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewVertexAiIndexDeployedIndexesList_Override ¶
func NewVertexAiIndexDeployedIndexesList_Override(v VertexAiIndexDeployedIndexesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewVertexAiIndexDeployedIndexesOutputReference_Override ¶
func NewVertexAiIndexDeployedIndexesOutputReference_Override(v VertexAiIndexDeployedIndexesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewVertexAiIndexIndexStatsList_Override ¶
func NewVertexAiIndexIndexStatsList_Override(v VertexAiIndexIndexStatsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewVertexAiIndexIndexStatsOutputReference_Override ¶
func NewVertexAiIndexIndexStatsOutputReference_Override(v VertexAiIndexIndexStatsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewVertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfigOutputReference_Override ¶
func NewVertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfigOutputReference_Override(v VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVertexAiIndexMetadataConfigAlgorithmConfigOutputReference_Override ¶
func NewVertexAiIndexMetadataConfigAlgorithmConfigOutputReference_Override(v VertexAiIndexMetadataConfigAlgorithmConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfigOutputReference_Override ¶
func NewVertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfigOutputReference_Override(v VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVertexAiIndexMetadataConfigOutputReference_Override ¶
func NewVertexAiIndexMetadataConfigOutputReference_Override(v VertexAiIndexMetadataConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVertexAiIndexMetadataOutputReference_Override ¶
func NewVertexAiIndexMetadataOutputReference_Override(v VertexAiIndexMetadataOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVertexAiIndexTimeoutsOutputReference_Override ¶
func NewVertexAiIndexTimeoutsOutputReference_Override(v VertexAiIndexTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVertexAiIndex_Override ¶
func NewVertexAiIndex_Override(v VertexAiIndex, scope constructs.Construct, id *string, config *VertexAiIndexConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index google_vertex_ai_index} Resource.
func VertexAiIndex_IsConstruct ¶
func VertexAiIndex_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func VertexAiIndex_IsTerraformElement ¶
func VertexAiIndex_IsTerraformElement(x interface{}) *bool
Experimental.
func VertexAiIndex_IsTerraformResource ¶
func VertexAiIndex_IsTerraformResource(x interface{}) *bool
Experimental.
func VertexAiIndex_TfResourceType ¶
func VertexAiIndex_TfResourceType() *string
Types ¶
type VertexAiIndex ¶
type VertexAiIndex interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeployedIndexes() VertexAiIndexDeployedIndexesList
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
Etag() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IndexStats() VertexAiIndexIndexStatsList
IndexUpdateMethod() *string
SetIndexUpdateMethod(val *string)
IndexUpdateMethodInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Metadata() VertexAiIndexMetadataOutputReference
MetadataInput() *VertexAiIndexMetadata
MetadataSchemaUri() *string
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() VertexAiIndexTimeoutsOutputReference
TimeoutsInput() interface{}
UpdateTime() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutMetadata(value *VertexAiIndexMetadata)
PutTimeouts(value *VertexAiIndexTimeouts)
ResetDescription()
ResetId()
ResetIndexUpdateMethod()
ResetLabels()
ResetMetadata()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index google_vertex_ai_index}.
func NewVertexAiIndex ¶
func NewVertexAiIndex(scope constructs.Construct, id *string, config *VertexAiIndexConfig) VertexAiIndex
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index google_vertex_ai_index} Resource.
type VertexAiIndexConfig ¶
type VertexAiIndexConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The display name of the Index.
//
// The name can be up to 128 characters long and can consist of any UTF-8 characters.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#display_name VertexAiIndex#display_name}
DisplayName *string `field:"required" json:"displayName" yaml:"displayName"`
// The description of the Index.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#description VertexAiIndex#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#id VertexAiIndex#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The update method to use with this Index.
//
// The value must be the followings. If not set, BATCH_UPDATE will be used by default.
// BATCH_UPDATE: user can call indexes.patch with files on Cloud Storage of datapoints to update.
// STREAM_UPDATE: user can call indexes.upsertDatapoints/DeleteDatapoints to update the Index and the updates will be applied in corresponding DeployedIndexes in nearly real-time.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#index_update_method VertexAiIndex#index_update_method}
IndexUpdateMethod *string `field:"optional" json:"indexUpdateMethod" yaml:"indexUpdateMethod"`
// The labels with user-defined metadata to organize your Indexes.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#labels VertexAiIndex#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// metadata block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#metadata VertexAiIndex#metadata}
Metadata *VertexAiIndexMetadata `field:"optional" json:"metadata" yaml:"metadata"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#project VertexAiIndex#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// The region of the index. eg us-central1.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#region VertexAiIndex#region}
Region *string `field:"optional" json:"region" yaml:"region"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#timeouts VertexAiIndex#timeouts}
Timeouts *VertexAiIndexTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type VertexAiIndexDeployedIndexes ¶
type VertexAiIndexDeployedIndexes struct {
}
type VertexAiIndexDeployedIndexesList ¶
type VertexAiIndexDeployedIndexesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) VertexAiIndexDeployedIndexesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVertexAiIndexDeployedIndexesList ¶
func NewVertexAiIndexDeployedIndexesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) VertexAiIndexDeployedIndexesList
type VertexAiIndexDeployedIndexesOutputReference ¶
type VertexAiIndexDeployedIndexesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeployedIndexId() *string
// Experimental.
Fqn() *string
IndexEndpoint() *string
InternalValue() *VertexAiIndexDeployedIndexes
SetInternalValue(val *VertexAiIndexDeployedIndexes)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVertexAiIndexDeployedIndexesOutputReference ¶
func NewVertexAiIndexDeployedIndexesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) VertexAiIndexDeployedIndexesOutputReference
type VertexAiIndexIndexStats ¶
type VertexAiIndexIndexStats struct {
}
type VertexAiIndexIndexStatsList ¶
type VertexAiIndexIndexStatsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) VertexAiIndexIndexStatsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVertexAiIndexIndexStatsList ¶
func NewVertexAiIndexIndexStatsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) VertexAiIndexIndexStatsList
type VertexAiIndexIndexStatsOutputReference ¶
type VertexAiIndexIndexStatsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VertexAiIndexIndexStats
SetInternalValue(val *VertexAiIndexIndexStats)
ShardsCount() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VectorsCount() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVertexAiIndexIndexStatsOutputReference ¶
func NewVertexAiIndexIndexStatsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) VertexAiIndexIndexStatsOutputReference
type VertexAiIndexMetadata ¶
type VertexAiIndexMetadata struct {
// config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#config VertexAiIndex#config}
Config *VertexAiIndexMetadataConfig `field:"optional" json:"config" yaml:"config"`
// Allows inserting, updating or deleting the contents of the Matching Engine Index.
//
// The string must be a valid Cloud Storage directory path. If this
// field is set when calling IndexService.UpdateIndex, then no other
// Index field can be also updated as part of the same call.
// The expected structure and format of the files this URI points to is
// described at https://cloud.google.com/vertex-ai/docs/matching-engine/using-matching-engine#input-data-format
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#contents_delta_uri VertexAiIndex#contents_delta_uri}
ContentsDeltaUri *string `field:"optional" json:"contentsDeltaUri" yaml:"contentsDeltaUri"`
// If this field is set together with contentsDeltaUri when calling IndexService.UpdateIndex, then existing content of the Index will be replaced by the data from the contentsDeltaUri.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#is_complete_overwrite VertexAiIndex#is_complete_overwrite}
IsCompleteOverwrite interface{} `field:"optional" json:"isCompleteOverwrite" yaml:"isCompleteOverwrite"`
}
type VertexAiIndexMetadataConfig ¶
type VertexAiIndexMetadataConfig struct {
// The number of dimensions of the input vectors.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#dimensions VertexAiIndex#dimensions}
Dimensions *float64 `field:"required" json:"dimensions" yaml:"dimensions"`
// algorithm_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#algorithm_config VertexAiIndex#algorithm_config}
AlgorithmConfig *VertexAiIndexMetadataConfigAlgorithmConfig `field:"optional" json:"algorithmConfig" yaml:"algorithmConfig"`
// The default number of neighbors to find via approximate search before exact reordering is performed.
//
// Exact reordering is a procedure where results returned by an
// approximate search algorithm are reordered via a more expensive distance computation.
// Required if tree-AH algorithm is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#approximate_neighbors_count VertexAiIndex#approximate_neighbors_count}
ApproximateNeighborsCount *float64 `field:"optional" json:"approximateNeighborsCount" yaml:"approximateNeighborsCount"`
// The distance measure used in nearest neighbor search.
//
// The value must be one of the followings:
// SQUARED_L2_DISTANCE: Euclidean (L_2) Distance
// L1_DISTANCE: Manhattan (L_1) Distance
// COSINE_DISTANCE: Cosine Distance. Defined as 1 - cosine similarity.
// DOT_PRODUCT_DISTANCE: Dot Product Distance. Defined as a negative of the dot product
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#distance_measure_type VertexAiIndex#distance_measure_type}
DistanceMeasureType *string `field:"optional" json:"distanceMeasureType" yaml:"distanceMeasureType"`
// Type of normalization to be carried out on each vector.
//
// The value must be one of the followings:
// UNIT_L2_NORM: Unit L2 normalization type
// NONE: No normalization type is specified.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#feature_norm_type VertexAiIndex#feature_norm_type}
FeatureNormType *string `field:"optional" json:"featureNormType" yaml:"featureNormType"`
// Index data is split into equal parts to be processed.
//
// These are called "shards".
// The shard size must be specified when creating an index. The value must be one of the followings:
// SHARD_SIZE_SMALL: Small (2GB)
// SHARD_SIZE_MEDIUM: Medium (20GB)
// SHARD_SIZE_LARGE: Large (50GB)
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#shard_size VertexAiIndex#shard_size}
ShardSize *string `field:"optional" json:"shardSize" yaml:"shardSize"`
}
type VertexAiIndexMetadataConfigAlgorithmConfig ¶
type VertexAiIndexMetadataConfigAlgorithmConfig struct {
// brute_force_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#brute_force_config VertexAiIndex#brute_force_config}
BruteForceConfig *VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfig `field:"optional" json:"bruteForceConfig" yaml:"bruteForceConfig"`
// tree_ah_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#tree_ah_config VertexAiIndex#tree_ah_config}
TreeAhConfig *VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfig `field:"optional" json:"treeAhConfig" yaml:"treeAhConfig"`
}
type VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfig ¶
type VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfig struct {
}
type VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfigOutputReference ¶
type VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfig
SetInternalValue(val *VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfigOutputReference ¶
func NewVertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfigOutputReference
type VertexAiIndexMetadataConfigAlgorithmConfigOutputReference ¶
type VertexAiIndexMetadataConfigAlgorithmConfigOutputReference interface {
cdktf.ComplexObject
BruteForceConfig() VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfigOutputReference
BruteForceConfigInput() *VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfig
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VertexAiIndexMetadataConfigAlgorithmConfig
SetInternalValue(val *VertexAiIndexMetadataConfigAlgorithmConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TreeAhConfig() VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfigOutputReference
TreeAhConfigInput() *VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfig
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutBruteForceConfig(value *VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfig)
PutTreeAhConfig(value *VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfig)
ResetBruteForceConfig()
ResetTreeAhConfig()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVertexAiIndexMetadataConfigAlgorithmConfigOutputReference ¶
func NewVertexAiIndexMetadataConfigAlgorithmConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VertexAiIndexMetadataConfigAlgorithmConfigOutputReference
type VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfig ¶
type VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfig struct {
// Number of embeddings on each leaf node. The default value is 1000 if not set.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#leaf_node_embedding_count VertexAiIndex#leaf_node_embedding_count}
LeafNodeEmbeddingCount *float64 `field:"optional" json:"leafNodeEmbeddingCount" yaml:"leafNodeEmbeddingCount"`
// The default percentage of leaf nodes that any query may be searched.
//
// Must be in
// range 1-100, inclusive. The default value is 10 (means 10%) if not set.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#leaf_nodes_to_search_percent VertexAiIndex#leaf_nodes_to_search_percent}
LeafNodesToSearchPercent *float64 `field:"optional" json:"leafNodesToSearchPercent" yaml:"leafNodesToSearchPercent"`
}
type VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfigOutputReference ¶
type VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfig
SetInternalValue(val *VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfig)
LeafNodeEmbeddingCount() *float64
SetLeafNodeEmbeddingCount(val *float64)
LeafNodeEmbeddingCountInput() *float64
LeafNodesToSearchPercent() *float64
SetLeafNodesToSearchPercent(val *float64)
LeafNodesToSearchPercentInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetLeafNodeEmbeddingCount()
ResetLeafNodesToSearchPercent()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfigOutputReference ¶
func NewVertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfigOutputReference
type VertexAiIndexMetadataConfigOutputReference ¶
type VertexAiIndexMetadataConfigOutputReference interface {
cdktf.ComplexObject
AlgorithmConfig() VertexAiIndexMetadataConfigAlgorithmConfigOutputReference
AlgorithmConfigInput() *VertexAiIndexMetadataConfigAlgorithmConfig
ApproximateNeighborsCount() *float64
SetApproximateNeighborsCount(val *float64)
ApproximateNeighborsCountInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Dimensions() *float64
SetDimensions(val *float64)
DimensionsInput() *float64
DistanceMeasureType() *string
SetDistanceMeasureType(val *string)
DistanceMeasureTypeInput() *string
FeatureNormType() *string
SetFeatureNormType(val *string)
FeatureNormTypeInput() *string
// Experimental.
Fqn() *string
InternalValue() *VertexAiIndexMetadataConfig
SetInternalValue(val *VertexAiIndexMetadataConfig)
ShardSize() *string
SetShardSize(val *string)
ShardSizeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAlgorithmConfig(value *VertexAiIndexMetadataConfigAlgorithmConfig)
ResetAlgorithmConfig()
ResetApproximateNeighborsCount()
ResetDistanceMeasureType()
ResetFeatureNormType()
ResetShardSize()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVertexAiIndexMetadataConfigOutputReference ¶
func NewVertexAiIndexMetadataConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VertexAiIndexMetadataConfigOutputReference
type VertexAiIndexMetadataOutputReference ¶
type VertexAiIndexMetadataOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Config() VertexAiIndexMetadataConfigOutputReference
ConfigInput() *VertexAiIndexMetadataConfig
ContentsDeltaUri() *string
SetContentsDeltaUri(val *string)
ContentsDeltaUriInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VertexAiIndexMetadata
SetInternalValue(val *VertexAiIndexMetadata)
IsCompleteOverwrite() interface{}
SetIsCompleteOverwrite(val interface{})
IsCompleteOverwriteInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutConfig(value *VertexAiIndexMetadataConfig)
ResetConfig()
ResetContentsDeltaUri()
ResetIsCompleteOverwrite()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVertexAiIndexMetadataOutputReference ¶
func NewVertexAiIndexMetadataOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VertexAiIndexMetadataOutputReference
type VertexAiIndexTimeouts ¶
type VertexAiIndexTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#create VertexAiIndex#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#delete VertexAiIndex#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.84.0/docs/resources/vertex_ai_index#update VertexAiIndex#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type VertexAiIndexTimeoutsOutputReference ¶
type VertexAiIndexTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVertexAiIndexTimeoutsOutputReference ¶
func NewVertexAiIndexTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VertexAiIndexTimeoutsOutputReference
Source Files
¶
- VertexAiIndex.go
- VertexAiIndexConfig.go
- VertexAiIndexDeployedIndexes.go
- VertexAiIndexDeployedIndexesList.go
- VertexAiIndexDeployedIndexesList__checks.go
- VertexAiIndexDeployedIndexesOutputReference.go
- VertexAiIndexDeployedIndexesOutputReference__checks.go
- VertexAiIndexIndexStats.go
- VertexAiIndexIndexStatsList.go
- VertexAiIndexIndexStatsList__checks.go
- VertexAiIndexIndexStatsOutputReference.go
- VertexAiIndexIndexStatsOutputReference__checks.go
- VertexAiIndexMetadata.go
- VertexAiIndexMetadataConfig.go
- VertexAiIndexMetadataConfigAlgorithmConfig.go
- VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfig.go
- VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfigOutputReference.go
- VertexAiIndexMetadataConfigAlgorithmConfigBruteForceConfigOutputReference__checks.go
- VertexAiIndexMetadataConfigAlgorithmConfigOutputReference.go
- VertexAiIndexMetadataConfigAlgorithmConfigOutputReference__checks.go
- VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfig.go
- VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfigOutputReference.go
- VertexAiIndexMetadataConfigAlgorithmConfigTreeAhConfigOutputReference__checks.go
- VertexAiIndexMetadataConfigOutputReference.go
- VertexAiIndexMetadataConfigOutputReference__checks.go
- VertexAiIndexMetadataOutputReference.go
- VertexAiIndexMetadataOutputReference__checks.go
- VertexAiIndexTimeouts.go
- VertexAiIndexTimeoutsOutputReference.go
- VertexAiIndexTimeoutsOutputReference__checks.go
- VertexAiIndex__checks.go
- main.go